#define _CFFI_

/* We try to define Py_LIMITED_API before including Python.h.

   Mess: we can only define it if Py_DEBUG, Py_TRACE_REFS and
   Py_REF_DEBUG are not defined.  This is a best-effort approximation:
   we can learn about Py_DEBUG from pyconfig.h, but it is unclear if
   the same works for the other two macros.  Py_DEBUG implies them,
   but not the other way around.

   The implementation is messy (issue #350): on Windows, with _MSC_VER,
   we have to define Py_LIMITED_API even before including pyconfig.h.
   In that case, we guess what pyconfig.h will do to the macros above,
   and check our guess after the #include.

   Note that on Windows, with CPython 3.x, you need >= 3.5 and virtualenv
   version >= 16.0.0.  With older versions of either, you don't get a
   copy of PYTHON3.DLL in the virtualenv.  We can't check the version of
   CPython *before* we even include pyconfig.h.  ffi.set_source() puts
   a ``#define _CFFI_NO_LIMITED_API'' at the start of this file if it is
   running on Windows < 3.5, as an attempt at fixing it, but that's
   arguably wrong because it may not be the target version of Python.
   Still better than nothing I guess.  As another workaround, you can
   remove the definition of Py_LIMITED_API here.

   See also 'py_limited_api' in cffi/setuptools_ext.py.
*/
#if !defined(_CFFI_USE_EMBEDDING) && !defined(Py_LIMITED_API)
#  ifdef _MSC_VER
#    if !defined(_DEBUG) && !defined(Py_DEBUG) && !defined(Py_TRACE_REFS) && !defined(Py_REF_DEBUG) && !defined(_CFFI_NO_LIMITED_API)
#      define Py_LIMITED_API
#    endif
#    include <pyconfig.h>
     /* sanity-check: Py_LIMITED_API will cause crashes if any of these
        are also defined.  Normally, the Python file PC/pyconfig.h does not
        cause any of these to be defined, with the exception that _DEBUG
        causes Py_DEBUG.  Double-check that. */
#    ifdef Py_LIMITED_API
#      if defined(Py_DEBUG)
#        error "pyconfig.h unexpectedly defines Py_DEBUG, but Py_LIMITED_API is set"
#      endif
#      if defined(Py_TRACE_REFS)
#        error "pyconfig.h unexpectedly defines Py_TRACE_REFS, but Py_LIMITED_API is set"
#      endif
#      if defined(Py_REF_DEBUG)
#        error "pyconfig.h unexpectedly defines Py_REF_DEBUG, but Py_LIMITED_API is set"
#      endif
#    endif
#  else
#    include <pyconfig.h>
#    if !defined(Py_DEBUG) && !defined(Py_TRACE_REFS) && !defined(Py_REF_DEBUG) && !defined(_CFFI_NO_LIMITED_API)
#      define Py_LIMITED_API
#    endif
#  endif
#endif

#include <Python.h>
#ifdef __cplusplus
extern "C" {
#endif
#include <stddef.h>

/* This part is from file 'cffi/parse_c_type.h'.  It is copied at the
   beginning of C sources generated by CFFI's ffi.set_source(). */

typedef void *_cffi_opcode_t;

#define _CFFI_OP(opcode, arg)   (_cffi_opcode_t)(opcode | (((uintptr_t)(arg)) << 8))
#define _CFFI_GETOP(cffi_opcode)    ((unsigned char)(uintptr_t)cffi_opcode)
#define _CFFI_GETARG(cffi_opcode)   (((intptr_t)cffi_opcode) >> 8)

#define _CFFI_OP_PRIMITIVE       1
#define _CFFI_OP_POINTER         3
#define _CFFI_OP_ARRAY           5
#define _CFFI_OP_OPEN_ARRAY      7
#define _CFFI_OP_STRUCT_UNION    9
#define _CFFI_OP_ENUM           11
#define _CFFI_OP_FUNCTION       13
#define _CFFI_OP_FUNCTION_END   15
#define _CFFI_OP_NOOP           17
#define _CFFI_OP_BITFIELD       19
#define _CFFI_OP_TYPENAME       21
#define _CFFI_OP_CPYTHON_BLTN_V 23   // varargs
#define _CFFI_OP_CPYTHON_BLTN_N 25   // noargs
#define _CFFI_OP_CPYTHON_BLTN_O 27   // O  (i.e. a single arg)
#define _CFFI_OP_CONSTANT       29
#define _CFFI_OP_CONSTANT_INT   31
#define _CFFI_OP_GLOBAL_VAR     33
#define _CFFI_OP_DLOPEN_FUNC    35
#define _CFFI_OP_DLOPEN_CONST   37
#define _CFFI_OP_GLOBAL_VAR_F   39
#define _CFFI_OP_EXTERN_PYTHON  41

#define _CFFI_PRIM_VOID          0
#define _CFFI_PRIM_BOOL          1
#define _CFFI_PRIM_CHAR          2
#define _CFFI_PRIM_SCHAR         3
#define _CFFI_PRIM_UCHAR         4
#define _CFFI_PRIM_SHORT         5
#define _CFFI_PRIM_USHORT        6
#define _CFFI_PRIM_INT           7
#define _CFFI_PRIM_UINT          8
#define _CFFI_PRIM_LONG          9
#define _CFFI_PRIM_ULONG        10
#define _CFFI_PRIM_LONGLONG     11
#define _CFFI_PRIM_ULONGLONG    12
#define _CFFI_PRIM_FLOAT        13
#define _CFFI_PRIM_DOUBLE       14
#define _CFFI_PRIM_LONGDOUBLE   15

#define _CFFI_PRIM_WCHAR        16
#define _CFFI_PRIM_INT8         17
#define _CFFI_PRIM_UINT8        18
#define _CFFI_PRIM_INT16        19
#define _CFFI_PRIM_UINT16       20
#define _CFFI_PRIM_INT32        21
#define _CFFI_PRIM_UINT32       22
#define _CFFI_PRIM_INT64        23
#define _CFFI_PRIM_UINT64       24
#define _CFFI_PRIM_INTPTR       25
#define _CFFI_PRIM_UINTPTR      26
#define _CFFI_PRIM_PTRDIFF      27
#define _CFFI_PRIM_SIZE         28
#define _CFFI_PRIM_SSIZE        29
#define _CFFI_PRIM_INT_LEAST8   30
#define _CFFI_PRIM_UINT_LEAST8  31
#define _CFFI_PRIM_INT_LEAST16  32
#define _CFFI_PRIM_UINT_LEAST16 33
#define _CFFI_PRIM_INT_LEAST32  34
#define _CFFI_PRIM_UINT_LEAST32 35
#define _CFFI_PRIM_INT_LEAST64  36
#define _CFFI_PRIM_UINT_LEAST64 37
#define _CFFI_PRIM_INT_FAST8    38
#define _CFFI_PRIM_UINT_FAST8   39
#define _CFFI_PRIM_INT_FAST16   40
#define _CFFI_PRIM_UINT_FAST16  41
#define _CFFI_PRIM_INT_FAST32   42
#define _CFFI_PRIM_UINT_FAST32  43
#define _CFFI_PRIM_INT_FAST64   44
#define _CFFI_PRIM_UINT_FAST64  45
#define _CFFI_PRIM_INTMAX       46
#define _CFFI_PRIM_UINTMAX      47
#define _CFFI_PRIM_FLOATCOMPLEX 48
#define _CFFI_PRIM_DOUBLECOMPLEX 49
#define _CFFI_PRIM_CHAR16       50
#define _CFFI_PRIM_CHAR32       51

#define _CFFI__NUM_PRIM         52
#define _CFFI__UNKNOWN_PRIM           (-1)
#define _CFFI__UNKNOWN_FLOAT_PRIM     (-2)
#define _CFFI__UNKNOWN_LONG_DOUBLE    (-3)

#define _CFFI__IO_FILE_STRUCT         (-1)


struct _cffi_global_s {
    const char *name;
    void *address;
    _cffi_opcode_t type_op;
    void *size_or_direct_fn;  // OP_GLOBAL_VAR: size, or 0 if unknown
                              // OP_CPYTHON_BLTN_*: addr of direct function
};

struct _cffi_getconst_s {
    unsigned long long value;
    const struct _cffi_type_context_s *ctx;
    int gindex;
};

struct _cffi_struct_union_s {
    const char *name;
    int type_index;          // -> _cffi_types, on a OP_STRUCT_UNION
    int flags;               // _CFFI_F_* flags below
    size_t size;
    int alignment;
    int first_field_index;   // -> _cffi_fields array
    int num_fields;
};
#define _CFFI_F_UNION         0x01   // is a union, not a struct
#define _CFFI_F_CHECK_FIELDS  0x02   // complain if fields are not in the
                                     // "standard layout" or if some are missing
#define _CFFI_F_PACKED        0x04   // for CHECK_FIELDS, assume a packed struct
#define _CFFI_F_EXTERNAL      0x08   // in some other ffi.include()
#define _CFFI_F_OPAQUE        0x10   // opaque

struct _cffi_field_s {
    const char *name;
    size_t field_offset;
    size_t field_size;
    _cffi_opcode_t field_type_op;
};

struct _cffi_enum_s {
    const char *name;
    int type_index;          // -> _cffi_types, on a OP_ENUM
    int type_prim;           // _CFFI_PRIM_xxx
    const char *enumerators; // comma-delimited string
};

struct _cffi_typename_s {
    const char *name;
    int type_index;   /* if opaque, points to a possibly artificial
                         OP_STRUCT which is itself opaque */
};

struct _cffi_type_context_s {
    _cffi_opcode_t *types;
    const struct _cffi_global_s *globals;
    const struct _cffi_field_s *fields;
    const struct _cffi_struct_union_s *struct_unions;
    const struct _cffi_enum_s *enums;
    const struct _cffi_typename_s *typenames;
    int num_globals;
    int num_struct_unions;
    int num_enums;
    int num_typenames;
    const char *const *includes;
    int num_types;
    int flags;      /* future extension */
};

struct _cffi_parse_info_s {
    const struct _cffi_type_context_s *ctx;
    _cffi_opcode_t *output;
    unsigned int output_size;
    size_t error_location;
    const char *error_message;
};

struct _cffi_externpy_s {
    const char *name;
    size_t size_of_result;
    void *reserved1, *reserved2;
};

#ifdef _CFFI_INTERNAL
static int parse_c_type(struct _cffi_parse_info_s *info, const char *input);
static int search_in_globals(const struct _cffi_type_context_s *ctx,
                             const char *search, size_t search_len);
static int search_in_struct_unions(const struct _cffi_type_context_s *ctx,
                                   const char *search, size_t search_len);
#endif

/* this block of #ifs should be kept exactly identical between
   c/_cffi_backend.c, cffi/vengine_cpy.py, cffi/vengine_gen.py
   and cffi/_cffi_include.h */
#if defined(_MSC_VER)
# include <malloc.h>   /* for alloca() */
# if _MSC_VER < 1600   /* MSVC < 2010 */
   typedef __int8 int8_t;
   typedef __int16 int16_t;
   typedef __int32 int32_t;
   typedef __int64 int64_t;
   typedef unsigned __int8 uint8_t;
   typedef unsigned __int16 uint16_t;
   typedef unsigned __int32 uint32_t;
   typedef unsigned __int64 uint64_t;
   typedef __int8 int_least8_t;
   typedef __int16 int_least16_t;
   typedef __int32 int_least32_t;
   typedef __int64 int_least64_t;
   typedef unsigned __int8 uint_least8_t;
   typedef unsigned __int16 uint_least16_t;
   typedef unsigned __int32 uint_least32_t;
   typedef unsigned __int64 uint_least64_t;
   typedef __int8 int_fast8_t;
   typedef __int16 int_fast16_t;
   typedef __int32 int_fast32_t;
   typedef __int64 int_fast64_t;
   typedef unsigned __int8 uint_fast8_t;
   typedef unsigned __int16 uint_fast16_t;
   typedef unsigned __int32 uint_fast32_t;
   typedef unsigned __int64 uint_fast64_t;
   typedef __int64 intmax_t;
   typedef unsigned __int64 uintmax_t;
# else
#  include <stdint.h>
# endif
# if _MSC_VER < 1800   /* MSVC < 2013 */
#  ifndef __cplusplus
    typedef unsigned char _Bool;
#  endif
# endif
# define _cffi_float_complex_t   _Fcomplex    /* include <complex.h> for it */
# define _cffi_double_complex_t  _Dcomplex    /* include <complex.h> for it */
#else
# include <stdint.h>
# if (defined (__SVR4) && defined (__sun)) || defined(_AIX) || defined(__hpux)
#  include <alloca.h>
# endif
# define _cffi_float_complex_t   float _Complex
# define _cffi_double_complex_t  double _Complex
#endif

#ifdef __GNUC__
# define _CFFI_UNUSED_FN  __attribute__((unused))
#else
# define _CFFI_UNUSED_FN  /* nothing */
#endif

#ifdef __cplusplus
# ifndef _Bool
   typedef bool _Bool;   /* semi-hackish: C++ has no _Bool; bool is builtin */
# endif
#endif

/**********  CPython-specific section  **********/
#ifndef PYPY_VERSION


#if PY_MAJOR_VERSION >= 3
# define PyInt_FromLong PyLong_FromLong
#endif

#define _cffi_from_c_double PyFloat_FromDouble
#define _cffi_from_c_float PyFloat_FromDouble
#define _cffi_from_c_long PyInt_FromLong
#define _cffi_from_c_ulong PyLong_FromUnsignedLong
#define _cffi_from_c_longlong PyLong_FromLongLong
#define _cffi_from_c_ulonglong PyLong_FromUnsignedLongLong
#define _cffi_from_c__Bool PyBool_FromLong

#define _cffi_to_c_double PyFloat_AsDouble
#define _cffi_to_c_float PyFloat_AsDouble

#define _cffi_from_c_int(x, type)                                        \
    (((type)-1) > 0 ? /* unsigned */                                     \
        (sizeof(type) < sizeof(long) ?                                   \
            PyInt_FromLong((long)x) :                                    \
         sizeof(type) == sizeof(long) ?                                  \
            PyLong_FromUnsignedLong((unsigned long)x) :                  \
            PyLong_FromUnsignedLongLong((unsigned long long)x)) :        \
        (sizeof(type) <= sizeof(long) ?                                  \
            PyInt_FromLong((long)x) :                                    \
            PyLong_FromLongLong((long long)x)))

#define _cffi_to_c_int(o, type)                                          \
    ((type)(                                                             \
     sizeof(type) == 1 ? (((type)-1) > 0 ? (type)_cffi_to_c_u8(o)        \
                                         : (type)_cffi_to_c_i8(o)) :     \
     sizeof(type) == 2 ? (((type)-1) > 0 ? (type)_cffi_to_c_u16(o)       \
                                         : (type)_cffi_to_c_i16(o)) :    \
     sizeof(type) == 4 ? (((type)-1) > 0 ? (type)_cffi_to_c_u32(o)       \
                                         : (type)_cffi_to_c_i32(o)) :    \
     sizeof(type) == 8 ? (((type)-1) > 0 ? (type)_cffi_to_c_u64(o)       \
                                         : (type)_cffi_to_c_i64(o)) :    \
     (Py_FatalError("unsupported size for type " #type), (type)0)))

#define _cffi_to_c_i8                                                    \
                 ((int(*)(PyObject *))_cffi_exports[1])
#define _cffi_to_c_u8                                                    \
                 ((int(*)(PyObject *))_cffi_exports[2])
#define _cffi_to_c_i16                                                   \
                 ((int(*)(PyObject *))_cffi_exports[3])
#define _cffi_to_c_u16                                                   \
                 ((int(*)(PyObject *))_cffi_exports[4])
#define _cffi_to_c_i32                                                   \
                 ((int(*)(PyObject *))_cffi_exports[5])
#define _cffi_to_c_u32                                                   \
                 ((unsigned int(*)(PyObject *))_cffi_exports[6])
#define _cffi_to_c_i64                                                   \
                 ((long long(*)(PyObject *))_cffi_exports[7])
#define _cffi_to_c_u64                                                   \
                 ((unsigned long long(*)(PyObject *))_cffi_exports[8])
#define _cffi_to_c_char                                                  \
                 ((int(*)(PyObject *))_cffi_exports[9])
#define _cffi_from_c_pointer                                             \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[10])
#define _cffi_to_c_pointer                                               \
    ((char *(*)(PyObject *, struct _cffi_ctypedescr *))_cffi_exports[11])
#define _cffi_get_struct_layout                                          \
    not used any more
#define _cffi_restore_errno                                              \
    ((void(*)(void))_cffi_exports[13])
#define _cffi_save_errno                                                 \
    ((void(*)(void))_cffi_exports[14])
#define _cffi_from_c_char                                                \
    ((PyObject *(*)(char))_cffi_exports[15])
#define _cffi_from_c_deref                                               \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[16])
#define _cffi_to_c                                                       \
    ((int(*)(char *, struct _cffi_ctypedescr *, PyObject *))_cffi_exports[17])
#define _cffi_from_c_struct                                              \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[18])
#define _cffi_to_c_wchar_t                                               \
    ((_cffi_wchar_t(*)(PyObject *))_cffi_exports[19])
#define _cffi_from_c_wchar_t                                             \
    ((PyObject *(*)(_cffi_wchar_t))_cffi_exports[20])
#define _cffi_to_c_long_double                                           \
    ((long double(*)(PyObject *))_cffi_exports[21])
#define _cffi_to_c__Bool                                                 \
    ((_Bool(*)(PyObject *))_cffi_exports[22])
#define _cffi_prepare_pointer_call_argument                              \
    ((Py_ssize_t(*)(struct _cffi_ctypedescr *,                           \
                    PyObject *, char **))_cffi_exports[23])
#define _cffi_convert_array_from_object                                  \
    ((int(*)(char *, struct _cffi_ctypedescr *, PyObject *))_cffi_exports[24])
#define _CFFI_CPIDX  25
#define _cffi_call_python                                                \
    ((void(*)(struct _cffi_externpy_s *, char *))_cffi_exports[_CFFI_CPIDX])
#define _cffi_to_c_wchar3216_t                                           \
    ((int(*)(PyObject *))_cffi_exports[26])
#define _cffi_from_c_wchar3216_t                                         \
    ((PyObject *(*)(int))_cffi_exports[27])
#define _CFFI_NUM_EXPORTS 28

struct _cffi_ctypedescr;

static void *_cffi_exports[_CFFI_NUM_EXPORTS];

#define _cffi_type(index)   (                           \
    assert((((uintptr_t)_cffi_types[index]) & 1) == 0), \
    (struct _cffi_ctypedescr *)_cffi_types[index])

static PyObject *_cffi_init(const char *module_name, Py_ssize_t version,
                            const struct _cffi_type_context_s *ctx)
{
    PyObject *module, *o_arg, *new_module;
    void *raw[] = {
        (void *)module_name,
        (void *)version,
        (void *)_cffi_exports,
        (void *)ctx,
    };

    module = PyImport_ImportModule("_cffi_backend");
    if (module == NULL)
        goto failure;

    o_arg = PyLong_FromVoidPtr((void *)raw);
    if (o_arg == NULL)
        goto failure;

    new_module = PyObject_CallMethod(
        module, (char *)"_init_cffi_1_0_external_module", (char *)"O", o_arg);

    Py_DECREF(o_arg);
    Py_DECREF(module);
    return new_module;

  failure:
    Py_XDECREF(module);
    return NULL;
}


#ifdef HAVE_WCHAR_H
typedef wchar_t _cffi_wchar_t;
#else
typedef uint16_t _cffi_wchar_t;   /* same random pick as _cffi_backend.c */
#endif

_CFFI_UNUSED_FN static uint16_t _cffi_to_c_char16_t(PyObject *o)
{
    if (sizeof(_cffi_wchar_t) == 2)
        return (uint16_t)_cffi_to_c_wchar_t(o);
    else
        return (uint16_t)_cffi_to_c_wchar3216_t(o);
}

_CFFI_UNUSED_FN static PyObject *_cffi_from_c_char16_t(uint16_t x)
{
    if (sizeof(_cffi_wchar_t) == 2)
        return _cffi_from_c_wchar_t((_cffi_wchar_t)x);
    else
        return _cffi_from_c_wchar3216_t((int)x);
}

_CFFI_UNUSED_FN static int _cffi_to_c_char32_t(PyObject *o)
{
    if (sizeof(_cffi_wchar_t) == 4)
        return (int)_cffi_to_c_wchar_t(o);
    else
        return (int)_cffi_to_c_wchar3216_t(o);
}

_CFFI_UNUSED_FN static PyObject *_cffi_from_c_char32_t(unsigned int x)
{
    if (sizeof(_cffi_wchar_t) == 4)
        return _cffi_from_c_wchar_t((_cffi_wchar_t)x);
    else
        return _cffi_from_c_wchar3216_t((int)x);
}

union _cffi_union_alignment_u {
    unsigned char m_char;
    unsigned short m_short;
    unsigned int m_int;
    unsigned long m_long;
    unsigned long long m_longlong;
    float m_float;
    double m_double;
    long double m_longdouble;
};

struct _cffi_freeme_s {
    struct _cffi_freeme_s *next;
    union _cffi_union_alignment_u alignment;
};

_CFFI_UNUSED_FN static int
_cffi_convert_array_argument(struct _cffi_ctypedescr *ctptr, PyObject *arg,
                             char **output_data, Py_ssize_t datasize,
                             struct _cffi_freeme_s **freeme)
{
    char *p;
    if (datasize < 0)
        return -1;

    p = *output_data;
    if (p == NULL) {
        struct _cffi_freeme_s *fp = (struct _cffi_freeme_s *)PyObject_Malloc(
            offsetof(struct _cffi_freeme_s, alignment) + (size_t)datasize);
        if (fp == NULL)
            return -1;
        fp->next = *freeme;
        *freeme = fp;
        p = *output_data = (char *)&fp->alignment;
    }
    memset((void *)p, 0, (size_t)datasize);
    return _cffi_convert_array_from_object(p, ctptr, arg);
}

_CFFI_UNUSED_FN static void
_cffi_free_array_arguments(struct _cffi_freeme_s *freeme)
{
    do {
        void *p = (void *)freeme;
        freeme = freeme->next;
        PyObject_Free(p);
    } while (freeme != NULL);
}

/**********  end CPython-specific section  **********/
#else
_CFFI_UNUSED_FN
static void (*_cffi_call_python_org)(struct _cffi_externpy_s *, char *);
# define _cffi_call_python  _cffi_call_python_org
#endif


#define _cffi_array_len(array)   (sizeof(array) / sizeof((array)[0]))

#define _cffi_prim_int(size, sign)                                      \
    ((size) == 1 ? ((sign) ? _CFFI_PRIM_INT8  : _CFFI_PRIM_UINT8)  :    \
     (size) == 2 ? ((sign) ? _CFFI_PRIM_INT16 : _CFFI_PRIM_UINT16) :    \
     (size) == 4 ? ((sign) ? _CFFI_PRIM_INT32 : _CFFI_PRIM_UINT32) :    \
     (size) == 8 ? ((sign) ? _CFFI_PRIM_INT64 : _CFFI_PRIM_UINT64) :    \
     _CFFI__UNKNOWN_PRIM)

#define _cffi_prim_float(size)                                          \
    ((size) == sizeof(float) ? _CFFI_PRIM_FLOAT :                       \
     (size) == sizeof(double) ? _CFFI_PRIM_DOUBLE :                     \
     (size) == sizeof(long double) ? _CFFI__UNKNOWN_LONG_DOUBLE :       \
     _CFFI__UNKNOWN_FLOAT_PRIM)

#define _cffi_check_int(got, got_nonpos, expected)      \
    ((got_nonpos) == (expected <= 0) &&                 \
     (got) == (unsigned long long)expected)

#ifdef MS_WIN32
# define _cffi_stdcall  __stdcall
#else
# define _cffi_stdcall  /* nothing */
#endif

#ifdef __cplusplus
}
#endif

/************************************************************/


#include <libkdumpfile/kdumpfile.h>
#include <stdlib.h>


/************************************************************/

static void *_cffi_types[] = {
/*  0 */ _CFFI_OP(_CFFI_OP_FUNCTION, 138), // addrxlat_cb_t *()(addrxlat_ctx_t *)
/*  1 */ _CFFI_OP(_CFFI_OP_POINTER, 172), // addrxlat_ctx_t *
/*  2 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/*  3 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // addrxlat_cb_t const *()(addrxlat_ctx_t const *)
/*  4 */ _CFFI_OP(_CFFI_OP_POINTER, 172), // addrxlat_ctx_t const *
/*  5 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/*  6 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // addrxlat_ctx_t *()(void)
/*  7 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/*  8 */ _CFFI_OP(_CFFI_OP_FUNCTION, 54), // addrxlat_map_t *()(addrxlat_map_t const *)
/*  9 */ _CFFI_OP(_CFFI_OP_POINTER, 178), // addrxlat_map_t const *
/* 10 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 11 */ _CFFI_OP(_CFFI_OP_FUNCTION, 54), // addrxlat_map_t *()(addrxlat_sys_t const *, addrxlat_sys_map_t)
/* 12 */ _CFFI_OP(_CFFI_OP_POINTER, 200), // addrxlat_sys_t const *
/* 13 */ _CFFI_OP(_CFFI_OP_ENUM, 6), // addrxlat_sys_map_t
/* 14 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 15 */ _CFFI_OP(_CFFI_OP_FUNCTION, 54), // addrxlat_map_t *()(void)
/* 16 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 17 */ _CFFI_OP(_CFFI_OP_FUNCTION, 164), // addrxlat_meth_t const *()(addrxlat_sys_t const *, addrxlat_sys_meth_t)
/* 18 */ _CFFI_OP(_CFFI_OP_NOOP, 12),
/* 19 */ _CFFI_OP(_CFFI_OP_ENUM, 7), // addrxlat_sys_meth_t
/* 20 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 21 */ _CFFI_OP(_CFFI_OP_FUNCTION, 92), // addrxlat_pte_format_t()(char const *)
/* 22 */ _CFFI_OP(_CFFI_OP_POINTER, 201), // char const *
/* 23 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 24 */ _CFFI_OP(_CFFI_OP_FUNCTION, 56), // addrxlat_range_t const *()(addrxlat_map_t const *)
/* 25 */ _CFFI_OP(_CFFI_OP_NOOP, 9),
/* 26 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 27 */ _CFFI_OP(_CFFI_OP_FUNCTION, 44), // addrxlat_status()(addrxlat_cb_t const *, addrxlat_buffer_t *)
/* 28 */ _CFFI_OP(_CFFI_OP_POINTER, 171), // addrxlat_cb_t const *
/* 29 */ _CFFI_OP(_CFFI_OP_POINTER, 169), // addrxlat_buffer_t *
/* 30 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 31 */ _CFFI_OP(_CFFI_OP_FUNCTION, 44), // addrxlat_status()(addrxlat_cb_t const *, char const *, char const *, uint_fast64_t *)
/* 32 */ _CFFI_OP(_CFFI_OP_NOOP, 28),
/* 33 */ _CFFI_OP(_CFFI_OP_NOOP, 22),
/* 34 */ _CFFI_OP(_CFFI_OP_NOOP, 22),
/* 35 */ _CFFI_OP(_CFFI_OP_POINTER, 55), // uint_fast64_t *
/* 36 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 37 */ _CFFI_OP(_CFFI_OP_FUNCTION, 44), // addrxlat_status()(addrxlat_cb_t const *, char const *, uint_fast64_t *)
/* 38 */ _CFFI_OP(_CFFI_OP_NOOP, 28),
/* 39 */ _CFFI_OP(_CFFI_OP_NOOP, 22),
/* 40 */ _CFFI_OP(_CFFI_OP_NOOP, 35),
/* 41 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 42 */ _CFFI_OP(_CFFI_OP_FUNCTION, 44), // addrxlat_status()(addrxlat_ctx_t *, addrxlat_status, char const *, ...)
/* 43 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/* 44 */ _CFFI_OP(_CFFI_OP_ENUM, 5), // addrxlat_status
/* 45 */ _CFFI_OP(_CFFI_OP_NOOP, 22),
/* 46 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 1),
/* 47 */ _CFFI_OP(_CFFI_OP_FUNCTION, 44), // addrxlat_status()(addrxlat_fulladdr_t *, addrxlat_addrspace_t, addrxlat_ctx_t *, addrxlat_sys_t *)
/* 48 */ _CFFI_OP(_CFFI_OP_POINTER, 173), // addrxlat_fulladdr_t *
/* 49 */ _CFFI_OP(_CFFI_OP_ENUM, 0), // addrxlat_addrspace_t
/* 50 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/* 51 */ _CFFI_OP(_CFFI_OP_POINTER, 200), // addrxlat_sys_t *
/* 52 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 53 */ _CFFI_OP(_CFFI_OP_FUNCTION, 44), // addrxlat_status()(addrxlat_map_t *, uint_fast64_t, addrxlat_range_t const *)
/* 54 */ _CFFI_OP(_CFFI_OP_POINTER, 178), // addrxlat_map_t *
/* 55 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 45), // uint_fast64_t
/* 56 */ _CFFI_OP(_CFFI_OP_POINTER, 191), // addrxlat_range_t const *
/* 57 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 58 */ _CFFI_OP(_CFFI_OP_FUNCTION, 44), // addrxlat_status()(addrxlat_op_ctl_t const *, addrxlat_fulladdr_t const *)
/* 59 */ _CFFI_OP(_CFFI_OP_POINTER, 180), // addrxlat_op_ctl_t const *
/* 60 */ _CFFI_OP(_CFFI_OP_POINTER, 173), // addrxlat_fulladdr_t const *
/* 61 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 62 */ _CFFI_OP(_CFFI_OP_FUNCTION, 44), // addrxlat_status()(addrxlat_step_t *)
/* 63 */ _CFFI_OP(_CFFI_OP_POINTER, 199), // addrxlat_step_t *
/* 64 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 65 */ _CFFI_OP(_CFFI_OP_FUNCTION, 44), // addrxlat_status()(addrxlat_step_t *, uint_fast64_t)
/* 66 */ _CFFI_OP(_CFFI_OP_NOOP, 63),
/* 67 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 45),
/* 68 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 69 */ _CFFI_OP(_CFFI_OP_FUNCTION, 44), // addrxlat_status()(addrxlat_sys_t *, addrxlat_ctx_t *, unsigned int, addrxlat_opt_t const *)
/* 70 */ _CFFI_OP(_CFFI_OP_NOOP, 51),
/* 71 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/* 72 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8), // unsigned int
/* 73 */ _CFFI_OP(_CFFI_OP_POINTER, 181), // addrxlat_opt_t const *
/* 74 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 75 */ _CFFI_OP(_CFFI_OP_FUNCTION, 44), // addrxlat_status()(void *, addrxlat_fulladdr_t const *)
/* 76 */ _CFFI_OP(_CFFI_OP_POINTER, 213), // void *
/* 77 */ _CFFI_OP(_CFFI_OP_NOOP, 60),
/* 78 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 79 */ _CFFI_OP(_CFFI_OP_FUNCTION, 19), // addrxlat_sys_meth_t()(addrxlat_map_t const *, uint_fast64_t)
/* 80 */ _CFFI_OP(_CFFI_OP_NOOP, 9),
/* 81 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 45),
/* 82 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 83 */ _CFFI_OP(_CFFI_OP_FUNCTION, 51), // addrxlat_sys_t *()(void)
/* 84 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 85 */ _CFFI_OP(_CFFI_OP_FUNCTION, 22), // char const *()(addrxlat_addrspace_t)
/* 86 */ _CFFI_OP(_CFFI_OP_NOOP, 49),
/* 87 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 88 */ _CFFI_OP(_CFFI_OP_FUNCTION, 22), // char const *()(addrxlat_ctx_t const *)
/* 89 */ _CFFI_OP(_CFFI_OP_NOOP, 4),
/* 90 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 91 */ _CFFI_OP(_CFFI_OP_FUNCTION, 22), // char const *()(addrxlat_pte_format_t)
/* 92 */ _CFFI_OP(_CFFI_OP_ENUM, 4), // addrxlat_pte_format_t
/* 93 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 94 */ _CFFI_OP(_CFFI_OP_FUNCTION, 22), // char const *()(addrxlat_status)
/* 95 */ _CFFI_OP(_CFFI_OP_NOOP, 44),
/* 96 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 97 */ _CFFI_OP(_CFFI_OP_FUNCTION, 202), // int()(addrxlat_pte_format_t)
/* 98 */ _CFFI_OP(_CFFI_OP_NOOP, 92),
/* 99 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 100 */ _CFFI_OP(_CFFI_OP_FUNCTION, 128), // size_t()(addrxlat_map_t const *)
/* 101 */ _CFFI_OP(_CFFI_OP_NOOP, 9),
/* 102 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 103 */ _CFFI_OP(_CFFI_OP_FUNCTION, 154), // unsigned long()(addrxlat_cb_t const *)
/* 104 */ _CFFI_OP(_CFFI_OP_NOOP, 28),
/* 105 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 106 */ _CFFI_OP(_CFFI_OP_FUNCTION, 154), // unsigned long()(addrxlat_ctx_t *)
/* 107 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/* 108 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 109 */ _CFFI_OP(_CFFI_OP_FUNCTION, 154), // unsigned long()(addrxlat_map_t *)
/* 110 */ _CFFI_OP(_CFFI_OP_NOOP, 54),
/* 111 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 112 */ _CFFI_OP(_CFFI_OP_FUNCTION, 154), // unsigned long()(addrxlat_sys_t *)
/* 113 */ _CFFI_OP(_CFFI_OP_NOOP, 51),
/* 114 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 115 */ _CFFI_OP(_CFFI_OP_FUNCTION, 154), // unsigned long()(unsigned int)
/* 116 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 117 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 118 */ _CFFI_OP(_CFFI_OP_FUNCTION, 154), // unsigned long()(unsigned int, unsigned int)
/* 119 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 120 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 121 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 122 */ _CFFI_OP(_CFFI_OP_FUNCTION, 154), // unsigned long()(unsigned int, unsigned int, unsigned int)
/* 123 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 124 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 125 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 126 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 127 */ _CFFI_OP(_CFFI_OP_FUNCTION, 76), // void *()(size_t)
/* 128 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28), // size_t
/* 129 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 130 */ _CFFI_OP(_CFFI_OP_FUNCTION, 213), // void()(addrxlat_buffer_t const *)
/* 131 */ _CFFI_OP(_CFFI_OP_POINTER, 169), // addrxlat_buffer_t const *
/* 132 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 133 */ _CFFI_OP(_CFFI_OP_FUNCTION, 213), // void()(addrxlat_ctx_t *)
/* 134 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/* 135 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 136 */ _CFFI_OP(_CFFI_OP_FUNCTION, 213), // void()(addrxlat_ctx_t *, addrxlat_cb_t *)
/* 137 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/* 138 */ _CFFI_OP(_CFFI_OP_POINTER, 171), // addrxlat_cb_t *
/* 139 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 140 */ _CFFI_OP(_CFFI_OP_FUNCTION, 213), // void()(addrxlat_opt_t *, addrxlat_fulladdr_t const *)
/* 141 */ _CFFI_OP(_CFFI_OP_POINTER, 181), // addrxlat_opt_t *
/* 142 */ _CFFI_OP(_CFFI_OP_NOOP, 60),
/* 143 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 144 */ _CFFI_OP(_CFFI_OP_FUNCTION, 213), // void()(addrxlat_opt_t *, char const *)
/* 145 */ _CFFI_OP(_CFFI_OP_NOOP, 141),
/* 146 */ _CFFI_OP(_CFFI_OP_NOOP, 22),
/* 147 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 148 */ _CFFI_OP(_CFFI_OP_FUNCTION, 213), // void()(addrxlat_opt_t *, uint_fast64_t)
/* 149 */ _CFFI_OP(_CFFI_OP_NOOP, 141),
/* 150 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 45),
/* 151 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 152 */ _CFFI_OP(_CFFI_OP_FUNCTION, 213), // void()(addrxlat_opt_t *, unsigned long)
/* 153 */ _CFFI_OP(_CFFI_OP_NOOP, 141),
/* 154 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 10), // unsigned long
/* 155 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 156 */ _CFFI_OP(_CFFI_OP_FUNCTION, 213), // void()(addrxlat_sys_t *, addrxlat_sys_map_t, addrxlat_map_t *)
/* 157 */ _CFFI_OP(_CFFI_OP_NOOP, 51),
/* 158 */ _CFFI_OP(_CFFI_OP_NOOP, 13),
/* 159 */ _CFFI_OP(_CFFI_OP_NOOP, 54),
/* 160 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 161 */ _CFFI_OP(_CFFI_OP_FUNCTION, 213), // void()(addrxlat_sys_t *, addrxlat_sys_meth_t, addrxlat_meth_t const *)
/* 162 */ _CFFI_OP(_CFFI_OP_NOOP, 51),
/* 163 */ _CFFI_OP(_CFFI_OP_NOOP, 19),
/* 164 */ _CFFI_OP(_CFFI_OP_POINTER, 179), // addrxlat_meth_t const *
/* 165 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 166 */ _CFFI_OP(_CFFI_OP_FUNCTION, 213), // void()(void *)
/* 167 */ _CFFI_OP(_CFFI_OP_NOOP, 76),
/* 168 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 169 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 1), // addrxlat_buffer_t
/* 170 */ _CFFI_OP(_CFFI_OP_ENUM, 1), // addrxlat_byte_order_t
/* 171 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 2), // addrxlat_cb_t
/* 172 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 3), // addrxlat_ctx_t
/* 173 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 4), // addrxlat_fulladdr_t
/* 174 */ _CFFI_OP(_CFFI_OP_ENUM, 2), // addrxlat_kind_t
/* 175 */ _CFFI_OP(_CFFI_OP_POINTER, 177), // addrxlat_lookup_elem_t *
/* 176 */ _CFFI_OP(_CFFI_OP_POINTER, 177), // addrxlat_lookup_elem_t const *
/* 177 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 5), // addrxlat_lookup_elem_t
/* 178 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 6), // addrxlat_map_t
/* 179 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 7), // addrxlat_meth_t
/* 180 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 8), // addrxlat_op_ctl_t
/* 181 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 9), // addrxlat_opt_t
/* 182 */ _CFFI_OP(_CFFI_OP_ENUM, 3), // addrxlat_optidx_t
/* 183 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 10), // addrxlat_optval_t
/* 184 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 11), // addrxlat_paging_form_t
/* 185 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 13), // addrxlat_param_custom_t
/* 186 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 14), // addrxlat_param_linear_t
/* 187 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 15), // addrxlat_param_lookup_t
/* 188 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 16), // addrxlat_param_memarr_t
/* 189 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 17), // addrxlat_param_pgt_t
/* 190 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 12), // addrxlat_param_t
/* 191 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 18), // addrxlat_range_t
/* 192 */ _CFFI_OP(_CFFI_OP_POINTER, 27), // addrxlat_status(*)(addrxlat_cb_t const *, addrxlat_buffer_t *)
/* 193 */ _CFFI_OP(_CFFI_OP_POINTER, 31), // addrxlat_status(*)(addrxlat_cb_t const *, char const *, char const *, uint_fast64_t *)
/* 194 */ _CFFI_OP(_CFFI_OP_POINTER, 37), // addrxlat_status(*)(addrxlat_cb_t const *, char const *, uint_fast64_t *)
/* 195 */ _CFFI_OP(_CFFI_OP_POINTER, 42), // addrxlat_status(*)(addrxlat_ctx_t *, addrxlat_status, char const *, ...)
/* 196 */ _CFFI_OP(_CFFI_OP_POINTER, 62), // addrxlat_status(*)(addrxlat_step_t *)
/* 197 */ _CFFI_OP(_CFFI_OP_POINTER, 65), // addrxlat_status(*)(addrxlat_step_t *, uint_fast64_t)
/* 198 */ _CFFI_OP(_CFFI_OP_POINTER, 75), // addrxlat_status(*)(void *, addrxlat_fulladdr_t const *)
/* 199 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 19), // addrxlat_step_t
/* 200 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 20), // addrxlat_sys_t
/* 201 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 2), // char
/* 202 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7), // int
/* 203 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 44), // int_fast64_t
/* 204 */ _CFFI_OP(_CFFI_OP_ARRAY, 55), // uint_fast64_t[9]
/* 205 */ (_cffi_opcode_t)(9),
/* 206 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 0), // union $1
/* 207 */ _CFFI_OP(_CFFI_OP_POINTER, 103), // unsigned long(*)(addrxlat_cb_t const *)
/* 208 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6), // unsigned short
/* 209 */ _CFFI_OP(_CFFI_OP_ARRAY, 208), // unsigned short[8]
/* 210 */ (_cffi_opcode_t)(8),
/* 211 */ _CFFI_OP(_CFFI_OP_POINTER, 213), // void const *
/* 212 */ _CFFI_OP(_CFFI_OP_POINTER, 130), // void(*)(addrxlat_buffer_t const *)
/* 213 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 0), // void
};

static int _cffi_const_ADDRXLAT_KPHYSADDR(unsigned long long *o)
{
  int n = (ADDRXLAT_KPHYSADDR) <= 0;
  *o = (unsigned long long)((ADDRXLAT_KPHYSADDR) | 0);  /* check that ADDRXLAT_KPHYSADDR is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_MACHPHYSADDR(unsigned long long *o)
{
  int n = (ADDRXLAT_MACHPHYSADDR) <= 0;
  *o = (unsigned long long)((ADDRXLAT_MACHPHYSADDR) | 0);  /* check that ADDRXLAT_MACHPHYSADDR is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_KVADDR(unsigned long long *o)
{
  int n = (ADDRXLAT_KVADDR) <= 0;
  *o = (unsigned long long)((ADDRXLAT_KVADDR) | 0);  /* check that ADDRXLAT_KVADDR is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_NOADDR(unsigned long long *o)
{
  int n = (ADDRXLAT_NOADDR) <= 0;
  *o = (unsigned long long)((ADDRXLAT_NOADDR) | 0);  /* check that ADDRXLAT_NOADDR is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_BIG_ENDIAN(unsigned long long *o)
{
  int n = (ADDRXLAT_BIG_ENDIAN) <= 0;
  *o = (unsigned long long)((ADDRXLAT_BIG_ENDIAN) | 0);  /* check that ADDRXLAT_BIG_ENDIAN is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_LITTLE_ENDIAN(unsigned long long *o)
{
  int n = (ADDRXLAT_LITTLE_ENDIAN) <= 0;
  *o = (unsigned long long)((ADDRXLAT_LITTLE_ENDIAN) | 0);  /* check that ADDRXLAT_LITTLE_ENDIAN is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_HOST_ENDIAN(unsigned long long *o)
{
  int n = (ADDRXLAT_HOST_ENDIAN) <= 0;
  *o = (unsigned long long)((ADDRXLAT_HOST_ENDIAN) | 0);  /* check that ADDRXLAT_HOST_ENDIAN is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_NOMETH(unsigned long long *o)
{
  int n = (ADDRXLAT_NOMETH) <= 0;
  *o = (unsigned long long)((ADDRXLAT_NOMETH) | 0);  /* check that ADDRXLAT_NOMETH is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_CUSTOM(unsigned long long *o)
{
  int n = (ADDRXLAT_CUSTOM) <= 0;
  *o = (unsigned long long)((ADDRXLAT_CUSTOM) | 0);  /* check that ADDRXLAT_CUSTOM is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_LINEAR(unsigned long long *o)
{
  int n = (ADDRXLAT_LINEAR) <= 0;
  *o = (unsigned long long)((ADDRXLAT_LINEAR) | 0);  /* check that ADDRXLAT_LINEAR is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_PGT(unsigned long long *o)
{
  int n = (ADDRXLAT_PGT) <= 0;
  *o = (unsigned long long)((ADDRXLAT_PGT) | 0);  /* check that ADDRXLAT_PGT is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_LOOKUP(unsigned long long *o)
{
  int n = (ADDRXLAT_LOOKUP) <= 0;
  *o = (unsigned long long)((ADDRXLAT_LOOKUP) | 0);  /* check that ADDRXLAT_LOOKUP is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_MEMARR(unsigned long long *o)
{
  int n = (ADDRXLAT_MEMARR) <= 0;
  *o = (unsigned long long)((ADDRXLAT_MEMARR) | 0);  /* check that ADDRXLAT_MEMARR is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_OPT_NULL(unsigned long long *o)
{
  int n = (ADDRXLAT_OPT_NULL) <= 0;
  *o = (unsigned long long)((ADDRXLAT_OPT_NULL) | 0);  /* check that ADDRXLAT_OPT_NULL is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_OPT_arch(unsigned long long *o)
{
  int n = (ADDRXLAT_OPT_arch) <= 0;
  *o = (unsigned long long)((ADDRXLAT_OPT_arch) | 0);  /* check that ADDRXLAT_OPT_arch is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_OPT_os_type(unsigned long long *o)
{
  int n = (ADDRXLAT_OPT_os_type) <= 0;
  *o = (unsigned long long)((ADDRXLAT_OPT_os_type) | 0);  /* check that ADDRXLAT_OPT_os_type is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_OPT_version_code(unsigned long long *o)
{
  int n = (ADDRXLAT_OPT_version_code) <= 0;
  *o = (unsigned long long)((ADDRXLAT_OPT_version_code) | 0);  /* check that ADDRXLAT_OPT_version_code is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_OPT_phys_bits(unsigned long long *o)
{
  int n = (ADDRXLAT_OPT_phys_bits) <= 0;
  *o = (unsigned long long)((ADDRXLAT_OPT_phys_bits) | 0);  /* check that ADDRXLAT_OPT_phys_bits is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_OPT_virt_bits(unsigned long long *o)
{
  int n = (ADDRXLAT_OPT_virt_bits) <= 0;
  *o = (unsigned long long)((ADDRXLAT_OPT_virt_bits) | 0);  /* check that ADDRXLAT_OPT_virt_bits is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_OPT_page_shift(unsigned long long *o)
{
  int n = (ADDRXLAT_OPT_page_shift) <= 0;
  *o = (unsigned long long)((ADDRXLAT_OPT_page_shift) | 0);  /* check that ADDRXLAT_OPT_page_shift is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_OPT_phys_base(unsigned long long *o)
{
  int n = (ADDRXLAT_OPT_phys_base) <= 0;
  *o = (unsigned long long)((ADDRXLAT_OPT_phys_base) | 0);  /* check that ADDRXLAT_OPT_phys_base is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_OPT_rootpgt(unsigned long long *o)
{
  int n = (ADDRXLAT_OPT_rootpgt) <= 0;
  *o = (unsigned long long)((ADDRXLAT_OPT_rootpgt) | 0);  /* check that ADDRXLAT_OPT_rootpgt is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_OPT_xen_p2m_mfn(unsigned long long *o)
{
  int n = (ADDRXLAT_OPT_xen_p2m_mfn) <= 0;
  *o = (unsigned long long)((ADDRXLAT_OPT_xen_p2m_mfn) | 0);  /* check that ADDRXLAT_OPT_xen_p2m_mfn is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_OPT_xen_xlat(unsigned long long *o)
{
  int n = (ADDRXLAT_OPT_xen_xlat) <= 0;
  *o = (unsigned long long)((ADDRXLAT_OPT_xen_xlat) | 0);  /* check that ADDRXLAT_OPT_xen_xlat is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_OPT_NUM(unsigned long long *o)
{
  int n = (ADDRXLAT_OPT_NUM) <= 0;
  *o = (unsigned long long)((ADDRXLAT_OPT_NUM) | 0);  /* check that ADDRXLAT_OPT_NUM is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_PTE_INVALID(unsigned long long *o)
{
  int n = (ADDRXLAT_PTE_INVALID) <= 0;
  *o = (unsigned long long)((ADDRXLAT_PTE_INVALID) | 0);  /* check that ADDRXLAT_PTE_INVALID is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_PTE_NONE(unsigned long long *o)
{
  int n = (ADDRXLAT_PTE_NONE) <= 0;
  *o = (unsigned long long)((ADDRXLAT_PTE_NONE) | 0);  /* check that ADDRXLAT_PTE_NONE is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_PTE_PFN32(unsigned long long *o)
{
  int n = (ADDRXLAT_PTE_PFN32) <= 0;
  *o = (unsigned long long)((ADDRXLAT_PTE_PFN32) | 0);  /* check that ADDRXLAT_PTE_PFN32 is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_PTE_PFN64(unsigned long long *o)
{
  int n = (ADDRXLAT_PTE_PFN64) <= 0;
  *o = (unsigned long long)((ADDRXLAT_PTE_PFN64) | 0);  /* check that ADDRXLAT_PTE_PFN64 is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_PTE_AARCH64(unsigned long long *o)
{
  int n = (ADDRXLAT_PTE_AARCH64) <= 0;
  *o = (unsigned long long)((ADDRXLAT_PTE_AARCH64) | 0);  /* check that ADDRXLAT_PTE_AARCH64 is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_PTE_IA32(unsigned long long *o)
{
  int n = (ADDRXLAT_PTE_IA32) <= 0;
  *o = (unsigned long long)((ADDRXLAT_PTE_IA32) | 0);  /* check that ADDRXLAT_PTE_IA32 is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_PTE_IA32_PAE(unsigned long long *o)
{
  int n = (ADDRXLAT_PTE_IA32_PAE) <= 0;
  *o = (unsigned long long)((ADDRXLAT_PTE_IA32_PAE) | 0);  /* check that ADDRXLAT_PTE_IA32_PAE is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_PTE_X86_64(unsigned long long *o)
{
  int n = (ADDRXLAT_PTE_X86_64) <= 0;
  *o = (unsigned long long)((ADDRXLAT_PTE_X86_64) | 0);  /* check that ADDRXLAT_PTE_X86_64 is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_PTE_S390X(unsigned long long *o)
{
  int n = (ADDRXLAT_PTE_S390X) <= 0;
  *o = (unsigned long long)((ADDRXLAT_PTE_S390X) | 0);  /* check that ADDRXLAT_PTE_S390X is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_PTE_PPC64_LINUX_RPN30(unsigned long long *o)
{
  int n = (ADDRXLAT_PTE_PPC64_LINUX_RPN30) <= 0;
  *o = (unsigned long long)((ADDRXLAT_PTE_PPC64_LINUX_RPN30) | 0);  /* check that ADDRXLAT_PTE_PPC64_LINUX_RPN30 is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_PTE_AARCH64_LPA(unsigned long long *o)
{
  int n = (ADDRXLAT_PTE_AARCH64_LPA) <= 0;
  *o = (unsigned long long)((ADDRXLAT_PTE_AARCH64_LPA) | 0);  /* check that ADDRXLAT_PTE_AARCH64_LPA is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_PTE_AARCH64_LPA2(unsigned long long *o)
{
  int n = (ADDRXLAT_PTE_AARCH64_LPA2) <= 0;
  *o = (unsigned long long)((ADDRXLAT_PTE_AARCH64_LPA2) | 0);  /* check that ADDRXLAT_PTE_AARCH64_LPA2 is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_PTE_ARM(unsigned long long *o)
{
  int n = (ADDRXLAT_PTE_ARM) <= 0;
  *o = (unsigned long long)((ADDRXLAT_PTE_ARM) | 0);  /* check that ADDRXLAT_PTE_ARM is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_PTE_RISCV32(unsigned long long *o)
{
  int n = (ADDRXLAT_PTE_RISCV32) <= 0;
  *o = (unsigned long long)((ADDRXLAT_PTE_RISCV32) | 0);  /* check that ADDRXLAT_PTE_RISCV32 is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_PTE_RISCV64(unsigned long long *o)
{
  int n = (ADDRXLAT_PTE_RISCV64) <= 0;
  *o = (unsigned long long)((ADDRXLAT_PTE_RISCV64) | 0);  /* check that ADDRXLAT_PTE_RISCV64 is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_OK(unsigned long long *o)
{
  int n = (ADDRXLAT_OK) <= 0;
  *o = (unsigned long long)((ADDRXLAT_OK) | 0);  /* check that ADDRXLAT_OK is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_ERR_NOTIMPL(unsigned long long *o)
{
  int n = (ADDRXLAT_ERR_NOTIMPL) <= 0;
  *o = (unsigned long long)((ADDRXLAT_ERR_NOTIMPL) | 0);  /* check that ADDRXLAT_ERR_NOTIMPL is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_ERR_NOTPRESENT(unsigned long long *o)
{
  int n = (ADDRXLAT_ERR_NOTPRESENT) <= 0;
  *o = (unsigned long long)((ADDRXLAT_ERR_NOTPRESENT) | 0);  /* check that ADDRXLAT_ERR_NOTPRESENT is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_ERR_INVALID(unsigned long long *o)
{
  int n = (ADDRXLAT_ERR_INVALID) <= 0;
  *o = (unsigned long long)((ADDRXLAT_ERR_INVALID) | 0);  /* check that ADDRXLAT_ERR_INVALID is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_ERR_NOMEM(unsigned long long *o)
{
  int n = (ADDRXLAT_ERR_NOMEM) <= 0;
  *o = (unsigned long long)((ADDRXLAT_ERR_NOMEM) | 0);  /* check that ADDRXLAT_ERR_NOMEM is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_ERR_NODATA(unsigned long long *o)
{
  int n = (ADDRXLAT_ERR_NODATA) <= 0;
  *o = (unsigned long long)((ADDRXLAT_ERR_NODATA) | 0);  /* check that ADDRXLAT_ERR_NODATA is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_ERR_NOMETH(unsigned long long *o)
{
  int n = (ADDRXLAT_ERR_NOMETH) <= 0;
  *o = (unsigned long long)((ADDRXLAT_ERR_NOMETH) | 0);  /* check that ADDRXLAT_ERR_NOMETH is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_ERR_CUSTOM_BASE(unsigned long long *o)
{
  int n = (ADDRXLAT_ERR_CUSTOM_BASE) <= 0;
  *o = (unsigned long long)((ADDRXLAT_ERR_CUSTOM_BASE) | 0);  /* check that ADDRXLAT_ERR_CUSTOM_BASE is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_SYS_MAP_HW(unsigned long long *o)
{
  int n = (ADDRXLAT_SYS_MAP_HW) <= 0;
  *o = (unsigned long long)((ADDRXLAT_SYS_MAP_HW) | 0);  /* check that ADDRXLAT_SYS_MAP_HW is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_SYS_MAP_KV_PHYS(unsigned long long *o)
{
  int n = (ADDRXLAT_SYS_MAP_KV_PHYS) <= 0;
  *o = (unsigned long long)((ADDRXLAT_SYS_MAP_KV_PHYS) | 0);  /* check that ADDRXLAT_SYS_MAP_KV_PHYS is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_SYS_MAP_KPHYS_DIRECT(unsigned long long *o)
{
  int n = (ADDRXLAT_SYS_MAP_KPHYS_DIRECT) <= 0;
  *o = (unsigned long long)((ADDRXLAT_SYS_MAP_KPHYS_DIRECT) | 0);  /* check that ADDRXLAT_SYS_MAP_KPHYS_DIRECT is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_SYS_MAP_MACHPHYS_KPHYS(unsigned long long *o)
{
  int n = (ADDRXLAT_SYS_MAP_MACHPHYS_KPHYS) <= 0;
  *o = (unsigned long long)((ADDRXLAT_SYS_MAP_MACHPHYS_KPHYS) | 0);  /* check that ADDRXLAT_SYS_MAP_MACHPHYS_KPHYS is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_SYS_MAP_KPHYS_MACHPHYS(unsigned long long *o)
{
  int n = (ADDRXLAT_SYS_MAP_KPHYS_MACHPHYS) <= 0;
  *o = (unsigned long long)((ADDRXLAT_SYS_MAP_KPHYS_MACHPHYS) | 0);  /* check that ADDRXLAT_SYS_MAP_KPHYS_MACHPHYS is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_SYS_MAP_NUM(unsigned long long *o)
{
  int n = (ADDRXLAT_SYS_MAP_NUM) <= 0;
  *o = (unsigned long long)((ADDRXLAT_SYS_MAP_NUM) | 0);  /* check that ADDRXLAT_SYS_MAP_NUM is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_SYS_METH_NONE(unsigned long long *o)
{
  int n = (ADDRXLAT_SYS_METH_NONE) <= 0;
  *o = (unsigned long long)((ADDRXLAT_SYS_METH_NONE) | 0);  /* check that ADDRXLAT_SYS_METH_NONE is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_SYS_METH_PGT(unsigned long long *o)
{
  int n = (ADDRXLAT_SYS_METH_PGT) <= 0;
  *o = (unsigned long long)((ADDRXLAT_SYS_METH_PGT) | 0);  /* check that ADDRXLAT_SYS_METH_PGT is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_SYS_METH_UPGT(unsigned long long *o)
{
  int n = (ADDRXLAT_SYS_METH_UPGT) <= 0;
  *o = (unsigned long long)((ADDRXLAT_SYS_METH_UPGT) | 0);  /* check that ADDRXLAT_SYS_METH_UPGT is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_SYS_METH_DIRECT(unsigned long long *o)
{
  int n = (ADDRXLAT_SYS_METH_DIRECT) <= 0;
  *o = (unsigned long long)((ADDRXLAT_SYS_METH_DIRECT) | 0);  /* check that ADDRXLAT_SYS_METH_DIRECT is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_SYS_METH_KTEXT(unsigned long long *o)
{
  int n = (ADDRXLAT_SYS_METH_KTEXT) <= 0;
  *o = (unsigned long long)((ADDRXLAT_SYS_METH_KTEXT) | 0);  /* check that ADDRXLAT_SYS_METH_KTEXT is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_SYS_METH_VMEMMAP(unsigned long long *o)
{
  int n = (ADDRXLAT_SYS_METH_VMEMMAP) <= 0;
  *o = (unsigned long long)((ADDRXLAT_SYS_METH_VMEMMAP) | 0);  /* check that ADDRXLAT_SYS_METH_VMEMMAP is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_SYS_METH_RDIRECT(unsigned long long *o)
{
  int n = (ADDRXLAT_SYS_METH_RDIRECT) <= 0;
  *o = (unsigned long long)((ADDRXLAT_SYS_METH_RDIRECT) | 0);  /* check that ADDRXLAT_SYS_METH_RDIRECT is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_SYS_METH_MACHPHYS_KPHYS(unsigned long long *o)
{
  int n = (ADDRXLAT_SYS_METH_MACHPHYS_KPHYS) <= 0;
  *o = (unsigned long long)((ADDRXLAT_SYS_METH_MACHPHYS_KPHYS) | 0);  /* check that ADDRXLAT_SYS_METH_MACHPHYS_KPHYS is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_SYS_METH_KPHYS_MACHPHYS(unsigned long long *o)
{
  int n = (ADDRXLAT_SYS_METH_KPHYS_MACHPHYS) <= 0;
  *o = (unsigned long long)((ADDRXLAT_SYS_METH_KPHYS_MACHPHYS) | 0);  /* check that ADDRXLAT_SYS_METH_KPHYS_MACHPHYS is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_SYS_METH_CUSTOM(unsigned long long *o)
{
  int n = (ADDRXLAT_SYS_METH_CUSTOM) <= 0;
  *o = (unsigned long long)((ADDRXLAT_SYS_METH_CUSTOM) | 0);  /* check that ADDRXLAT_SYS_METH_CUSTOM is an integer */
  return n;
}

static struct _cffi_externpy_s _cffi_externpy___cb_first_step =
  { "_addrxlat._cb_first_step", (int)sizeof(addrxlat_status), 0, 0 };

static addrxlat_status _cb_first_step(addrxlat_step_t * a0, uint_fast64_t a1)
{
  char a[16];
  char *p = a;
  *(addrxlat_step_t * *)(p + 0) = a0;
  *(uint_fast64_t *)(p + 8) = a1;
  _cffi_call_python(&_cffi_externpy___cb_first_step, p);
  return *(addrxlat_status *)p;
}

static struct _cffi_externpy_s _cffi_externpy___cb_get_page =
  { "_addrxlat._cb_get_page", (int)sizeof(addrxlat_status), 0, 0 };

static addrxlat_status _cb_get_page(addrxlat_cb_t const * a0, addrxlat_buffer_t * a1)
{
  char a[16];
  char *p = a;
  *(addrxlat_cb_t const * *)(p + 0) = a0;
  *(addrxlat_buffer_t * *)(p + 8) = a1;
  _cffi_call_python(&_cffi_externpy___cb_get_page, p);
  return *(addrxlat_status *)p;
}

static struct _cffi_externpy_s _cffi_externpy___cb_next_step =
  { "_addrxlat._cb_next_step", (int)sizeof(addrxlat_status), 0, 0 };

static addrxlat_status _cb_next_step(addrxlat_step_t * a0)
{
  char a[8];
  char *p = a;
  *(addrxlat_step_t * *)(p + 0) = a0;
  _cffi_call_python(&_cffi_externpy___cb_next_step, p);
  return *(addrxlat_status *)p;
}

static struct _cffi_externpy_s _cffi_externpy___cb_num_value =
  { "_addrxlat._cb_num_value", (int)sizeof(addrxlat_status), 0, 0 };

static addrxlat_status _cb_num_value(addrxlat_cb_t const * a0, char const * a1, uint_fast64_t * a2)
{
  char a[24];
  char *p = a;
  *(addrxlat_cb_t const * *)(p + 0) = a0;
  *(char const * *)(p + 8) = a1;
  *(uint_fast64_t * *)(p + 16) = a2;
  _cffi_call_python(&_cffi_externpy___cb_num_value, p);
  return *(addrxlat_status *)p;
}

static struct _cffi_externpy_s _cffi_externpy___cb_op =
  { "_addrxlat._cb_op", (int)sizeof(addrxlat_status), 0, 0 };

static addrxlat_status _cb_op(void * a0, addrxlat_fulladdr_t const * a1)
{
  char a[16];
  char *p = a;
  *(void * *)(p + 0) = a0;
  *(addrxlat_fulladdr_t const * *)(p + 8) = a1;
  _cffi_call_python(&_cffi_externpy___cb_op, p);
  return *(addrxlat_status *)p;
}

static struct _cffi_externpy_s _cffi_externpy___cb_put_page =
  { "_addrxlat._cb_put_page", 0, 0, 0 };

static void _cb_put_page(addrxlat_buffer_t const * a0)
{
  char a[8];
  char *p = a;
  *(addrxlat_buffer_t const * *)(p + 0) = a0;
  _cffi_call_python(&_cffi_externpy___cb_put_page, p);
}

static struct _cffi_externpy_s _cffi_externpy___cb_read_caps =
  { "_addrxlat._cb_read_caps", (int)sizeof(unsigned long), 0, 0 };

static unsigned long _cb_read_caps(addrxlat_cb_t const * a0)
{
  char a[8];
  char *p = a;
  *(addrxlat_cb_t const * *)(p + 0) = a0;
  _cffi_call_python(&_cffi_externpy___cb_read_caps, p);
  return *(unsigned long *)p;
}

static struct _cffi_externpy_s _cffi_externpy___cb_reg_value =
  { "_addrxlat._cb_reg_value", (int)sizeof(addrxlat_status), 0, 0 };

static addrxlat_status _cb_reg_value(addrxlat_cb_t const * a0, char const * a1, uint_fast64_t * a2)
{
  char a[24];
  char *p = a;
  *(addrxlat_cb_t const * *)(p + 0) = a0;
  *(char const * *)(p + 8) = a1;
  *(uint_fast64_t * *)(p + 16) = a2;
  _cffi_call_python(&_cffi_externpy___cb_reg_value, p);
  return *(addrxlat_status *)p;
}

static struct _cffi_externpy_s _cffi_externpy___cb_sym_offsetof =
  { "_addrxlat._cb_sym_offsetof", (int)sizeof(addrxlat_status), 0, 0 };

static addrxlat_status _cb_sym_offsetof(addrxlat_cb_t const * a0, char const * a1, char const * a2, uint_fast64_t * a3)
{
  char a[32];
  char *p = a;
  *(addrxlat_cb_t const * *)(p + 0) = a0;
  *(char const * *)(p + 8) = a1;
  *(char const * *)(p + 16) = a2;
  *(uint_fast64_t * *)(p + 24) = a3;
  _cffi_call_python(&_cffi_externpy___cb_sym_offsetof, p);
  return *(addrxlat_status *)p;
}

static struct _cffi_externpy_s _cffi_externpy___cb_sym_sizeof =
  { "_addrxlat._cb_sym_sizeof", (int)sizeof(addrxlat_status), 0, 0 };

static addrxlat_status _cb_sym_sizeof(addrxlat_cb_t const * a0, char const * a1, uint_fast64_t * a2)
{
  char a[24];
  char *p = a;
  *(addrxlat_cb_t const * *)(p + 0) = a0;
  *(char const * *)(p + 8) = a1;
  *(uint_fast64_t * *)(p + 16) = a2;
  _cffi_call_python(&_cffi_externpy___cb_sym_sizeof, p);
  return *(addrxlat_status *)p;
}

static struct _cffi_externpy_s _cffi_externpy___cb_sym_value =
  { "_addrxlat._cb_sym_value", (int)sizeof(addrxlat_status), 0, 0 };

static addrxlat_status _cb_sym_value(addrxlat_cb_t const * a0, char const * a1, uint_fast64_t * a2)
{
  char a[24];
  char *p = a;
  *(addrxlat_cb_t const * *)(p + 0) = a0;
  *(char const * *)(p + 8) = a1;
  *(uint_fast64_t * *)(p + 16) = a2;
  _cffi_call_python(&_cffi_externpy___cb_sym_value, p);
  return *(addrxlat_status *)p;
}

static unsigned long _cffi_d_ADDRXLAT_CAPS(unsigned int x0)
{
  return ADDRXLAT_CAPS(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_ADDRXLAT_CAPS(PyObject *self, PyObject *arg0)
{
  unsigned int x0;
  unsigned long result;
  PyObject *pyresult;

  x0 = _cffi_to_c_int(arg0, unsigned int);
  if (x0 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = ADDRXLAT_CAPS(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned long);
  return pyresult;
}
#else
#  define _cffi_f_ADDRXLAT_CAPS _cffi_d_ADDRXLAT_CAPS
#endif

static unsigned long _cffi_d_ADDRXLAT_VER_LINUX(unsigned int x0, unsigned int x1, unsigned int x2)
{
  return ADDRXLAT_VER_LINUX(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_ADDRXLAT_VER_LINUX(PyObject *self, PyObject *args)
{
  unsigned int x0;
  unsigned int x1;
  unsigned int x2;
  unsigned long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "ADDRXLAT_VER_LINUX", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned int);
  if (x0 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned int);
  if (x1 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned int);
  if (x2 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = ADDRXLAT_VER_LINUX(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned long);
  return pyresult;
}
#else
#  define _cffi_f_ADDRXLAT_VER_LINUX _cffi_d_ADDRXLAT_VER_LINUX
#endif

static unsigned long _cffi_d_ADDRXLAT_VER_XEN(unsigned int x0, unsigned int x1)
{
  return ADDRXLAT_VER_XEN(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_ADDRXLAT_VER_XEN(PyObject *self, PyObject *args)
{
  unsigned int x0;
  unsigned int x1;
  unsigned long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "ADDRXLAT_VER_XEN", 2, 2, &arg0, &arg1))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned int);
  if (x0 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned int);
  if (x1 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = ADDRXLAT_VER_XEN(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned long);
  return pyresult;
}
#else
#  define _cffi_f_ADDRXLAT_VER_XEN _cffi_d_ADDRXLAT_VER_XEN
#endif

static char const * _cffi_d_addrxlat_addrspace_name(addrxlat_addrspace_t x0)
{
  return addrxlat_addrspace_name(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_addrspace_name(PyObject *self, PyObject *arg0)
{
  addrxlat_addrspace_t x0;
  char const * result;
  PyObject *pyresult;

  if (_cffi_to_c((char *)&x0, _cffi_type(49), arg0) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_addrspace_name(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(22));
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_addrspace_name _cffi_d_addrxlat_addrspace_name
#endif

static addrxlat_cb_t * _cffi_d_addrxlat_ctx_add_cb(addrxlat_ctx_t * x0)
{
  return addrxlat_ctx_add_cb(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_ctx_add_cb(PyObject *self, PyObject *arg0)
{
  addrxlat_ctx_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  addrxlat_cb_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_ctx_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_ctx_add_cb(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(138));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_ctx_add_cb _cffi_d_addrxlat_ctx_add_cb
#endif

static void _cffi_d_addrxlat_ctx_clear_err(addrxlat_ctx_t * x0)
{
  addrxlat_ctx_clear_err(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_ctx_clear_err(PyObject *self, PyObject *arg0)
{
  addrxlat_ctx_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_ctx_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { addrxlat_ctx_clear_err(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_addrxlat_ctx_clear_err _cffi_d_addrxlat_ctx_clear_err
#endif

static unsigned long _cffi_d_addrxlat_ctx_decref(addrxlat_ctx_t * x0)
{
  return addrxlat_ctx_decref(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_ctx_decref(PyObject *self, PyObject *arg0)
{
  addrxlat_ctx_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned long result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_ctx_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_ctx_decref(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_ctx_decref _cffi_d_addrxlat_ctx_decref
#endif

static void _cffi_d_addrxlat_ctx_del_cb(addrxlat_ctx_t * x0, addrxlat_cb_t * x1)
{
  addrxlat_ctx_del_cb(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_ctx_del_cb(PyObject *self, PyObject *args)
{
  addrxlat_ctx_t * x0;
  addrxlat_cb_t * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "addrxlat_ctx_del_cb", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_ctx_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(138), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (addrxlat_cb_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(138), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { addrxlat_ctx_del_cb(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_addrxlat_ctx_del_cb _cffi_d_addrxlat_ctx_del_cb
#endif

static void _cffi_const_addrxlat_ctx_err(char *o)
{
  *(addrxlat_status(* *)(addrxlat_ctx_t *, addrxlat_status, char const *, ...))o = addrxlat_ctx_err;
}

static addrxlat_cb_t const * _cffi_d_addrxlat_ctx_get_cb(addrxlat_ctx_t const * x0)
{
  return addrxlat_ctx_get_cb(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_ctx_get_cb(PyObject *self, PyObject *arg0)
{
  addrxlat_ctx_t const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  addrxlat_cb_t const * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(4), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_ctx_t const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(4), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_ctx_get_cb(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(28));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_ctx_get_cb _cffi_d_addrxlat_ctx_get_cb
#endif

static char const * _cffi_d_addrxlat_ctx_get_err(addrxlat_ctx_t const * x0)
{
  return addrxlat_ctx_get_err(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_ctx_get_err(PyObject *self, PyObject *arg0)
{
  addrxlat_ctx_t const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  char const * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(4), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_ctx_t const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(4), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_ctx_get_err(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(22));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_ctx_get_err _cffi_d_addrxlat_ctx_get_err
#endif

static unsigned long _cffi_d_addrxlat_ctx_incref(addrxlat_ctx_t * x0)
{
  return addrxlat_ctx_incref(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_ctx_incref(PyObject *self, PyObject *arg0)
{
  addrxlat_ctx_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned long result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_ctx_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_ctx_incref(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_ctx_incref _cffi_d_addrxlat_ctx_incref
#endif

static addrxlat_ctx_t * _cffi_d_addrxlat_ctx_new(void)
{
  return addrxlat_ctx_new();
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_ctx_new(PyObject *self, PyObject *noarg)
{
  addrxlat_ctx_t * result;
  PyObject *pyresult;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_ctx_new(); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  (void)noarg; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(1));
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_ctx_new _cffi_d_addrxlat_ctx_new
#endif

static addrxlat_status _cffi_d_addrxlat_fulladdr_conv(addrxlat_fulladdr_t * x0, addrxlat_addrspace_t x1, addrxlat_ctx_t * x2, addrxlat_sys_t * x3)
{
  return addrxlat_fulladdr_conv(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_fulladdr_conv(PyObject *self, PyObject *args)
{
  addrxlat_fulladdr_t * x0;
  addrxlat_addrspace_t x1;
  addrxlat_ctx_t * x2;
  addrxlat_sys_t * x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  addrxlat_status result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "addrxlat_fulladdr_conv", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(48), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_fulladdr_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(48), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(49), arg1) < 0)
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (addrxlat_ctx_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(51), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (addrxlat_sys_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(51), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_fulladdr_conv(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(44));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_fulladdr_conv _cffi_d_addrxlat_fulladdr_conv
#endif

static addrxlat_status _cffi_d_addrxlat_launch(addrxlat_step_t * x0, uint_fast64_t x1)
{
  return addrxlat_launch(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_launch(PyObject *self, PyObject *args)
{
  addrxlat_step_t * x0;
  uint_fast64_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  addrxlat_status result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "addrxlat_launch", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(63), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_step_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(63), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, uint_fast64_t);
  if (x1 == (uint_fast64_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_launch(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(44));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_launch _cffi_d_addrxlat_launch
#endif

static addrxlat_map_t * _cffi_d_addrxlat_map_copy(addrxlat_map_t const * x0)
{
  return addrxlat_map_copy(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_map_copy(PyObject *self, PyObject *arg0)
{
  addrxlat_map_t const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  addrxlat_map_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(9), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_map_t const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(9), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_map_copy(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(54));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_map_copy _cffi_d_addrxlat_map_copy
#endif

static unsigned long _cffi_d_addrxlat_map_decref(addrxlat_map_t * x0)
{
  return addrxlat_map_decref(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_map_decref(PyObject *self, PyObject *arg0)
{
  addrxlat_map_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned long result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(54), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_map_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(54), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_map_decref(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_map_decref _cffi_d_addrxlat_map_decref
#endif

static unsigned long _cffi_d_addrxlat_map_incref(addrxlat_map_t * x0)
{
  return addrxlat_map_incref(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_map_incref(PyObject *self, PyObject *arg0)
{
  addrxlat_map_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned long result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(54), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_map_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(54), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_map_incref(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_map_incref _cffi_d_addrxlat_map_incref
#endif

static size_t _cffi_d_addrxlat_map_len(addrxlat_map_t const * x0)
{
  return addrxlat_map_len(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_map_len(PyObject *self, PyObject *arg0)
{
  addrxlat_map_t const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  size_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(9), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_map_t const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(9), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_map_len(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, size_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_map_len _cffi_d_addrxlat_map_len
#endif

static addrxlat_map_t * _cffi_d_addrxlat_map_new(void)
{
  return addrxlat_map_new();
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_map_new(PyObject *self, PyObject *noarg)
{
  addrxlat_map_t * result;
  PyObject *pyresult;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_map_new(); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  (void)noarg; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(54));
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_map_new _cffi_d_addrxlat_map_new
#endif

static addrxlat_range_t const * _cffi_d_addrxlat_map_ranges(addrxlat_map_t const * x0)
{
  return addrxlat_map_ranges(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_map_ranges(PyObject *self, PyObject *arg0)
{
  addrxlat_map_t const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  addrxlat_range_t const * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(9), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_map_t const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(9), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_map_ranges(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(56));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_map_ranges _cffi_d_addrxlat_map_ranges
#endif

static addrxlat_sys_meth_t _cffi_d_addrxlat_map_search(addrxlat_map_t const * x0, uint_fast64_t x1)
{
  return addrxlat_map_search(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_map_search(PyObject *self, PyObject *args)
{
  addrxlat_map_t const * x0;
  uint_fast64_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  addrxlat_sys_meth_t result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "addrxlat_map_search", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(9), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_map_t const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(9), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, uint_fast64_t);
  if (x1 == (uint_fast64_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_map_search(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(19));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_map_search _cffi_d_addrxlat_map_search
#endif

static addrxlat_status _cffi_d_addrxlat_map_set(addrxlat_map_t * x0, uint_fast64_t x1, addrxlat_range_t const * x2)
{
  return addrxlat_map_set(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_map_set(PyObject *self, PyObject *args)
{
  addrxlat_map_t * x0;
  uint_fast64_t x1;
  addrxlat_range_t const * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  addrxlat_status result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "addrxlat_map_set", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(54), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_map_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(54), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, uint_fast64_t);
  if (x1 == (uint_fast64_t)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(56), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (addrxlat_range_t const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(56), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_map_set(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(44));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_map_set _cffi_d_addrxlat_map_set
#endif

static addrxlat_status _cffi_d_addrxlat_op(addrxlat_op_ctl_t const * x0, addrxlat_fulladdr_t const * x1)
{
  return addrxlat_op(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_op(PyObject *self, PyObject *args)
{
  addrxlat_op_ctl_t const * x0;
  addrxlat_fulladdr_t const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  addrxlat_status result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "addrxlat_op", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(59), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_op_ctl_t const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(59), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(60), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (addrxlat_fulladdr_t const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(60), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_op(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(44));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_op _cffi_d_addrxlat_op
#endif

static void _cffi_d_addrxlat_opt_arch(addrxlat_opt_t * x0, char const * x1)
{
  addrxlat_opt_arch(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_opt_arch(PyObject *self, PyObject *args)
{
  addrxlat_opt_t * x0;
  char const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "addrxlat_opt_arch", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(141), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_opt_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(141), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(22), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(22), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { addrxlat_opt_arch(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_addrxlat_opt_arch _cffi_d_addrxlat_opt_arch
#endif

static void _cffi_d_addrxlat_opt_os_type(addrxlat_opt_t * x0, char const * x1)
{
  addrxlat_opt_os_type(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_opt_os_type(PyObject *self, PyObject *args)
{
  addrxlat_opt_t * x0;
  char const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "addrxlat_opt_os_type", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(141), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_opt_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(141), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(22), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(22), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { addrxlat_opt_os_type(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_addrxlat_opt_os_type _cffi_d_addrxlat_opt_os_type
#endif

static void _cffi_d_addrxlat_opt_page_shift(addrxlat_opt_t * x0, unsigned long x1)
{
  addrxlat_opt_page_shift(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_opt_page_shift(PyObject *self, PyObject *args)
{
  addrxlat_opt_t * x0;
  unsigned long x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "addrxlat_opt_page_shift", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(141), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_opt_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(141), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, unsigned long);
  if (x1 == (unsigned long)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { addrxlat_opt_page_shift(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_addrxlat_opt_page_shift _cffi_d_addrxlat_opt_page_shift
#endif

static void _cffi_d_addrxlat_opt_phys_base(addrxlat_opt_t * x0, uint_fast64_t x1)
{
  addrxlat_opt_phys_base(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_opt_phys_base(PyObject *self, PyObject *args)
{
  addrxlat_opt_t * x0;
  uint_fast64_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "addrxlat_opt_phys_base", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(141), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_opt_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(141), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, uint_fast64_t);
  if (x1 == (uint_fast64_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { addrxlat_opt_phys_base(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_addrxlat_opt_phys_base _cffi_d_addrxlat_opt_phys_base
#endif

static void _cffi_d_addrxlat_opt_phys_bits(addrxlat_opt_t * x0, unsigned long x1)
{
  addrxlat_opt_phys_bits(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_opt_phys_bits(PyObject *self, PyObject *args)
{
  addrxlat_opt_t * x0;
  unsigned long x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "addrxlat_opt_phys_bits", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(141), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_opt_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(141), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, unsigned long);
  if (x1 == (unsigned long)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { addrxlat_opt_phys_bits(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_addrxlat_opt_phys_bits _cffi_d_addrxlat_opt_phys_bits
#endif

static void _cffi_d_addrxlat_opt_rootpgt(addrxlat_opt_t * x0, addrxlat_fulladdr_t const * x1)
{
  addrxlat_opt_rootpgt(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_opt_rootpgt(PyObject *self, PyObject *args)
{
  addrxlat_opt_t * x0;
  addrxlat_fulladdr_t const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "addrxlat_opt_rootpgt", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(141), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_opt_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(141), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(60), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (addrxlat_fulladdr_t const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(60), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { addrxlat_opt_rootpgt(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_addrxlat_opt_rootpgt _cffi_d_addrxlat_opt_rootpgt
#endif

static void _cffi_d_addrxlat_opt_version_code(addrxlat_opt_t * x0, unsigned long x1)
{
  addrxlat_opt_version_code(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_opt_version_code(PyObject *self, PyObject *args)
{
  addrxlat_opt_t * x0;
  unsigned long x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "addrxlat_opt_version_code", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(141), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_opt_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(141), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, unsigned long);
  if (x1 == (unsigned long)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { addrxlat_opt_version_code(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_addrxlat_opt_version_code _cffi_d_addrxlat_opt_version_code
#endif

static void _cffi_d_addrxlat_opt_virt_bits(addrxlat_opt_t * x0, unsigned long x1)
{
  addrxlat_opt_virt_bits(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_opt_virt_bits(PyObject *self, PyObject *args)
{
  addrxlat_opt_t * x0;
  unsigned long x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "addrxlat_opt_virt_bits", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(141), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_opt_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(141), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, unsigned long);
  if (x1 == (unsigned long)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { addrxlat_opt_virt_bits(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_addrxlat_opt_virt_bits _cffi_d_addrxlat_opt_virt_bits
#endif

static void _cffi_d_addrxlat_opt_xen_p2m_mfn(addrxlat_opt_t * x0, unsigned long x1)
{
  addrxlat_opt_xen_p2m_mfn(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_opt_xen_p2m_mfn(PyObject *self, PyObject *args)
{
  addrxlat_opt_t * x0;
  unsigned long x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "addrxlat_opt_xen_p2m_mfn", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(141), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_opt_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(141), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, unsigned long);
  if (x1 == (unsigned long)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { addrxlat_opt_xen_p2m_mfn(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_addrxlat_opt_xen_p2m_mfn _cffi_d_addrxlat_opt_xen_p2m_mfn
#endif

static void _cffi_d_addrxlat_opt_xen_xlat(addrxlat_opt_t * x0, unsigned long x1)
{
  addrxlat_opt_xen_xlat(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_opt_xen_xlat(PyObject *self, PyObject *args)
{
  addrxlat_opt_t * x0;
  unsigned long x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "addrxlat_opt_xen_xlat", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(141), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_opt_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(141), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, unsigned long);
  if (x1 == (unsigned long)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { addrxlat_opt_xen_xlat(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_addrxlat_opt_xen_xlat _cffi_d_addrxlat_opt_xen_xlat
#endif

static addrxlat_pte_format_t _cffi_d_addrxlat_pte_format(char const * x0)
{
  return addrxlat_pte_format(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_pte_format(PyObject *self, PyObject *arg0)
{
  char const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  addrxlat_pte_format_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(22), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(22), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_pte_format(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(92));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_pte_format _cffi_d_addrxlat_pte_format
#endif

static char const * _cffi_d_addrxlat_pte_format_name(addrxlat_pte_format_t x0)
{
  return addrxlat_pte_format_name(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_pte_format_name(PyObject *self, PyObject *arg0)
{
  addrxlat_pte_format_t x0;
  char const * result;
  PyObject *pyresult;

  if (_cffi_to_c((char *)&x0, _cffi_type(92), arg0) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_pte_format_name(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(22));
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_pte_format_name _cffi_d_addrxlat_pte_format_name
#endif

static int _cffi_d_addrxlat_pteval_shift(addrxlat_pte_format_t x0)
{
  return addrxlat_pteval_shift(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_pteval_shift(PyObject *self, PyObject *arg0)
{
  addrxlat_pte_format_t x0;
  int result;
  PyObject *pyresult;

  if (_cffi_to_c((char *)&x0, _cffi_type(92), arg0) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_pteval_shift(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_pteval_shift _cffi_d_addrxlat_pteval_shift
#endif

static addrxlat_status _cffi_d_addrxlat_step(addrxlat_step_t * x0)
{
  return addrxlat_step(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_step(PyObject *self, PyObject *arg0)
{
  addrxlat_step_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  addrxlat_status result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(63), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_step_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(63), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_step(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(44));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_step _cffi_d_addrxlat_step
#endif

static char const * _cffi_d_addrxlat_strerror(addrxlat_status x0)
{
  return addrxlat_strerror(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_strerror(PyObject *self, PyObject *arg0)
{
  addrxlat_status x0;
  char const * result;
  PyObject *pyresult;

  if (_cffi_to_c((char *)&x0, _cffi_type(44), arg0) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_strerror(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(22));
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_strerror _cffi_d_addrxlat_strerror
#endif

static unsigned long _cffi_d_addrxlat_sys_decref(addrxlat_sys_t * x0)
{
  return addrxlat_sys_decref(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_sys_decref(PyObject *self, PyObject *arg0)
{
  addrxlat_sys_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned long result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(51), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_sys_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(51), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_sys_decref(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_sys_decref _cffi_d_addrxlat_sys_decref
#endif

static addrxlat_map_t * _cffi_d_addrxlat_sys_get_map(addrxlat_sys_t const * x0, addrxlat_sys_map_t x1)
{
  return addrxlat_sys_get_map(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_sys_get_map(PyObject *self, PyObject *args)
{
  addrxlat_sys_t const * x0;
  addrxlat_sys_map_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  addrxlat_map_t * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "addrxlat_sys_get_map", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(12), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_sys_t const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(12), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(13), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_sys_get_map(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(54));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_sys_get_map _cffi_d_addrxlat_sys_get_map
#endif

static addrxlat_meth_t const * _cffi_d_addrxlat_sys_get_meth(addrxlat_sys_t const * x0, addrxlat_sys_meth_t x1)
{
  return addrxlat_sys_get_meth(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_sys_get_meth(PyObject *self, PyObject *args)
{
  addrxlat_sys_t const * x0;
  addrxlat_sys_meth_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  addrxlat_meth_t const * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "addrxlat_sys_get_meth", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(12), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_sys_t const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(12), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(19), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_sys_get_meth(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(164));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_sys_get_meth _cffi_d_addrxlat_sys_get_meth
#endif

static unsigned long _cffi_d_addrxlat_sys_incref(addrxlat_sys_t * x0)
{
  return addrxlat_sys_incref(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_sys_incref(PyObject *self, PyObject *arg0)
{
  addrxlat_sys_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned long result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(51), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_sys_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(51), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_sys_incref(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_sys_incref _cffi_d_addrxlat_sys_incref
#endif

static addrxlat_sys_t * _cffi_d_addrxlat_sys_new(void)
{
  return addrxlat_sys_new();
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_sys_new(PyObject *self, PyObject *noarg)
{
  addrxlat_sys_t * result;
  PyObject *pyresult;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_sys_new(); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  (void)noarg; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(51));
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_sys_new _cffi_d_addrxlat_sys_new
#endif

static addrxlat_status _cffi_d_addrxlat_sys_os_init(addrxlat_sys_t * x0, addrxlat_ctx_t * x1, unsigned int x2, addrxlat_opt_t const * x3)
{
  return addrxlat_sys_os_init(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_sys_os_init(PyObject *self, PyObject *args)
{
  addrxlat_sys_t * x0;
  addrxlat_ctx_t * x1;
  unsigned int x2;
  addrxlat_opt_t const * x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  addrxlat_status result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "addrxlat_sys_os_init", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(51), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_sys_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(51), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (addrxlat_ctx_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x2 = _cffi_to_c_int(arg2, unsigned int);
  if (x2 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(73), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (addrxlat_opt_t const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(73), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_sys_os_init(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(44));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_sys_os_init _cffi_d_addrxlat_sys_os_init
#endif

static void _cffi_d_addrxlat_sys_set_map(addrxlat_sys_t * x0, addrxlat_sys_map_t x1, addrxlat_map_t * x2)
{
  addrxlat_sys_set_map(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_sys_set_map(PyObject *self, PyObject *args)
{
  addrxlat_sys_t * x0;
  addrxlat_sys_map_t x1;
  addrxlat_map_t * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "addrxlat_sys_set_map", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(51), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_sys_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(51), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(13), arg1) < 0)
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(54), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (addrxlat_map_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(54), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { addrxlat_sys_set_map(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_addrxlat_sys_set_map _cffi_d_addrxlat_sys_set_map
#endif

static void _cffi_d_addrxlat_sys_set_meth(addrxlat_sys_t * x0, addrxlat_sys_meth_t x1, addrxlat_meth_t const * x2)
{
  addrxlat_sys_set_meth(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_sys_set_meth(PyObject *self, PyObject *args)
{
  addrxlat_sys_t * x0;
  addrxlat_sys_meth_t x1;
  addrxlat_meth_t const * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "addrxlat_sys_set_meth", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(51), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_sys_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(51), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(19), arg1) < 0)
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(164), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (addrxlat_meth_t const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(164), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { addrxlat_sys_set_meth(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_addrxlat_sys_set_meth _cffi_d_addrxlat_sys_set_meth
#endif

static addrxlat_status _cffi_d_addrxlat_walk(addrxlat_step_t * x0)
{
  return addrxlat_walk(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_walk(PyObject *self, PyObject *arg0)
{
  addrxlat_step_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  addrxlat_status result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(63), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_step_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(63), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_walk(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(44));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_walk _cffi_d_addrxlat_walk
#endif

static void _cffi_d_free(void * x0)
{
  free(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_free(PyObject *self, PyObject *arg0)
{
  void * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(76), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (void *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(76), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { free(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_free _cffi_d_free
#endif

static void * _cffi_d_malloc(size_t x0)
{
  return malloc(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_malloc(PyObject *self, PyObject *arg0)
{
  size_t x0;
  void * result;
  PyObject *pyresult;

  x0 = _cffi_to_c_int(arg0, size_t);
  if (x0 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = malloc(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(76));
  return pyresult;
}
#else
#  define _cffi_f_malloc _cffi_d_malloc
#endif

static int _cffi_const_ADDRXLAT_ADDR_MAX(unsigned long long *o)
{
  int n = (ADDRXLAT_ADDR_MAX) <= 0;
  *o = (unsigned long long)((ADDRXLAT_ADDR_MAX) | 0);  /* check that ADDRXLAT_ADDR_MAX is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_FIELDS_MAX(unsigned long long *o)
{
  int n = (ADDRXLAT_FIELDS_MAX) <= 0;
  *o = (unsigned long long)((ADDRXLAT_FIELDS_MAX) | 0);  /* check that ADDRXLAT_FIELDS_MAX is an integer */
  if (!_cffi_check_int(*o, n, 8U))
    n |= 2;
  return n;
}

static int _cffi_const_ADDRXLAT_SYS_METH_CUSTOM_NUM(unsigned long long *o)
{
  int n = (ADDRXLAT_SYS_METH_CUSTOM_NUM) <= 0;
  *o = (unsigned long long)((ADDRXLAT_SYS_METH_CUSTOM_NUM) | 0);  /* check that ADDRXLAT_SYS_METH_CUSTOM_NUM is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_SYS_METH_NUM(unsigned long long *o)
{
  int n = (ADDRXLAT_SYS_METH_NUM) <= 0;
  *o = (unsigned long long)((ADDRXLAT_SYS_METH_NUM) | 0);  /* check that ADDRXLAT_SYS_METH_NUM is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_VERSION(unsigned long long *o)
{
  int n = (ADDRXLAT_VERSION) <= 0;
  *o = (unsigned long long)((ADDRXLAT_VERSION) | 0);  /* check that ADDRXLAT_VERSION is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_VER_MAJOR(unsigned long long *o)
{
  int n = (ADDRXLAT_VER_MAJOR) <= 0;
  *o = (unsigned long long)((ADDRXLAT_VER_MAJOR) | 0);  /* check that ADDRXLAT_VER_MAJOR is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_VER_MICRO(unsigned long long *o)
{
  int n = (ADDRXLAT_VER_MICRO) <= 0;
  *o = (unsigned long long)((ADDRXLAT_VER_MICRO) | 0);  /* check that ADDRXLAT_VER_MICRO is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_VER_MINOR(unsigned long long *o)
{
  int n = (ADDRXLAT_VER_MINOR) <= 0;
  *o = (unsigned long long)((ADDRXLAT_VER_MINOR) | 0);  /* check that ADDRXLAT_VER_MINOR is an integer */
  return n;
}

_CFFI_UNUSED_FN
static void _cffi_checkfld__addrxlat_buffer_t(addrxlat_buffer_t *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { addrxlat_fulladdr_t *tmp = &p->addr; (void)tmp; }
  { void const * *tmp = &p->ptr; (void)tmp; }
  (void)((p->size) | 0);  /* check that 'addrxlat_buffer_t.size' is an integer */
  { addrxlat_byte_order_t *tmp = &p->byte_order; (void)tmp; }
  { void(* *tmp)(addrxlat_buffer_t const *) = &p->put_page; (void)tmp; }
  { void * *tmp = &p->priv; (void)tmp; }
}
struct _cffi_align__addrxlat_buffer_t { char x; addrxlat_buffer_t y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__addrxlat_cb_t(addrxlat_cb_t *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { addrxlat_cb_t const * *tmp = &p->next; (void)tmp; }
  { void * *tmp = &p->priv; (void)tmp; }
  { addrxlat_status(* *tmp)(addrxlat_cb_t const *, addrxlat_buffer_t *) = &p->get_page; (void)tmp; }
  { unsigned long(* *tmp)(addrxlat_cb_t const *) = &p->read_caps; (void)tmp; }
  { addrxlat_status(* *tmp)(addrxlat_cb_t const *, char const *, uint_fast64_t *) = &p->reg_value; (void)tmp; }
  { addrxlat_status(* *tmp)(addrxlat_cb_t const *, char const *, uint_fast64_t *) = &p->sym_value; (void)tmp; }
  { addrxlat_status(* *tmp)(addrxlat_cb_t const *, char const *, uint_fast64_t *) = &p->sym_sizeof; (void)tmp; }
  { addrxlat_status(* *tmp)(addrxlat_cb_t const *, char const *, char const *, uint_fast64_t *) = &p->sym_offsetof; (void)tmp; }
  { addrxlat_status(* *tmp)(addrxlat_cb_t const *, char const *, uint_fast64_t *) = &p->num_value; (void)tmp; }
}
struct _cffi_align__addrxlat_cb_t { char x; addrxlat_cb_t y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__addrxlat_fulladdr_t(addrxlat_fulladdr_t *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->addr) | 0);  /* check that 'addrxlat_fulladdr_t.addr' is an integer */
  { addrxlat_addrspace_t *tmp = &p->as; (void)tmp; }
}
struct _cffi_align__addrxlat_fulladdr_t { char x; addrxlat_fulladdr_t y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__addrxlat_lookup_elem_t(addrxlat_lookup_elem_t *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->orig) | 0);  /* check that 'addrxlat_lookup_elem_t.orig' is an integer */
  (void)((p->dest) | 0);  /* check that 'addrxlat_lookup_elem_t.dest' is an integer */
}
struct _cffi_align__addrxlat_lookup_elem_t { char x; addrxlat_lookup_elem_t y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__addrxlat_meth_t(addrxlat_meth_t *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { addrxlat_kind_t *tmp = &p->kind; (void)tmp; }
  { addrxlat_addrspace_t *tmp = &p->target_as; (void)tmp; }
  { addrxlat_param_t *tmp = &p->param; (void)tmp; }
}
struct _cffi_align__addrxlat_meth_t { char x; addrxlat_meth_t y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__addrxlat_op_ctl_t(addrxlat_op_ctl_t *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { addrxlat_ctx_t * *tmp = &p->ctx; (void)tmp; }
  { addrxlat_sys_t * *tmp = &p->sys; (void)tmp; }
  { addrxlat_status(* *tmp)(void *, addrxlat_fulladdr_t const *) = &p->op; (void)tmp; }
  { void * *tmp = &p->data; (void)tmp; }
  (void)((p->caps) | 0);  /* check that 'addrxlat_op_ctl_t.caps' is an integer */
}
struct _cffi_align__addrxlat_op_ctl_t { char x; addrxlat_op_ctl_t y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__addrxlat_opt_t(addrxlat_opt_t *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { addrxlat_optidx_t *tmp = &p->idx; (void)tmp; }
  { addrxlat_optval_t *tmp = &p->val; (void)tmp; }
}
struct _cffi_align__addrxlat_opt_t { char x; addrxlat_opt_t y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__addrxlat_paging_form_t(addrxlat_paging_form_t *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { addrxlat_pte_format_t *tmp = &p->pte_format; (void)tmp; }
  (void)((p->nfields) | 0);  /* check that 'addrxlat_paging_form_t.nfields' is an integer */
  { unsigned short(*tmp)[8] = &p->fieldsz; (void)tmp; }
}
struct _cffi_align__addrxlat_paging_form_t { char x; addrxlat_paging_form_t y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__addrxlat_param_custom_t(addrxlat_param_custom_t *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { addrxlat_status(* *tmp)(addrxlat_step_t *, uint_fast64_t) = &p->first_step; (void)tmp; }
  { addrxlat_status(* *tmp)(addrxlat_step_t *) = &p->next_step; (void)tmp; }
  { void * *tmp = &p->data; (void)tmp; }
}
struct _cffi_align__addrxlat_param_custom_t { char x; addrxlat_param_custom_t y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__addrxlat_param_linear_t(addrxlat_param_linear_t *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->off) | 0);  /* check that 'addrxlat_param_linear_t.off' is an integer */
}
struct _cffi_align__addrxlat_param_linear_t { char x; addrxlat_param_linear_t y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__addrxlat_param_lookup_t(addrxlat_param_lookup_t *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->endoff) | 0);  /* check that 'addrxlat_param_lookup_t.endoff' is an integer */
  (void)((p->nelem) | 0);  /* check that 'addrxlat_param_lookup_t.nelem' is an integer */
  { addrxlat_lookup_elem_t * *tmp = &p->tbl; (void)tmp; }
}
struct _cffi_align__addrxlat_param_lookup_t { char x; addrxlat_param_lookup_t y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__addrxlat_param_memarr_t(addrxlat_param_memarr_t *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { addrxlat_fulladdr_t *tmp = &p->base; (void)tmp; }
  (void)((p->shift) | 0);  /* check that 'addrxlat_param_memarr_t.shift' is an integer */
  (void)((p->elemsz) | 0);  /* check that 'addrxlat_param_memarr_t.elemsz' is an integer */
  (void)((p->valsz) | 0);  /* check that 'addrxlat_param_memarr_t.valsz' is an integer */
}
struct _cffi_align__addrxlat_param_memarr_t { char x; addrxlat_param_memarr_t y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__addrxlat_param_pgt_t(addrxlat_param_pgt_t *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { addrxlat_fulladdr_t *tmp = &p->root; (void)tmp; }
  (void)((p->pte_mask) | 0);  /* check that 'addrxlat_param_pgt_t.pte_mask' is an integer */
  { addrxlat_paging_form_t *tmp = &p->pf; (void)tmp; }
}
struct _cffi_align__addrxlat_param_pgt_t { char x; addrxlat_param_pgt_t y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__addrxlat_range_t(addrxlat_range_t *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->endoff) | 0);  /* check that 'addrxlat_range_t.endoff' is an integer */
  { addrxlat_sys_meth_t *tmp = &p->meth; (void)tmp; }
}
struct _cffi_align__addrxlat_range_t { char x; addrxlat_range_t y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__addrxlat_step_t(addrxlat_step_t *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { addrxlat_ctx_t * *tmp = &p->ctx; (void)tmp; }
  { addrxlat_sys_t * *tmp = &p->sys; (void)tmp; }
  { addrxlat_meth_t const * *tmp = &p->meth; (void)tmp; }
  (void)((p->remain) | 0);  /* check that 'addrxlat_step_t.remain' is an integer */
  (void)((p->elemsz) | 0);  /* check that 'addrxlat_step_t.elemsz' is an integer */
  { addrxlat_fulladdr_t *tmp = &p->base; (void)tmp; }
  /* cannot generate 'union $1' in field 'raw': unknown type name */
  { uint_fast64_t(*tmp)[9] = &p->idx; (void)tmp; }
}
struct _cffi_align__addrxlat_step_t { char x; addrxlat_step_t y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__addrxlat_optval_t(addrxlat_optval_t *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { char const * *tmp = &p->str; (void)tmp; }
  (void)((p->num) | 0);  /* check that 'addrxlat_optval_t.num' is an integer */
  (void)((p->addr) | 0);  /* check that 'addrxlat_optval_t.addr' is an integer */
  { addrxlat_fulladdr_t *tmp = &p->fulladdr; (void)tmp; }
}
struct _cffi_align__addrxlat_optval_t { char x; addrxlat_optval_t y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__addrxlat_param_t(addrxlat_param_t *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { addrxlat_param_custom_t *tmp = &p->custom; (void)tmp; }
  { addrxlat_param_linear_t *tmp = &p->linear; (void)tmp; }
  { addrxlat_param_pgt_t *tmp = &p->pgt; (void)tmp; }
  { addrxlat_param_lookup_t *tmp = &p->lookup; (void)tmp; }
  { addrxlat_param_memarr_t *tmp = &p->memarr; (void)tmp; }
}
struct _cffi_align__addrxlat_param_t { char x; addrxlat_param_t y; };

static const struct _cffi_global_s _cffi_globals[] = {
  { "ADDRXLAT_ADDR_MAX", (void *)_cffi_const_ADDRXLAT_ADDR_MAX, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "ADDRXLAT_BIG_ENDIAN", (void *)_cffi_const_ADDRXLAT_BIG_ENDIAN, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_CAPS", (void *)_cffi_f_ADDRXLAT_CAPS, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 115), (void *)_cffi_d_ADDRXLAT_CAPS },
  { "ADDRXLAT_CUSTOM", (void *)_cffi_const_ADDRXLAT_CUSTOM, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_ERR_CUSTOM_BASE", (void *)_cffi_const_ADDRXLAT_ERR_CUSTOM_BASE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_ERR_INVALID", (void *)_cffi_const_ADDRXLAT_ERR_INVALID, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_ERR_NODATA", (void *)_cffi_const_ADDRXLAT_ERR_NODATA, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_ERR_NOMEM", (void *)_cffi_const_ADDRXLAT_ERR_NOMEM, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_ERR_NOMETH", (void *)_cffi_const_ADDRXLAT_ERR_NOMETH, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_ERR_NOTIMPL", (void *)_cffi_const_ADDRXLAT_ERR_NOTIMPL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_ERR_NOTPRESENT", (void *)_cffi_const_ADDRXLAT_ERR_NOTPRESENT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_FIELDS_MAX", (void *)_cffi_const_ADDRXLAT_FIELDS_MAX, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "ADDRXLAT_HOST_ENDIAN", (void *)_cffi_const_ADDRXLAT_HOST_ENDIAN, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_KPHYSADDR", (void *)_cffi_const_ADDRXLAT_KPHYSADDR, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_KVADDR", (void *)_cffi_const_ADDRXLAT_KVADDR, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_LINEAR", (void *)_cffi_const_ADDRXLAT_LINEAR, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_LITTLE_ENDIAN", (void *)_cffi_const_ADDRXLAT_LITTLE_ENDIAN, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_LOOKUP", (void *)_cffi_const_ADDRXLAT_LOOKUP, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_MACHPHYSADDR", (void *)_cffi_const_ADDRXLAT_MACHPHYSADDR, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_MEMARR", (void *)_cffi_const_ADDRXLAT_MEMARR, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_NOADDR", (void *)_cffi_const_ADDRXLAT_NOADDR, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_NOMETH", (void *)_cffi_const_ADDRXLAT_NOMETH, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_OK", (void *)_cffi_const_ADDRXLAT_OK, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_OPT_NULL", (void *)_cffi_const_ADDRXLAT_OPT_NULL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_OPT_NUM", (void *)_cffi_const_ADDRXLAT_OPT_NUM, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_OPT_arch", (void *)_cffi_const_ADDRXLAT_OPT_arch, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_OPT_os_type", (void *)_cffi_const_ADDRXLAT_OPT_os_type, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_OPT_page_shift", (void *)_cffi_const_ADDRXLAT_OPT_page_shift, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_OPT_phys_base", (void *)_cffi_const_ADDRXLAT_OPT_phys_base, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_OPT_phys_bits", (void *)_cffi_const_ADDRXLAT_OPT_phys_bits, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_OPT_rootpgt", (void *)_cffi_const_ADDRXLAT_OPT_rootpgt, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_OPT_version_code", (void *)_cffi_const_ADDRXLAT_OPT_version_code, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_OPT_virt_bits", (void *)_cffi_const_ADDRXLAT_OPT_virt_bits, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_OPT_xen_p2m_mfn", (void *)_cffi_const_ADDRXLAT_OPT_xen_p2m_mfn, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_OPT_xen_xlat", (void *)_cffi_const_ADDRXLAT_OPT_xen_xlat, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_PGT", (void *)_cffi_const_ADDRXLAT_PGT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_PTE_AARCH64", (void *)_cffi_const_ADDRXLAT_PTE_AARCH64, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_PTE_AARCH64_LPA", (void *)_cffi_const_ADDRXLAT_PTE_AARCH64_LPA, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_PTE_AARCH64_LPA2", (void *)_cffi_const_ADDRXLAT_PTE_AARCH64_LPA2, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_PTE_ARM", (void *)_cffi_const_ADDRXLAT_PTE_ARM, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_PTE_IA32", (void *)_cffi_const_ADDRXLAT_PTE_IA32, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_PTE_IA32_PAE", (void *)_cffi_const_ADDRXLAT_PTE_IA32_PAE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_PTE_INVALID", (void *)_cffi_const_ADDRXLAT_PTE_INVALID, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_PTE_NONE", (void *)_cffi_const_ADDRXLAT_PTE_NONE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_PTE_PFN32", (void *)_cffi_const_ADDRXLAT_PTE_PFN32, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_PTE_PFN64", (void *)_cffi_const_ADDRXLAT_PTE_PFN64, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_PTE_PPC64_LINUX_RPN30", (void *)_cffi_const_ADDRXLAT_PTE_PPC64_LINUX_RPN30, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_PTE_RISCV32", (void *)_cffi_const_ADDRXLAT_PTE_RISCV32, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_PTE_RISCV64", (void *)_cffi_const_ADDRXLAT_PTE_RISCV64, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_PTE_S390X", (void *)_cffi_const_ADDRXLAT_PTE_S390X, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_PTE_X86_64", (void *)_cffi_const_ADDRXLAT_PTE_X86_64, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_SYS_MAP_HW", (void *)_cffi_const_ADDRXLAT_SYS_MAP_HW, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_SYS_MAP_KPHYS_DIRECT", (void *)_cffi_const_ADDRXLAT_SYS_MAP_KPHYS_DIRECT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_SYS_MAP_KPHYS_MACHPHYS", (void *)_cffi_const_ADDRXLAT_SYS_MAP_KPHYS_MACHPHYS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_SYS_MAP_KV_PHYS", (void *)_cffi_const_ADDRXLAT_SYS_MAP_KV_PHYS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_SYS_MAP_MACHPHYS_KPHYS", (void *)_cffi_const_ADDRXLAT_SYS_MAP_MACHPHYS_KPHYS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_SYS_MAP_NUM", (void *)_cffi_const_ADDRXLAT_SYS_MAP_NUM, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_SYS_METH_CUSTOM", (void *)_cffi_const_ADDRXLAT_SYS_METH_CUSTOM, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_SYS_METH_CUSTOM_NUM", (void *)_cffi_const_ADDRXLAT_SYS_METH_CUSTOM_NUM, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "ADDRXLAT_SYS_METH_DIRECT", (void *)_cffi_const_ADDRXLAT_SYS_METH_DIRECT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_SYS_METH_KPHYS_MACHPHYS", (void *)_cffi_const_ADDRXLAT_SYS_METH_KPHYS_MACHPHYS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_SYS_METH_KTEXT", (void *)_cffi_const_ADDRXLAT_SYS_METH_KTEXT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_SYS_METH_MACHPHYS_KPHYS", (void *)_cffi_const_ADDRXLAT_SYS_METH_MACHPHYS_KPHYS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_SYS_METH_NONE", (void *)_cffi_const_ADDRXLAT_SYS_METH_NONE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_SYS_METH_NUM", (void *)_cffi_const_ADDRXLAT_SYS_METH_NUM, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "ADDRXLAT_SYS_METH_PGT", (void *)_cffi_const_ADDRXLAT_SYS_METH_PGT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_SYS_METH_RDIRECT", (void *)_cffi_const_ADDRXLAT_SYS_METH_RDIRECT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_SYS_METH_UPGT", (void *)_cffi_const_ADDRXLAT_SYS_METH_UPGT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_SYS_METH_VMEMMAP", (void *)_cffi_const_ADDRXLAT_SYS_METH_VMEMMAP, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_VERSION", (void *)_cffi_const_ADDRXLAT_VERSION, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "ADDRXLAT_VER_LINUX", (void *)_cffi_f_ADDRXLAT_VER_LINUX, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 122), (void *)_cffi_d_ADDRXLAT_VER_LINUX },
  { "ADDRXLAT_VER_MAJOR", (void *)_cffi_const_ADDRXLAT_VER_MAJOR, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "ADDRXLAT_VER_MICRO", (void *)_cffi_const_ADDRXLAT_VER_MICRO, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "ADDRXLAT_VER_MINOR", (void *)_cffi_const_ADDRXLAT_VER_MINOR, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "ADDRXLAT_VER_XEN", (void *)_cffi_f_ADDRXLAT_VER_XEN, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 118), (void *)_cffi_d_ADDRXLAT_VER_XEN },
  { "_cb_first_step", (void *)&_cffi_externpy___cb_first_step, _CFFI_OP(_CFFI_OP_EXTERN_PYTHON, 197), (void *)_cb_first_step },
  { "_cb_get_page", (void *)&_cffi_externpy___cb_get_page, _CFFI_OP(_CFFI_OP_EXTERN_PYTHON, 192), (void *)_cb_get_page },
  { "_cb_next_step", (void *)&_cffi_externpy___cb_next_step, _CFFI_OP(_CFFI_OP_EXTERN_PYTHON, 196), (void *)_cb_next_step },
  { "_cb_num_value", (void *)&_cffi_externpy___cb_num_value, _CFFI_OP(_CFFI_OP_EXTERN_PYTHON, 194), (void *)_cb_num_value },
  { "_cb_op", (void *)&_cffi_externpy___cb_op, _CFFI_OP(_CFFI_OP_EXTERN_PYTHON, 198), (void *)_cb_op },
  { "_cb_put_page", (void *)&_cffi_externpy___cb_put_page, _CFFI_OP(_CFFI_OP_EXTERN_PYTHON, 212), (void *)_cb_put_page },
  { "_cb_read_caps", (void *)&_cffi_externpy___cb_read_caps, _CFFI_OP(_CFFI_OP_EXTERN_PYTHON, 207), (void *)_cb_read_caps },
  { "_cb_reg_value", (void *)&_cffi_externpy___cb_reg_value, _CFFI_OP(_CFFI_OP_EXTERN_PYTHON, 194), (void *)_cb_reg_value },
  { "_cb_sym_offsetof", (void *)&_cffi_externpy___cb_sym_offsetof, _CFFI_OP(_CFFI_OP_EXTERN_PYTHON, 193), (void *)_cb_sym_offsetof },
  { "_cb_sym_sizeof", (void *)&_cffi_externpy___cb_sym_sizeof, _CFFI_OP(_CFFI_OP_EXTERN_PYTHON, 194), (void *)_cb_sym_sizeof },
  { "_cb_sym_value", (void *)&_cffi_externpy___cb_sym_value, _CFFI_OP(_CFFI_OP_EXTERN_PYTHON, 194), (void *)_cb_sym_value },
  { "addrxlat_addrspace_name", (void *)_cffi_f_addrxlat_addrspace_name, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 85), (void *)_cffi_d_addrxlat_addrspace_name },
  { "addrxlat_ctx_add_cb", (void *)_cffi_f_addrxlat_ctx_add_cb, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 0), (void *)_cffi_d_addrxlat_ctx_add_cb },
  { "addrxlat_ctx_clear_err", (void *)_cffi_f_addrxlat_ctx_clear_err, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 133), (void *)_cffi_d_addrxlat_ctx_clear_err },
  { "addrxlat_ctx_decref", (void *)_cffi_f_addrxlat_ctx_decref, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 106), (void *)_cffi_d_addrxlat_ctx_decref },
  { "addrxlat_ctx_del_cb", (void *)_cffi_f_addrxlat_ctx_del_cb, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 136), (void *)_cffi_d_addrxlat_ctx_del_cb },
  { "addrxlat_ctx_err", (void *)_cffi_const_addrxlat_ctx_err, _CFFI_OP(_CFFI_OP_CONSTANT, 195), (void *)0 },
  { "addrxlat_ctx_get_cb", (void *)_cffi_f_addrxlat_ctx_get_cb, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 3), (void *)_cffi_d_addrxlat_ctx_get_cb },
  { "addrxlat_ctx_get_err", (void *)_cffi_f_addrxlat_ctx_get_err, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 88), (void *)_cffi_d_addrxlat_ctx_get_err },
  { "addrxlat_ctx_incref", (void *)_cffi_f_addrxlat_ctx_incref, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 106), (void *)_cffi_d_addrxlat_ctx_incref },
  { "addrxlat_ctx_new", (void *)_cffi_f_addrxlat_ctx_new, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_N, 6), (void *)_cffi_d_addrxlat_ctx_new },
  { "addrxlat_fulladdr_conv", (void *)_cffi_f_addrxlat_fulladdr_conv, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 47), (void *)_cffi_d_addrxlat_fulladdr_conv },
  { "addrxlat_launch", (void *)_cffi_f_addrxlat_launch, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 65), (void *)_cffi_d_addrxlat_launch },
  { "addrxlat_map_copy", (void *)_cffi_f_addrxlat_map_copy, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 8), (void *)_cffi_d_addrxlat_map_copy },
  { "addrxlat_map_decref", (void *)_cffi_f_addrxlat_map_decref, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 109), (void *)_cffi_d_addrxlat_map_decref },
  { "addrxlat_map_incref", (void *)_cffi_f_addrxlat_map_incref, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 109), (void *)_cffi_d_addrxlat_map_incref },
  { "addrxlat_map_len", (void *)_cffi_f_addrxlat_map_len, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 100), (void *)_cffi_d_addrxlat_map_len },
  { "addrxlat_map_new", (void *)_cffi_f_addrxlat_map_new, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_N, 15), (void *)_cffi_d_addrxlat_map_new },
  { "addrxlat_map_ranges", (void *)_cffi_f_addrxlat_map_ranges, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 24), (void *)_cffi_d_addrxlat_map_ranges },
  { "addrxlat_map_search", (void *)_cffi_f_addrxlat_map_search, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 79), (void *)_cffi_d_addrxlat_map_search },
  { "addrxlat_map_set", (void *)_cffi_f_addrxlat_map_set, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 53), (void *)_cffi_d_addrxlat_map_set },
  { "addrxlat_op", (void *)_cffi_f_addrxlat_op, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 58), (void *)_cffi_d_addrxlat_op },
  { "addrxlat_opt_arch", (void *)_cffi_f_addrxlat_opt_arch, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 144), (void *)_cffi_d_addrxlat_opt_arch },
  { "addrxlat_opt_os_type", (void *)_cffi_f_addrxlat_opt_os_type, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 144), (void *)_cffi_d_addrxlat_opt_os_type },
  { "addrxlat_opt_page_shift", (void *)_cffi_f_addrxlat_opt_page_shift, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 152), (void *)_cffi_d_addrxlat_opt_page_shift },
  { "addrxlat_opt_phys_base", (void *)_cffi_f_addrxlat_opt_phys_base, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 148), (void *)_cffi_d_addrxlat_opt_phys_base },
  { "addrxlat_opt_phys_bits", (void *)_cffi_f_addrxlat_opt_phys_bits, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 152), (void *)_cffi_d_addrxlat_opt_phys_bits },
  { "addrxlat_opt_rootpgt", (void *)_cffi_f_addrxlat_opt_rootpgt, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 140), (void *)_cffi_d_addrxlat_opt_rootpgt },
  { "addrxlat_opt_version_code", (void *)_cffi_f_addrxlat_opt_version_code, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 152), (void *)_cffi_d_addrxlat_opt_version_code },
  { "addrxlat_opt_virt_bits", (void *)_cffi_f_addrxlat_opt_virt_bits, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 152), (void *)_cffi_d_addrxlat_opt_virt_bits },
  { "addrxlat_opt_xen_p2m_mfn", (void *)_cffi_f_addrxlat_opt_xen_p2m_mfn, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 152), (void *)_cffi_d_addrxlat_opt_xen_p2m_mfn },
  { "addrxlat_opt_xen_xlat", (void *)_cffi_f_addrxlat_opt_xen_xlat, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 152), (void *)_cffi_d_addrxlat_opt_xen_xlat },
  { "addrxlat_pte_format", (void *)_cffi_f_addrxlat_pte_format, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 21), (void *)_cffi_d_addrxlat_pte_format },
  { "addrxlat_pte_format_name", (void *)_cffi_f_addrxlat_pte_format_name, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 91), (void *)_cffi_d_addrxlat_pte_format_name },
  { "addrxlat_pteval_shift", (void *)_cffi_f_addrxlat_pteval_shift, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 97), (void *)_cffi_d_addrxlat_pteval_shift },
  { "addrxlat_step", (void *)_cffi_f_addrxlat_step, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 62), (void *)_cffi_d_addrxlat_step },
  { "addrxlat_strerror", (void *)_cffi_f_addrxlat_strerror, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 94), (void *)_cffi_d_addrxlat_strerror },
  { "addrxlat_sys_decref", (void *)_cffi_f_addrxlat_sys_decref, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 112), (void *)_cffi_d_addrxlat_sys_decref },
  { "addrxlat_sys_get_map", (void *)_cffi_f_addrxlat_sys_get_map, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 11), (void *)_cffi_d_addrxlat_sys_get_map },
  { "addrxlat_sys_get_meth", (void *)_cffi_f_addrxlat_sys_get_meth, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 17), (void *)_cffi_d_addrxlat_sys_get_meth },
  { "addrxlat_sys_incref", (void *)_cffi_f_addrxlat_sys_incref, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 112), (void *)_cffi_d_addrxlat_sys_incref },
  { "addrxlat_sys_new", (void *)_cffi_f_addrxlat_sys_new, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_N, 83), (void *)_cffi_d_addrxlat_sys_new },
  { "addrxlat_sys_os_init", (void *)_cffi_f_addrxlat_sys_os_init, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 69), (void *)_cffi_d_addrxlat_sys_os_init },
  { "addrxlat_sys_set_map", (void *)_cffi_f_addrxlat_sys_set_map, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 156), (void *)_cffi_d_addrxlat_sys_set_map },
  { "addrxlat_sys_set_meth", (void *)_cffi_f_addrxlat_sys_set_meth, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 161), (void *)_cffi_d_addrxlat_sys_set_meth },
  { "addrxlat_walk", (void *)_cffi_f_addrxlat_walk, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 62), (void *)_cffi_d_addrxlat_walk },
  { "free", (void *)_cffi_f_free, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 166), (void *)_cffi_d_free },
  { "malloc", (void *)_cffi_f_malloc, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 127), (void *)_cffi_d_malloc },
};

static const struct _cffi_field_s _cffi_fields[] = {
  { "addr", offsetof(addrxlat_buffer_t, addr),
            sizeof(((addrxlat_buffer_t *)0)->addr),
            _CFFI_OP(_CFFI_OP_NOOP, 173) },
  { "ptr", offsetof(addrxlat_buffer_t, ptr),
           sizeof(((addrxlat_buffer_t *)0)->ptr),
           _CFFI_OP(_CFFI_OP_NOOP, 211) },
  { "size", offsetof(addrxlat_buffer_t, size),
            sizeof(((addrxlat_buffer_t *)0)->size),
            _CFFI_OP(_CFFI_OP_NOOP, 128) },
  { "byte_order", offsetof(addrxlat_buffer_t, byte_order),
                  sizeof(((addrxlat_buffer_t *)0)->byte_order),
                  _CFFI_OP(_CFFI_OP_NOOP, 170) },
  { "put_page", offsetof(addrxlat_buffer_t, put_page),
                sizeof(((addrxlat_buffer_t *)0)->put_page),
                _CFFI_OP(_CFFI_OP_NOOP, 212) },
  { "priv", offsetof(addrxlat_buffer_t, priv),
            sizeof(((addrxlat_buffer_t *)0)->priv),
            _CFFI_OP(_CFFI_OP_NOOP, 76) },
  { "next", offsetof(addrxlat_cb_t, next),
            sizeof(((addrxlat_cb_t *)0)->next),
            _CFFI_OP(_CFFI_OP_NOOP, 28) },
  { "priv", offsetof(addrxlat_cb_t, priv),
            sizeof(((addrxlat_cb_t *)0)->priv),
            _CFFI_OP(_CFFI_OP_NOOP, 76) },
  { "get_page", offsetof(addrxlat_cb_t, get_page),
                sizeof(((addrxlat_cb_t *)0)->get_page),
                _CFFI_OP(_CFFI_OP_NOOP, 192) },
  { "read_caps", offsetof(addrxlat_cb_t, read_caps),
                 sizeof(((addrxlat_cb_t *)0)->read_caps),
                 _CFFI_OP(_CFFI_OP_NOOP, 207) },
  { "reg_value", offsetof(addrxlat_cb_t, reg_value),
                 sizeof(((addrxlat_cb_t *)0)->reg_value),
                 _CFFI_OP(_CFFI_OP_NOOP, 194) },
  { "sym_value", offsetof(addrxlat_cb_t, sym_value),
                 sizeof(((addrxlat_cb_t *)0)->sym_value),
                 _CFFI_OP(_CFFI_OP_NOOP, 194) },
  { "sym_sizeof", offsetof(addrxlat_cb_t, sym_sizeof),
                  sizeof(((addrxlat_cb_t *)0)->sym_sizeof),
                  _CFFI_OP(_CFFI_OP_NOOP, 194) },
  { "sym_offsetof", offsetof(addrxlat_cb_t, sym_offsetof),
                    sizeof(((addrxlat_cb_t *)0)->sym_offsetof),
                    _CFFI_OP(_CFFI_OP_NOOP, 193) },
  { "num_value", offsetof(addrxlat_cb_t, num_value),
                 sizeof(((addrxlat_cb_t *)0)->num_value),
                 _CFFI_OP(_CFFI_OP_NOOP, 194) },
  { "addr", offsetof(addrxlat_fulladdr_t, addr),
            sizeof(((addrxlat_fulladdr_t *)0)->addr),
            _CFFI_OP(_CFFI_OP_NOOP, 55) },
  { "as", offsetof(addrxlat_fulladdr_t, as),
          sizeof(((addrxlat_fulladdr_t *)0)->as),
          _CFFI_OP(_CFFI_OP_NOOP, 49) },
  { "orig", offsetof(addrxlat_lookup_elem_t, orig),
            sizeof(((addrxlat_lookup_elem_t *)0)->orig),
            _CFFI_OP(_CFFI_OP_NOOP, 55) },
  { "dest", offsetof(addrxlat_lookup_elem_t, dest),
            sizeof(((addrxlat_lookup_elem_t *)0)->dest),
            _CFFI_OP(_CFFI_OP_NOOP, 55) },
  { "kind", offsetof(addrxlat_meth_t, kind),
            sizeof(((addrxlat_meth_t *)0)->kind),
            _CFFI_OP(_CFFI_OP_NOOP, 174) },
  { "target_as", offsetof(addrxlat_meth_t, target_as),
                 sizeof(((addrxlat_meth_t *)0)->target_as),
                 _CFFI_OP(_CFFI_OP_NOOP, 49) },
  { "param", offsetof(addrxlat_meth_t, param),
             sizeof(((addrxlat_meth_t *)0)->param),
             _CFFI_OP(_CFFI_OP_NOOP, 190) },
  { "ctx", offsetof(addrxlat_op_ctl_t, ctx),
           sizeof(((addrxlat_op_ctl_t *)0)->ctx),
           _CFFI_OP(_CFFI_OP_NOOP, 1) },
  { "sys", offsetof(addrxlat_op_ctl_t, sys),
           sizeof(((addrxlat_op_ctl_t *)0)->sys),
           _CFFI_OP(_CFFI_OP_NOOP, 51) },
  { "op", offsetof(addrxlat_op_ctl_t, op),
          sizeof(((addrxlat_op_ctl_t *)0)->op),
          _CFFI_OP(_CFFI_OP_NOOP, 198) },
  { "data", offsetof(addrxlat_op_ctl_t, data),
            sizeof(((addrxlat_op_ctl_t *)0)->data),
            _CFFI_OP(_CFFI_OP_NOOP, 76) },
  { "caps", offsetof(addrxlat_op_ctl_t, caps),
            sizeof(((addrxlat_op_ctl_t *)0)->caps),
            _CFFI_OP(_CFFI_OP_NOOP, 154) },
  { "idx", offsetof(addrxlat_opt_t, idx),
           sizeof(((addrxlat_opt_t *)0)->idx),
           _CFFI_OP(_CFFI_OP_NOOP, 182) },
  { "val", offsetof(addrxlat_opt_t, val),
           sizeof(((addrxlat_opt_t *)0)->val),
           _CFFI_OP(_CFFI_OP_NOOP, 183) },
  { "pte_format", offsetof(addrxlat_paging_form_t, pte_format),
                  sizeof(((addrxlat_paging_form_t *)0)->pte_format),
                  _CFFI_OP(_CFFI_OP_NOOP, 92) },
  { "nfields", offsetof(addrxlat_paging_form_t, nfields),
               sizeof(((addrxlat_paging_form_t *)0)->nfields),
               _CFFI_OP(_CFFI_OP_NOOP, 208) },
  { "fieldsz", offsetof(addrxlat_paging_form_t, fieldsz),
               sizeof(((addrxlat_paging_form_t *)0)->fieldsz),
               _CFFI_OP(_CFFI_OP_NOOP, 209) },
  { "first_step", offsetof(addrxlat_param_custom_t, first_step),
                  sizeof(((addrxlat_param_custom_t *)0)->first_step),
                  _CFFI_OP(_CFFI_OP_NOOP, 197) },
  { "next_step", offsetof(addrxlat_param_custom_t, next_step),
                 sizeof(((addrxlat_param_custom_t *)0)->next_step),
                 _CFFI_OP(_CFFI_OP_NOOP, 196) },
  { "data", offsetof(addrxlat_param_custom_t, data),
            sizeof(((addrxlat_param_custom_t *)0)->data),
            _CFFI_OP(_CFFI_OP_NOOP, 76) },
  { "off", offsetof(addrxlat_param_linear_t, off),
           sizeof(((addrxlat_param_linear_t *)0)->off),
           _CFFI_OP(_CFFI_OP_NOOP, 203) },
  { "endoff", offsetof(addrxlat_param_lookup_t, endoff),
              sizeof(((addrxlat_param_lookup_t *)0)->endoff),
              _CFFI_OP(_CFFI_OP_NOOP, 55) },
  { "nelem", offsetof(addrxlat_param_lookup_t, nelem),
             sizeof(((addrxlat_param_lookup_t *)0)->nelem),
             _CFFI_OP(_CFFI_OP_NOOP, 128) },
  { "tbl", offsetof(addrxlat_param_lookup_t, tbl),
           sizeof(((addrxlat_param_lookup_t *)0)->tbl),
           _CFFI_OP(_CFFI_OP_NOOP, 175) },
  { "base", offsetof(addrxlat_param_memarr_t, base),
            sizeof(((addrxlat_param_memarr_t *)0)->base),
            _CFFI_OP(_CFFI_OP_NOOP, 173) },
  { "shift", offsetof(addrxlat_param_memarr_t, shift),
             sizeof(((addrxlat_param_memarr_t *)0)->shift),
             _CFFI_OP(_CFFI_OP_NOOP, 72) },
  { "elemsz", offsetof(addrxlat_param_memarr_t, elemsz),
              sizeof(((addrxlat_param_memarr_t *)0)->elemsz),
              _CFFI_OP(_CFFI_OP_NOOP, 72) },
  { "valsz", offsetof(addrxlat_param_memarr_t, valsz),
             sizeof(((addrxlat_param_memarr_t *)0)->valsz),
             _CFFI_OP(_CFFI_OP_NOOP, 72) },
  { "root", offsetof(addrxlat_param_pgt_t, root),
            sizeof(((addrxlat_param_pgt_t *)0)->root),
            _CFFI_OP(_CFFI_OP_NOOP, 173) },
  { "pte_mask", offsetof(addrxlat_param_pgt_t, pte_mask),
                sizeof(((addrxlat_param_pgt_t *)0)->pte_mask),
                _CFFI_OP(_CFFI_OP_NOOP, 55) },
  { "pf", offsetof(addrxlat_param_pgt_t, pf),
          sizeof(((addrxlat_param_pgt_t *)0)->pf),
          _CFFI_OP(_CFFI_OP_NOOP, 184) },
  { "endoff", offsetof(addrxlat_range_t, endoff),
              sizeof(((addrxlat_range_t *)0)->endoff),
              _CFFI_OP(_CFFI_OP_NOOP, 55) },
  { "meth", offsetof(addrxlat_range_t, meth),
            sizeof(((addrxlat_range_t *)0)->meth),
            _CFFI_OP(_CFFI_OP_NOOP, 19) },
  { "ctx", offsetof(addrxlat_step_t, ctx),
           sizeof(((addrxlat_step_t *)0)->ctx),
           _CFFI_OP(_CFFI_OP_NOOP, 1) },
  { "sys", offsetof(addrxlat_step_t, sys),
           sizeof(((addrxlat_step_t *)0)->sys),
           _CFFI_OP(_CFFI_OP_NOOP, 51) },
  { "meth", offsetof(addrxlat_step_t, meth),
            sizeof(((addrxlat_step_t *)0)->meth),
            _CFFI_OP(_CFFI_OP_NOOP, 164) },
  { "remain", offsetof(addrxlat_step_t, remain),
              sizeof(((addrxlat_step_t *)0)->remain),
              _CFFI_OP(_CFFI_OP_NOOP, 208) },
  { "elemsz", offsetof(addrxlat_step_t, elemsz),
              sizeof(((addrxlat_step_t *)0)->elemsz),
              _CFFI_OP(_CFFI_OP_NOOP, 72) },
  { "base", offsetof(addrxlat_step_t, base),
            sizeof(((addrxlat_step_t *)0)->base),
            _CFFI_OP(_CFFI_OP_NOOP, 173) },
  { "raw", offsetof(addrxlat_step_t, raw),
           sizeof(((addrxlat_step_t *)0)->raw),
           _CFFI_OP(_CFFI_OP_NOOP, 206) },
  { "idx", offsetof(addrxlat_step_t, idx),
           sizeof(((addrxlat_step_t *)0)->idx),
           _CFFI_OP(_CFFI_OP_NOOP, 204) },
  { "str", offsetof(addrxlat_optval_t, str),
           sizeof(((addrxlat_optval_t *)0)->str),
           _CFFI_OP(_CFFI_OP_NOOP, 22) },
  { "num", offsetof(addrxlat_optval_t, num),
           sizeof(((addrxlat_optval_t *)0)->num),
           _CFFI_OP(_CFFI_OP_NOOP, 154) },
  { "addr", offsetof(addrxlat_optval_t, addr),
            sizeof(((addrxlat_optval_t *)0)->addr),
            _CFFI_OP(_CFFI_OP_NOOP, 55) },
  { "fulladdr", offsetof(addrxlat_optval_t, fulladdr),
                sizeof(((addrxlat_optval_t *)0)->fulladdr),
                _CFFI_OP(_CFFI_OP_NOOP, 173) },
  { "custom", offsetof(addrxlat_param_t, custom),
              sizeof(((addrxlat_param_t *)0)->custom),
              _CFFI_OP(_CFFI_OP_NOOP, 185) },
  { "linear", offsetof(addrxlat_param_t, linear),
              sizeof(((addrxlat_param_t *)0)->linear),
              _CFFI_OP(_CFFI_OP_NOOP, 186) },
  { "pgt", offsetof(addrxlat_param_t, pgt),
           sizeof(((addrxlat_param_t *)0)->pgt),
           _CFFI_OP(_CFFI_OP_NOOP, 189) },
  { "lookup", offsetof(addrxlat_param_t, lookup),
              sizeof(((addrxlat_param_t *)0)->lookup),
              _CFFI_OP(_CFFI_OP_NOOP, 187) },
  { "memarr", offsetof(addrxlat_param_t, memarr),
              sizeof(((addrxlat_param_t *)0)->memarr),
              _CFFI_OP(_CFFI_OP_NOOP, 188) },
  { "data", (size_t)-1,
            (size_t)-1,
            _CFFI_OP(_CFFI_OP_NOOP, 76) },
  { "pte", (size_t)-1,
           (size_t)-1,
           _CFFI_OP(_CFFI_OP_NOOP, 55) },
  { "elem", (size_t)-1,
            (size_t)-1,
            _CFFI_OP(_CFFI_OP_NOOP, 176) },
  { "addr", (size_t)-1,
            (size_t)-1,
            _CFFI_OP(_CFFI_OP_NOOP, 55) },
};

static const struct _cffi_struct_union_s _cffi_struct_unions[] = {
  { "$1", 206, _CFFI_F_UNION|_CFFI_F_CHECK_FIELDS,
    (size_t)-2, -2, 65, 4 /* unnamed */ },
  { "_addrxlat_buffer", 169, _CFFI_F_CHECK_FIELDS,
    sizeof(addrxlat_buffer_t), offsetof(struct _cffi_align__addrxlat_buffer_t, y), 0, 6 },
  { "_addrxlat_cb", 171, _CFFI_F_CHECK_FIELDS,
    sizeof(addrxlat_cb_t), offsetof(struct _cffi_align__addrxlat_cb_t, y), 6, 9 },
  { "_addrxlat_ctx", 172, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "_addrxlat_fulladdr", 173, _CFFI_F_CHECK_FIELDS,
    sizeof(addrxlat_fulladdr_t), offsetof(struct _cffi_align__addrxlat_fulladdr_t, y), 15, 2 },
  { "_addrxlat_lookup_elem", 177, _CFFI_F_CHECK_FIELDS,
    sizeof(addrxlat_lookup_elem_t), offsetof(struct _cffi_align__addrxlat_lookup_elem_t, y), 17, 2 },
  { "_addrxlat_map", 178, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "_addrxlat_meth", 179, _CFFI_F_CHECK_FIELDS,
    sizeof(addrxlat_meth_t), offsetof(struct _cffi_align__addrxlat_meth_t, y), 19, 3 },
  { "_addrxlat_op_ctl", 180, _CFFI_F_CHECK_FIELDS,
    sizeof(addrxlat_op_ctl_t), offsetof(struct _cffi_align__addrxlat_op_ctl_t, y), 22, 5 },
  { "_addrxlat_opt", 181, _CFFI_F_CHECK_FIELDS,
    sizeof(addrxlat_opt_t), offsetof(struct _cffi_align__addrxlat_opt_t, y), 27, 2 },
  { "_addrxlat_optval", 183, _CFFI_F_UNION|_CFFI_F_CHECK_FIELDS,
    sizeof(addrxlat_optval_t), offsetof(struct _cffi_align__addrxlat_optval_t, y), 56, 4 },
  { "_addrxlat_paging_form", 184, _CFFI_F_CHECK_FIELDS,
    sizeof(addrxlat_paging_form_t), offsetof(struct _cffi_align__addrxlat_paging_form_t, y), 29, 3 },
  { "_addrxlat_param", 190, _CFFI_F_UNION|_CFFI_F_CHECK_FIELDS,
    sizeof(addrxlat_param_t), offsetof(struct _cffi_align__addrxlat_param_t, y), 60, 5 },
  { "_addrxlat_param_custom", 185, _CFFI_F_CHECK_FIELDS,
    sizeof(addrxlat_param_custom_t), offsetof(struct _cffi_align__addrxlat_param_custom_t, y), 32, 3 },
  { "_addrxlat_param_linear", 186, _CFFI_F_CHECK_FIELDS,
    sizeof(addrxlat_param_linear_t), offsetof(struct _cffi_align__addrxlat_param_linear_t, y), 35, 1 },
  { "_addrxlat_param_lookup", 187, _CFFI_F_CHECK_FIELDS,
    sizeof(addrxlat_param_lookup_t), offsetof(struct _cffi_align__addrxlat_param_lookup_t, y), 36, 3 },
  { "_addrxlat_param_memarr", 188, _CFFI_F_CHECK_FIELDS,
    sizeof(addrxlat_param_memarr_t), offsetof(struct _cffi_align__addrxlat_param_memarr_t, y), 39, 4 },
  { "_addrxlat_param_pgt", 189, _CFFI_F_CHECK_FIELDS,
    sizeof(addrxlat_param_pgt_t), offsetof(struct _cffi_align__addrxlat_param_pgt_t, y), 43, 3 },
  { "_addrxlat_range", 191, _CFFI_F_CHECK_FIELDS,
    sizeof(addrxlat_range_t), offsetof(struct _cffi_align__addrxlat_range_t, y), 46, 2 },
  { "_addrxlat_step", 199, _CFFI_F_CHECK_FIELDS,
    sizeof(addrxlat_step_t), offsetof(struct _cffi_align__addrxlat_step_t, y), 48, 8 },
  { "_addrxlat_sys", 200, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
};

static const struct _cffi_enum_s _cffi_enums[] = {
  { "_addrxlat_addrspace", 49, _cffi_prim_int(sizeof(addrxlat_addrspace_t), ((addrxlat_addrspace_t)-1) <= 0),
    "ADDRXLAT_KPHYSADDR,ADDRXLAT_MACHPHYSADDR,ADDRXLAT_KVADDR,ADDRXLAT_NOADDR" },
  { "_addrxlat_byte_order", 170, _cffi_prim_int(sizeof(addrxlat_byte_order_t), ((addrxlat_byte_order_t)-1) <= 0),
    "ADDRXLAT_BIG_ENDIAN,ADDRXLAT_LITTLE_ENDIAN,ADDRXLAT_HOST_ENDIAN" },
  { "_addrxlat_kind", 174, _cffi_prim_int(sizeof(addrxlat_kind_t), ((addrxlat_kind_t)-1) <= 0),
    "ADDRXLAT_NOMETH,ADDRXLAT_CUSTOM,ADDRXLAT_LINEAR,ADDRXLAT_PGT,ADDRXLAT_LOOKUP,ADDRXLAT_MEMARR" },
  { "_addrxlat_optidx", 182, _cffi_prim_int(sizeof(addrxlat_optidx_t), ((addrxlat_optidx_t)-1) <= 0),
    "ADDRXLAT_OPT_NULL,ADDRXLAT_OPT_arch,ADDRXLAT_OPT_os_type,ADDRXLAT_OPT_version_code,ADDRXLAT_OPT_phys_bits,ADDRXLAT_OPT_virt_bits,ADDRXLAT_OPT_page_shift,ADDRXLAT_OPT_phys_base,ADDRXLAT_OPT_rootpgt,ADDRXLAT_OPT_xen_p2m_mfn,ADDRXLAT_OPT_xen_xlat,ADDRXLAT_OPT_NUM" },
  { "_addrxlat_pte_format", 92, _cffi_prim_int(sizeof(addrxlat_pte_format_t), ((addrxlat_pte_format_t)-1) <= 0),
    "ADDRXLAT_PTE_INVALID,ADDRXLAT_PTE_NONE,ADDRXLAT_PTE_PFN32,ADDRXLAT_PTE_PFN64,ADDRXLAT_PTE_AARCH64,ADDRXLAT_PTE_IA32,ADDRXLAT_PTE_IA32_PAE,ADDRXLAT_PTE_X86_64,ADDRXLAT_PTE_S390X,ADDRXLAT_PTE_PPC64_LINUX_RPN30,ADDRXLAT_PTE_AARCH64_LPA,ADDRXLAT_PTE_AARCH64_LPA2,ADDRXLAT_PTE_ARM,ADDRXLAT_PTE_RISCV32,ADDRXLAT_PTE_RISCV64" },
  { "_addrxlat_status", 44, _cffi_prim_int(sizeof(addrxlat_status), ((addrxlat_status)-1) <= 0),
    "ADDRXLAT_OK,ADDRXLAT_ERR_NOTIMPL,ADDRXLAT_ERR_NOTPRESENT,ADDRXLAT_ERR_INVALID,ADDRXLAT_ERR_NOMEM,ADDRXLAT_ERR_NODATA,ADDRXLAT_ERR_NOMETH,ADDRXLAT_ERR_CUSTOM_BASE" },
  { "_addrxlat_sys_map", 13, _cffi_prim_int(sizeof(addrxlat_sys_map_t), ((addrxlat_sys_map_t)-1) <= 0),
    "ADDRXLAT_SYS_MAP_HW,ADDRXLAT_SYS_MAP_KV_PHYS,ADDRXLAT_SYS_MAP_KPHYS_DIRECT,ADDRXLAT_SYS_MAP_MACHPHYS_KPHYS,ADDRXLAT_SYS_MAP_KPHYS_MACHPHYS,ADDRXLAT_SYS_MAP_NUM" },
  { "_addrxlat_sys_meth", 19, _cffi_prim_int(sizeof(addrxlat_sys_meth_t), ((addrxlat_sys_meth_t)-1) <= 0),
    "ADDRXLAT_SYS_METH_NONE,ADDRXLAT_SYS_METH_PGT,ADDRXLAT_SYS_METH_UPGT,ADDRXLAT_SYS_METH_DIRECT,ADDRXLAT_SYS_METH_KTEXT,ADDRXLAT_SYS_METH_VMEMMAP,ADDRXLAT_SYS_METH_RDIRECT,ADDRXLAT_SYS_METH_MACHPHYS_KPHYS,ADDRXLAT_SYS_METH_KPHYS_MACHPHYS,ADDRXLAT_SYS_METH_CUSTOM" },
};

static const struct _cffi_typename_s _cffi_typenames[] = {
  { "addrxlat_addr_t", 55 },
  { "addrxlat_addrspace_t", 49 },
  { "addrxlat_buffer_t", 169 },
  { "addrxlat_byte_order_t", 170 },
  { "addrxlat_cb_num_value_fn", 37 },
  { "addrxlat_cb_reg_value_fn", 37 },
  { "addrxlat_cb_sym_offsetof_fn", 31 },
  { "addrxlat_cb_sym_sizeof_fn", 37 },
  { "addrxlat_cb_sym_value_fn", 37 },
  { "addrxlat_cb_t", 171 },
  { "addrxlat_ctx_t", 172 },
  { "addrxlat_first_step_fn", 65 },
  { "addrxlat_fulladdr_t", 173 },
  { "addrxlat_get_page_fn", 27 },
  { "addrxlat_kind_t", 174 },
  { "addrxlat_lookup_elem_t", 177 },
  { "addrxlat_map_t", 178 },
  { "addrxlat_meth_t", 179 },
  { "addrxlat_next_step_fn", 62 },
  { "addrxlat_off_t", 203 },
  { "addrxlat_op_ctl_t", 180 },
  { "addrxlat_op_fn", 75 },
  { "addrxlat_opt_t", 181 },
  { "addrxlat_optidx_t", 182 },
  { "addrxlat_optval_t", 183 },
  { "addrxlat_paging_form_t", 184 },
  { "addrxlat_param_custom_t", 185 },
  { "addrxlat_param_linear_t", 186 },
  { "addrxlat_param_lookup_t", 187 },
  { "addrxlat_param_memarr_t", 188 },
  { "addrxlat_param_pgt_t", 189 },
  { "addrxlat_param_t", 190 },
  { "addrxlat_pte_format_t", 92 },
  { "addrxlat_pte_t", 55 },
  { "addrxlat_put_page_fn", 130 },
  { "addrxlat_range_t", 191 },
  { "addrxlat_read_caps_fn", 103 },
  { "addrxlat_status", 44 },
  { "addrxlat_step_t", 199 },
  { "addrxlat_sys_map_t", 13 },
  { "addrxlat_sys_meth_t", 19 },
  { "addrxlat_sys_t", 200 },
};

static const struct _cffi_type_context_s _cffi_type_context = {
  _cffi_types,
  _cffi_globals,
  _cffi_fields,
  _cffi_struct_unions,
  _cffi_enums,
  _cffi_typenames,
  133,  /* num_globals */
  21,  /* num_struct_unions */
  8,  /* num_enums */
  42,  /* num_typenames */
  NULL,  /* no includes */
  214,  /* num_types */
  1,  /* flags */
};

#ifdef __GNUC__
#  pragma GCC visibility push(default)  /* for -fvisibility= */
#endif

#ifdef PYPY_VERSION
PyMODINIT_FUNC
_cffi_pypyinit__addrxlat(const void *p[])
{
    if (((intptr_t)p[0]) >= 0x0A03) {
        _cffi_call_python_org = (void(*)(struct _cffi_externpy_s *, char *))p[1];
    }
    p[0] = (const void *)0x2601;
    p[1] = &_cffi_type_context;
#if PY_MAJOR_VERSION >= 3
    return NULL;
#endif
}
#  ifdef _MSC_VER
     PyMODINIT_FUNC
#  if PY_MAJOR_VERSION >= 3
     PyInit__addrxlat(void) { return NULL; }
#  else
     init_addrxlat(void) { }
#  endif
#  endif
#elif PY_MAJOR_VERSION >= 3
PyMODINIT_FUNC
PyInit__addrxlat(void)
{
  return _cffi_init("_addrxlat", 0x2601, &_cffi_type_context);
}
#else
PyMODINIT_FUNC
init_addrxlat(void)
{
  _cffi_init("_addrxlat", 0x2601, &_cffi_type_context);
}
#endif

#ifdef __GNUC__
#  pragma GCC visibility pop
#endif
