#define _CFFI_

/* We try to define Py_LIMITED_API before including Python.h.

   Mess: we can only define it if Py_DEBUG, Py_TRACE_REFS and
   Py_REF_DEBUG are not defined.  This is a best-effort approximation:
   we can learn about Py_DEBUG from pyconfig.h, but it is unclear if
   the same works for the other two macros.  Py_DEBUG implies them,
   but not the other way around.

   The implementation is messy (issue #350): on Windows, with _MSC_VER,
   we have to define Py_LIMITED_API even before including pyconfig.h.
   In that case, we guess what pyconfig.h will do to the macros above,
   and check our guess after the #include.

   Note that on Windows, with CPython 3.x, you need >= 3.5 and virtualenv
   version >= 16.0.0.  With older versions of either, you don't get a
   copy of PYTHON3.DLL in the virtualenv.  We can't check the version of
   CPython *before* we even include pyconfig.h.  ffi.set_source() puts
   a ``#define _CFFI_NO_LIMITED_API'' at the start of this file if it is
   running on Windows < 3.5, as an attempt at fixing it, but that's
   arguably wrong because it may not be the target version of Python.
   Still better than nothing I guess.  As another workaround, you can
   remove the definition of Py_LIMITED_API here.

   See also 'py_limited_api' in cffi/setuptools_ext.py.
*/
#if !defined(_CFFI_USE_EMBEDDING) && !defined(Py_LIMITED_API)
#  ifdef _MSC_VER
#    if !defined(_DEBUG) && !defined(Py_DEBUG) && !defined(Py_TRACE_REFS) && !defined(Py_REF_DEBUG) && !defined(_CFFI_NO_LIMITED_API)
#      define Py_LIMITED_API
#    endif
#    include <pyconfig.h>
     /* sanity-check: Py_LIMITED_API will cause crashes if any of these
        are also defined.  Normally, the Python file PC/pyconfig.h does not
        cause any of these to be defined, with the exception that _DEBUG
        causes Py_DEBUG.  Double-check that. */
#    ifdef Py_LIMITED_API
#      if defined(Py_DEBUG)
#        error "pyconfig.h unexpectedly defines Py_DEBUG, but Py_LIMITED_API is set"
#      endif
#      if defined(Py_TRACE_REFS)
#        error "pyconfig.h unexpectedly defines Py_TRACE_REFS, but Py_LIMITED_API is set"
#      endif
#      if defined(Py_REF_DEBUG)
#        error "pyconfig.h unexpectedly defines Py_REF_DEBUG, but Py_LIMITED_API is set"
#      endif
#    endif
#  else
#    include <pyconfig.h>
#    if !defined(Py_DEBUG) && !defined(Py_TRACE_REFS) && !defined(Py_REF_DEBUG) && !defined(_CFFI_NO_LIMITED_API)
#      define Py_LIMITED_API
#    endif
#  endif
#endif

#include <Python.h>
#ifdef __cplusplus
extern "C" {
#endif
#include <stddef.h>

/* This part is from file 'cffi/parse_c_type.h'.  It is copied at the
   beginning of C sources generated by CFFI's ffi.set_source(). */

typedef void *_cffi_opcode_t;

#define _CFFI_OP(opcode, arg)   (_cffi_opcode_t)(opcode | (((uintptr_t)(arg)) << 8))
#define _CFFI_GETOP(cffi_opcode)    ((unsigned char)(uintptr_t)cffi_opcode)
#define _CFFI_GETARG(cffi_opcode)   (((intptr_t)cffi_opcode) >> 8)

#define _CFFI_OP_PRIMITIVE       1
#define _CFFI_OP_POINTER         3
#define _CFFI_OP_ARRAY           5
#define _CFFI_OP_OPEN_ARRAY      7
#define _CFFI_OP_STRUCT_UNION    9
#define _CFFI_OP_ENUM           11
#define _CFFI_OP_FUNCTION       13
#define _CFFI_OP_FUNCTION_END   15
#define _CFFI_OP_NOOP           17
#define _CFFI_OP_BITFIELD       19
#define _CFFI_OP_TYPENAME       21
#define _CFFI_OP_CPYTHON_BLTN_V 23   // varargs
#define _CFFI_OP_CPYTHON_BLTN_N 25   // noargs
#define _CFFI_OP_CPYTHON_BLTN_O 27   // O  (i.e. a single arg)
#define _CFFI_OP_CONSTANT       29
#define _CFFI_OP_CONSTANT_INT   31
#define _CFFI_OP_GLOBAL_VAR     33
#define _CFFI_OP_DLOPEN_FUNC    35
#define _CFFI_OP_DLOPEN_CONST   37
#define _CFFI_OP_GLOBAL_VAR_F   39
#define _CFFI_OP_EXTERN_PYTHON  41

#define _CFFI_PRIM_VOID          0
#define _CFFI_PRIM_BOOL          1
#define _CFFI_PRIM_CHAR          2
#define _CFFI_PRIM_SCHAR         3
#define _CFFI_PRIM_UCHAR         4
#define _CFFI_PRIM_SHORT         5
#define _CFFI_PRIM_USHORT        6
#define _CFFI_PRIM_INT           7
#define _CFFI_PRIM_UINT          8
#define _CFFI_PRIM_LONG          9
#define _CFFI_PRIM_ULONG        10
#define _CFFI_PRIM_LONGLONG     11
#define _CFFI_PRIM_ULONGLONG    12
#define _CFFI_PRIM_FLOAT        13
#define _CFFI_PRIM_DOUBLE       14
#define _CFFI_PRIM_LONGDOUBLE   15

#define _CFFI_PRIM_WCHAR        16
#define _CFFI_PRIM_INT8         17
#define _CFFI_PRIM_UINT8        18
#define _CFFI_PRIM_INT16        19
#define _CFFI_PRIM_UINT16       20
#define _CFFI_PRIM_INT32        21
#define _CFFI_PRIM_UINT32       22
#define _CFFI_PRIM_INT64        23
#define _CFFI_PRIM_UINT64       24
#define _CFFI_PRIM_INTPTR       25
#define _CFFI_PRIM_UINTPTR      26
#define _CFFI_PRIM_PTRDIFF      27
#define _CFFI_PRIM_SIZE         28
#define _CFFI_PRIM_SSIZE        29
#define _CFFI_PRIM_INT_LEAST8   30
#define _CFFI_PRIM_UINT_LEAST8  31
#define _CFFI_PRIM_INT_LEAST16  32
#define _CFFI_PRIM_UINT_LEAST16 33
#define _CFFI_PRIM_INT_LEAST32  34
#define _CFFI_PRIM_UINT_LEAST32 35
#define _CFFI_PRIM_INT_LEAST64  36
#define _CFFI_PRIM_UINT_LEAST64 37
#define _CFFI_PRIM_INT_FAST8    38
#define _CFFI_PRIM_UINT_FAST8   39
#define _CFFI_PRIM_INT_FAST16   40
#define _CFFI_PRIM_UINT_FAST16  41
#define _CFFI_PRIM_INT_FAST32   42
#define _CFFI_PRIM_UINT_FAST32  43
#define _CFFI_PRIM_INT_FAST64   44
#define _CFFI_PRIM_UINT_FAST64  45
#define _CFFI_PRIM_INTMAX       46
#define _CFFI_PRIM_UINTMAX      47
#define _CFFI_PRIM_FLOATCOMPLEX 48
#define _CFFI_PRIM_DOUBLECOMPLEX 49
#define _CFFI_PRIM_CHAR16       50
#define _CFFI_PRIM_CHAR32       51

#define _CFFI__NUM_PRIM         52
#define _CFFI__UNKNOWN_PRIM           (-1)
#define _CFFI__UNKNOWN_FLOAT_PRIM     (-2)
#define _CFFI__UNKNOWN_LONG_DOUBLE    (-3)

#define _CFFI__IO_FILE_STRUCT         (-1)


struct _cffi_global_s {
    const char *name;
    void *address;
    _cffi_opcode_t type_op;
    void *size_or_direct_fn;  // OP_GLOBAL_VAR: size, or 0 if unknown
                              // OP_CPYTHON_BLTN_*: addr of direct function
};

struct _cffi_getconst_s {
    unsigned long long value;
    const struct _cffi_type_context_s *ctx;
    int gindex;
};

struct _cffi_struct_union_s {
    const char *name;
    int type_index;          // -> _cffi_types, on a OP_STRUCT_UNION
    int flags;               // _CFFI_F_* flags below
    size_t size;
    int alignment;
    int first_field_index;   // -> _cffi_fields array
    int num_fields;
};
#define _CFFI_F_UNION         0x01   // is a union, not a struct
#define _CFFI_F_CHECK_FIELDS  0x02   // complain if fields are not in the
                                     // "standard layout" or if some are missing
#define _CFFI_F_PACKED        0x04   // for CHECK_FIELDS, assume a packed struct
#define _CFFI_F_EXTERNAL      0x08   // in some other ffi.include()
#define _CFFI_F_OPAQUE        0x10   // opaque

struct _cffi_field_s {
    const char *name;
    size_t field_offset;
    size_t field_size;
    _cffi_opcode_t field_type_op;
};

struct _cffi_enum_s {
    const char *name;
    int type_index;          // -> _cffi_types, on a OP_ENUM
    int type_prim;           // _CFFI_PRIM_xxx
    const char *enumerators; // comma-delimited string
};

struct _cffi_typename_s {
    const char *name;
    int type_index;   /* if opaque, points to a possibly artificial
                         OP_STRUCT which is itself opaque */
};

struct _cffi_type_context_s {
    _cffi_opcode_t *types;
    const struct _cffi_global_s *globals;
    const struct _cffi_field_s *fields;
    const struct _cffi_struct_union_s *struct_unions;
    const struct _cffi_enum_s *enums;
    const struct _cffi_typename_s *typenames;
    int num_globals;
    int num_struct_unions;
    int num_enums;
    int num_typenames;
    const char *const *includes;
    int num_types;
    int flags;      /* future extension */
};

struct _cffi_parse_info_s {
    const struct _cffi_type_context_s *ctx;
    _cffi_opcode_t *output;
    unsigned int output_size;
    size_t error_location;
    const char *error_message;
};

struct _cffi_externpy_s {
    const char *name;
    size_t size_of_result;
    void *reserved1, *reserved2;
};

#ifdef _CFFI_INTERNAL
static int parse_c_type(struct _cffi_parse_info_s *info, const char *input);
static int search_in_globals(const struct _cffi_type_context_s *ctx,
                             const char *search, size_t search_len);
static int search_in_struct_unions(const struct _cffi_type_context_s *ctx,
                                   const char *search, size_t search_len);
#endif

/* this block of #ifs should be kept exactly identical between
   c/_cffi_backend.c, cffi/vengine_cpy.py, cffi/vengine_gen.py
   and cffi/_cffi_include.h */
#if defined(_MSC_VER)
# include <malloc.h>   /* for alloca() */
# if _MSC_VER < 1600   /* MSVC < 2010 */
   typedef __int8 int8_t;
   typedef __int16 int16_t;
   typedef __int32 int32_t;
   typedef __int64 int64_t;
   typedef unsigned __int8 uint8_t;
   typedef unsigned __int16 uint16_t;
   typedef unsigned __int32 uint32_t;
   typedef unsigned __int64 uint64_t;
   typedef __int8 int_least8_t;
   typedef __int16 int_least16_t;
   typedef __int32 int_least32_t;
   typedef __int64 int_least64_t;
   typedef unsigned __int8 uint_least8_t;
   typedef unsigned __int16 uint_least16_t;
   typedef unsigned __int32 uint_least32_t;
   typedef unsigned __int64 uint_least64_t;
   typedef __int8 int_fast8_t;
   typedef __int16 int_fast16_t;
   typedef __int32 int_fast32_t;
   typedef __int64 int_fast64_t;
   typedef unsigned __int8 uint_fast8_t;
   typedef unsigned __int16 uint_fast16_t;
   typedef unsigned __int32 uint_fast32_t;
   typedef unsigned __int64 uint_fast64_t;
   typedef __int64 intmax_t;
   typedef unsigned __int64 uintmax_t;
# else
#  include <stdint.h>
# endif
# if _MSC_VER < 1800   /* MSVC < 2013 */
#  ifndef __cplusplus
    typedef unsigned char _Bool;
#  endif
# endif
# define _cffi_float_complex_t   _Fcomplex    /* include <complex.h> for it */
# define _cffi_double_complex_t  _Dcomplex    /* include <complex.h> for it */
#else
# include <stdint.h>
# if (defined (__SVR4) && defined (__sun)) || defined(_AIX) || defined(__hpux)
#  include <alloca.h>
# endif
# define _cffi_float_complex_t   float _Complex
# define _cffi_double_complex_t  double _Complex
#endif

#ifdef __GNUC__
# define _CFFI_UNUSED_FN  __attribute__((unused))
#else
# define _CFFI_UNUSED_FN  /* nothing */
#endif

#ifdef __cplusplus
# ifndef _Bool
   typedef bool _Bool;   /* semi-hackish: C++ has no _Bool; bool is builtin */
# endif
#endif

/**********  CPython-specific section  **********/
#ifndef PYPY_VERSION


#if PY_MAJOR_VERSION >= 3
# define PyInt_FromLong PyLong_FromLong
#endif

#define _cffi_from_c_double PyFloat_FromDouble
#define _cffi_from_c_float PyFloat_FromDouble
#define _cffi_from_c_long PyInt_FromLong
#define _cffi_from_c_ulong PyLong_FromUnsignedLong
#define _cffi_from_c_longlong PyLong_FromLongLong
#define _cffi_from_c_ulonglong PyLong_FromUnsignedLongLong
#define _cffi_from_c__Bool PyBool_FromLong

#define _cffi_to_c_double PyFloat_AsDouble
#define _cffi_to_c_float PyFloat_AsDouble

#define _cffi_from_c_int(x, type)                                        \
    (((type)-1) > 0 ? /* unsigned */                                     \
        (sizeof(type) < sizeof(long) ?                                   \
            PyInt_FromLong((long)x) :                                    \
         sizeof(type) == sizeof(long) ?                                  \
            PyLong_FromUnsignedLong((unsigned long)x) :                  \
            PyLong_FromUnsignedLongLong((unsigned long long)x)) :        \
        (sizeof(type) <= sizeof(long) ?                                  \
            PyInt_FromLong((long)x) :                                    \
            PyLong_FromLongLong((long long)x)))

#define _cffi_to_c_int(o, type)                                          \
    ((type)(                                                             \
     sizeof(type) == 1 ? (((type)-1) > 0 ? (type)_cffi_to_c_u8(o)        \
                                         : (type)_cffi_to_c_i8(o)) :     \
     sizeof(type) == 2 ? (((type)-1) > 0 ? (type)_cffi_to_c_u16(o)       \
                                         : (type)_cffi_to_c_i16(o)) :    \
     sizeof(type) == 4 ? (((type)-1) > 0 ? (type)_cffi_to_c_u32(o)       \
                                         : (type)_cffi_to_c_i32(o)) :    \
     sizeof(type) == 8 ? (((type)-1) > 0 ? (type)_cffi_to_c_u64(o)       \
                                         : (type)_cffi_to_c_i64(o)) :    \
     (Py_FatalError("unsupported size for type " #type), (type)0)))

#define _cffi_to_c_i8                                                    \
                 ((int(*)(PyObject *))_cffi_exports[1])
#define _cffi_to_c_u8                                                    \
                 ((int(*)(PyObject *))_cffi_exports[2])
#define _cffi_to_c_i16                                                   \
                 ((int(*)(PyObject *))_cffi_exports[3])
#define _cffi_to_c_u16                                                   \
                 ((int(*)(PyObject *))_cffi_exports[4])
#define _cffi_to_c_i32                                                   \
                 ((int(*)(PyObject *))_cffi_exports[5])
#define _cffi_to_c_u32                                                   \
                 ((unsigned int(*)(PyObject *))_cffi_exports[6])
#define _cffi_to_c_i64                                                   \
                 ((long long(*)(PyObject *))_cffi_exports[7])
#define _cffi_to_c_u64                                                   \
                 ((unsigned long long(*)(PyObject *))_cffi_exports[8])
#define _cffi_to_c_char                                                  \
                 ((int(*)(PyObject *))_cffi_exports[9])
#define _cffi_from_c_pointer                                             \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[10])
#define _cffi_to_c_pointer                                               \
    ((char *(*)(PyObject *, struct _cffi_ctypedescr *))_cffi_exports[11])
#define _cffi_get_struct_layout                                          \
    not used any more
#define _cffi_restore_errno                                              \
    ((void(*)(void))_cffi_exports[13])
#define _cffi_save_errno                                                 \
    ((void(*)(void))_cffi_exports[14])
#define _cffi_from_c_char                                                \
    ((PyObject *(*)(char))_cffi_exports[15])
#define _cffi_from_c_deref                                               \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[16])
#define _cffi_to_c                                                       \
    ((int(*)(char *, struct _cffi_ctypedescr *, PyObject *))_cffi_exports[17])
#define _cffi_from_c_struct                                              \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[18])
#define _cffi_to_c_wchar_t                                               \
    ((_cffi_wchar_t(*)(PyObject *))_cffi_exports[19])
#define _cffi_from_c_wchar_t                                             \
    ((PyObject *(*)(_cffi_wchar_t))_cffi_exports[20])
#define _cffi_to_c_long_double                                           \
    ((long double(*)(PyObject *))_cffi_exports[21])
#define _cffi_to_c__Bool                                                 \
    ((_Bool(*)(PyObject *))_cffi_exports[22])
#define _cffi_prepare_pointer_call_argument                              \
    ((Py_ssize_t(*)(struct _cffi_ctypedescr *,                           \
                    PyObject *, char **))_cffi_exports[23])
#define _cffi_convert_array_from_object                                  \
    ((int(*)(char *, struct _cffi_ctypedescr *, PyObject *))_cffi_exports[24])
#define _CFFI_CPIDX  25
#define _cffi_call_python                                                \
    ((void(*)(struct _cffi_externpy_s *, char *))_cffi_exports[_CFFI_CPIDX])
#define _cffi_to_c_wchar3216_t                                           \
    ((int(*)(PyObject *))_cffi_exports[26])
#define _cffi_from_c_wchar3216_t                                         \
    ((PyObject *(*)(int))_cffi_exports[27])
#define _CFFI_NUM_EXPORTS 28

struct _cffi_ctypedescr;

static void *_cffi_exports[_CFFI_NUM_EXPORTS];

#define _cffi_type(index)   (                           \
    assert((((uintptr_t)_cffi_types[index]) & 1) == 0), \
    (struct _cffi_ctypedescr *)_cffi_types[index])

static PyObject *_cffi_init(const char *module_name, Py_ssize_t version,
                            const struct _cffi_type_context_s *ctx)
{
    PyObject *module, *o_arg, *new_module;
    void *raw[] = {
        (void *)module_name,
        (void *)version,
        (void *)_cffi_exports,
        (void *)ctx,
    };

    module = PyImport_ImportModule("_cffi_backend");
    if (module == NULL)
        goto failure;

    o_arg = PyLong_FromVoidPtr((void *)raw);
    if (o_arg == NULL)
        goto failure;

    new_module = PyObject_CallMethod(
        module, (char *)"_init_cffi_1_0_external_module", (char *)"O", o_arg);

    Py_DECREF(o_arg);
    Py_DECREF(module);
    return new_module;

  failure:
    Py_XDECREF(module);
    return NULL;
}


#ifdef HAVE_WCHAR_H
typedef wchar_t _cffi_wchar_t;
#else
typedef uint16_t _cffi_wchar_t;   /* same random pick as _cffi_backend.c */
#endif

_CFFI_UNUSED_FN static uint16_t _cffi_to_c_char16_t(PyObject *o)
{
    if (sizeof(_cffi_wchar_t) == 2)
        return (uint16_t)_cffi_to_c_wchar_t(o);
    else
        return (uint16_t)_cffi_to_c_wchar3216_t(o);
}

_CFFI_UNUSED_FN static PyObject *_cffi_from_c_char16_t(uint16_t x)
{
    if (sizeof(_cffi_wchar_t) == 2)
        return _cffi_from_c_wchar_t((_cffi_wchar_t)x);
    else
        return _cffi_from_c_wchar3216_t((int)x);
}

_CFFI_UNUSED_FN static int _cffi_to_c_char32_t(PyObject *o)
{
    if (sizeof(_cffi_wchar_t) == 4)
        return (int)_cffi_to_c_wchar_t(o);
    else
        return (int)_cffi_to_c_wchar3216_t(o);
}

_CFFI_UNUSED_FN static PyObject *_cffi_from_c_char32_t(unsigned int x)
{
    if (sizeof(_cffi_wchar_t) == 4)
        return _cffi_from_c_wchar_t((_cffi_wchar_t)x);
    else
        return _cffi_from_c_wchar3216_t((int)x);
}

union _cffi_union_alignment_u {
    unsigned char m_char;
    unsigned short m_short;
    unsigned int m_int;
    unsigned long m_long;
    unsigned long long m_longlong;
    float m_float;
    double m_double;
    long double m_longdouble;
};

struct _cffi_freeme_s {
    struct _cffi_freeme_s *next;
    union _cffi_union_alignment_u alignment;
};

_CFFI_UNUSED_FN static int
_cffi_convert_array_argument(struct _cffi_ctypedescr *ctptr, PyObject *arg,
                             char **output_data, Py_ssize_t datasize,
                             struct _cffi_freeme_s **freeme)
{
    char *p;
    if (datasize < 0)
        return -1;

    p = *output_data;
    if (p == NULL) {
        struct _cffi_freeme_s *fp = (struct _cffi_freeme_s *)PyObject_Malloc(
            offsetof(struct _cffi_freeme_s, alignment) + (size_t)datasize);
        if (fp == NULL)
            return -1;
        fp->next = *freeme;
        *freeme = fp;
        p = *output_data = (char *)&fp->alignment;
    }
    memset((void *)p, 0, (size_t)datasize);
    return _cffi_convert_array_from_object(p, ctptr, arg);
}

_CFFI_UNUSED_FN static void
_cffi_free_array_arguments(struct _cffi_freeme_s *freeme)
{
    do {
        void *p = (void *)freeme;
        freeme = freeme->next;
        PyObject_Free(p);
    } while (freeme != NULL);
}

/**********  end CPython-specific section  **********/
#else
_CFFI_UNUSED_FN
static void (*_cffi_call_python_org)(struct _cffi_externpy_s *, char *);
# define _cffi_call_python  _cffi_call_python_org
#endif


#define _cffi_array_len(array)   (sizeof(array) / sizeof((array)[0]))

#define _cffi_prim_int(size, sign)                                      \
    ((size) == 1 ? ((sign) ? _CFFI_PRIM_INT8  : _CFFI_PRIM_UINT8)  :    \
     (size) == 2 ? ((sign) ? _CFFI_PRIM_INT16 : _CFFI_PRIM_UINT16) :    \
     (size) == 4 ? ((sign) ? _CFFI_PRIM_INT32 : _CFFI_PRIM_UINT32) :    \
     (size) == 8 ? ((sign) ? _CFFI_PRIM_INT64 : _CFFI_PRIM_UINT64) :    \
     _CFFI__UNKNOWN_PRIM)

#define _cffi_prim_float(size)                                          \
    ((size) == sizeof(float) ? _CFFI_PRIM_FLOAT :                       \
     (size) == sizeof(double) ? _CFFI_PRIM_DOUBLE :                     \
     (size) == sizeof(long double) ? _CFFI__UNKNOWN_LONG_DOUBLE :       \
     _CFFI__UNKNOWN_FLOAT_PRIM)

#define _cffi_check_int(got, got_nonpos, expected)      \
    ((got_nonpos) == (expected <= 0) &&                 \
     (got) == (unsigned long long)expected)

#ifdef MS_WIN32
# define _cffi_stdcall  __stdcall
#else
# define _cffi_stdcall  /* nothing */
#endif

#ifdef __cplusplus
}
#endif

/************************************************************/


#include <libkdumpfile/kdumpfile.h>
#include <stdlib.h>


/************************************************************/

static void *_cffi_types[] = {
/*  0 */ _CFFI_OP(_CFFI_OP_FUNCTION, 333), // addrxlat_cb_t *()(addrxlat_ctx_t *)
/*  1 */ _CFFI_OP(_CFFI_OP_POINTER, 382), // addrxlat_ctx_t *
/*  2 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/*  3 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // addrxlat_cb_t const *()(addrxlat_ctx_t const *)
/*  4 */ _CFFI_OP(_CFFI_OP_POINTER, 382), // addrxlat_ctx_t const *
/*  5 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/*  6 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // addrxlat_ctx_t *()(void)
/*  7 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/*  8 */ _CFFI_OP(_CFFI_OP_FUNCTION, 54), // addrxlat_map_t *()(addrxlat_map_t const *)
/*  9 */ _CFFI_OP(_CFFI_OP_POINTER, 388), // addrxlat_map_t const *
/* 10 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 11 */ _CFFI_OP(_CFFI_OP_FUNCTION, 54), // addrxlat_map_t *()(addrxlat_sys_t const *, addrxlat_sys_map_t)
/* 12 */ _CFFI_OP(_CFFI_OP_POINTER, 410), // addrxlat_sys_t const *
/* 13 */ _CFFI_OP(_CFFI_OP_ENUM, 6), // addrxlat_sys_map_t
/* 14 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 15 */ _CFFI_OP(_CFFI_OP_FUNCTION, 54), // addrxlat_map_t *()(void)
/* 16 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 17 */ _CFFI_OP(_CFFI_OP_FUNCTION, 359), // addrxlat_meth_t const *()(addrxlat_sys_t const *, addrxlat_sys_meth_t)
/* 18 */ _CFFI_OP(_CFFI_OP_NOOP, 12),
/* 19 */ _CFFI_OP(_CFFI_OP_ENUM, 7), // addrxlat_sys_meth_t
/* 20 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 21 */ _CFFI_OP(_CFFI_OP_FUNCTION, 92), // addrxlat_pte_format_t()(char const *)
/* 22 */ _CFFI_OP(_CFFI_OP_POINTER, 412), // char const *
/* 23 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 24 */ _CFFI_OP(_CFFI_OP_FUNCTION, 56), // addrxlat_range_t const *()(addrxlat_map_t const *)
/* 25 */ _CFFI_OP(_CFFI_OP_NOOP, 9),
/* 26 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 27 */ _CFFI_OP(_CFFI_OP_FUNCTION, 44), // addrxlat_status()(addrxlat_cb_t const *, addrxlat_buffer_t *)
/* 28 */ _CFFI_OP(_CFFI_OP_POINTER, 381), // addrxlat_cb_t const *
/* 29 */ _CFFI_OP(_CFFI_OP_POINTER, 379), // addrxlat_buffer_t *
/* 30 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 31 */ _CFFI_OP(_CFFI_OP_FUNCTION, 44), // addrxlat_status()(addrxlat_cb_t const *, char const *, char const *, uint_fast64_t *)
/* 32 */ _CFFI_OP(_CFFI_OP_NOOP, 28),
/* 33 */ _CFFI_OP(_CFFI_OP_NOOP, 22),
/* 34 */ _CFFI_OP(_CFFI_OP_NOOP, 22),
/* 35 */ _CFFI_OP(_CFFI_OP_POINTER, 55), // uint_fast64_t *
/* 36 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 37 */ _CFFI_OP(_CFFI_OP_FUNCTION, 44), // addrxlat_status()(addrxlat_cb_t const *, char const *, uint_fast64_t *)
/* 38 */ _CFFI_OP(_CFFI_OP_NOOP, 28),
/* 39 */ _CFFI_OP(_CFFI_OP_NOOP, 22),
/* 40 */ _CFFI_OP(_CFFI_OP_NOOP, 35),
/* 41 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 42 */ _CFFI_OP(_CFFI_OP_FUNCTION, 44), // addrxlat_status()(addrxlat_ctx_t *, addrxlat_status, char const *, ...)
/* 43 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/* 44 */ _CFFI_OP(_CFFI_OP_ENUM, 5), // addrxlat_status
/* 45 */ _CFFI_OP(_CFFI_OP_NOOP, 22),
/* 46 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 1),
/* 47 */ _CFFI_OP(_CFFI_OP_FUNCTION, 44), // addrxlat_status()(addrxlat_fulladdr_t *, addrxlat_addrspace_t, addrxlat_ctx_t *, addrxlat_sys_t *)
/* 48 */ _CFFI_OP(_CFFI_OP_POINTER, 383), // addrxlat_fulladdr_t *
/* 49 */ _CFFI_OP(_CFFI_OP_ENUM, 0), // addrxlat_addrspace_t
/* 50 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/* 51 */ _CFFI_OP(_CFFI_OP_POINTER, 410), // addrxlat_sys_t *
/* 52 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 53 */ _CFFI_OP(_CFFI_OP_FUNCTION, 44), // addrxlat_status()(addrxlat_map_t *, uint_fast64_t, addrxlat_range_t const *)
/* 54 */ _CFFI_OP(_CFFI_OP_POINTER, 388), // addrxlat_map_t *
/* 55 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 45), // uint_fast64_t
/* 56 */ _CFFI_OP(_CFFI_OP_POINTER, 401), // addrxlat_range_t const *
/* 57 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 58 */ _CFFI_OP(_CFFI_OP_FUNCTION, 44), // addrxlat_status()(addrxlat_op_ctl_t const *, addrxlat_fulladdr_t const *)
/* 59 */ _CFFI_OP(_CFFI_OP_POINTER, 390), // addrxlat_op_ctl_t const *
/* 60 */ _CFFI_OP(_CFFI_OP_POINTER, 383), // addrxlat_fulladdr_t const *
/* 61 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 62 */ _CFFI_OP(_CFFI_OP_FUNCTION, 44), // addrxlat_status()(addrxlat_step_t *)
/* 63 */ _CFFI_OP(_CFFI_OP_POINTER, 409), // addrxlat_step_t *
/* 64 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 65 */ _CFFI_OP(_CFFI_OP_FUNCTION, 44), // addrxlat_status()(addrxlat_step_t *, uint_fast64_t)
/* 66 */ _CFFI_OP(_CFFI_OP_NOOP, 63),
/* 67 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 45),
/* 68 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 69 */ _CFFI_OP(_CFFI_OP_FUNCTION, 44), // addrxlat_status()(addrxlat_sys_t *, addrxlat_ctx_t *, unsigned int, addrxlat_opt_t const *)
/* 70 */ _CFFI_OP(_CFFI_OP_NOOP, 51),
/* 71 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/* 72 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8), // unsigned int
/* 73 */ _CFFI_OP(_CFFI_OP_POINTER, 391), // addrxlat_opt_t const *
/* 74 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 75 */ _CFFI_OP(_CFFI_OP_FUNCTION, 44), // addrxlat_status()(void *, addrxlat_fulladdr_t const *)
/* 76 */ _CFFI_OP(_CFFI_OP_POINTER, 436), // void *
/* 77 */ _CFFI_OP(_CFFI_OP_NOOP, 60),
/* 78 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 79 */ _CFFI_OP(_CFFI_OP_FUNCTION, 19), // addrxlat_sys_meth_t()(addrxlat_map_t const *, uint_fast64_t)
/* 80 */ _CFFI_OP(_CFFI_OP_NOOP, 9),
/* 81 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 45),
/* 82 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 83 */ _CFFI_OP(_CFFI_OP_FUNCTION, 51), // addrxlat_sys_t *()(void)
/* 84 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 85 */ _CFFI_OP(_CFFI_OP_FUNCTION, 22), // char const *()(addrxlat_addrspace_t)
/* 86 */ _CFFI_OP(_CFFI_OP_NOOP, 49),
/* 87 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 88 */ _CFFI_OP(_CFFI_OP_FUNCTION, 22), // char const *()(addrxlat_ctx_t const *)
/* 89 */ _CFFI_OP(_CFFI_OP_NOOP, 4),
/* 90 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 91 */ _CFFI_OP(_CFFI_OP_FUNCTION, 22), // char const *()(addrxlat_pte_format_t)
/* 92 */ _CFFI_OP(_CFFI_OP_ENUM, 4), // addrxlat_pte_format_t
/* 93 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 94 */ _CFFI_OP(_CFFI_OP_FUNCTION, 22), // char const *()(addrxlat_status)
/* 95 */ _CFFI_OP(_CFFI_OP_NOOP, 44),
/* 96 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 97 */ _CFFI_OP(_CFFI_OP_FUNCTION, 22), // char const *()(kdump_bmp_t const *)
/* 98 */ _CFFI_OP(_CFFI_OP_POINTER, 420), // kdump_bmp_t const *
/* 99 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 100 */ _CFFI_OP(_CFFI_OP_FUNCTION, 22), // char const *()(kdump_ctx_t *)
/* 101 */ _CFFI_OP(_CFFI_OP_POINTER, 422), // kdump_ctx_t *
/* 102 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 103 */ _CFFI_OP(_CFFI_OP_FUNCTION, 22), // char const *()(kdump_status)
/* 104 */ _CFFI_OP(_CFFI_OP_ENUM, 12), // kdump_status
/* 105 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 106 */ _CFFI_OP(_CFFI_OP_FUNCTION, 210), // int()(addrxlat_pte_format_t)
/* 107 */ _CFFI_OP(_CFFI_OP_NOOP, 92),
/* 108 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 109 */ _CFFI_OP(_CFFI_OP_FUNCTION, 210), // int()(kdump_attr_ref_t *)
/* 110 */ _CFFI_OP(_CFFI_OP_POINTER, 416), // kdump_attr_ref_t *
/* 111 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 112 */ _CFFI_OP(_CFFI_OP_FUNCTION, 195), // kdump_attr_type_t()(kdump_attr_ref_t *)
/* 113 */ _CFFI_OP(_CFFI_OP_NOOP, 110),
/* 114 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 115 */ _CFFI_OP(_CFFI_OP_FUNCTION, 130), // kdump_blob_t *()(void *, size_t)
/* 116 */ _CFFI_OP(_CFFI_OP_NOOP, 76),
/* 117 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28), // size_t
/* 118 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 119 */ _CFFI_OP(_CFFI_OP_FUNCTION, 130), // kdump_blob_t *()(void const *, size_t)
/* 120 */ _CFFI_OP(_CFFI_OP_POINTER, 436), // void const *
/* 121 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28),
/* 122 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 123 */ _CFFI_OP(_CFFI_OP_FUNCTION, 101), // kdump_ctx_t *()(kdump_ctx_t const *, unsigned long)
/* 124 */ _CFFI_OP(_CFFI_OP_POINTER, 422), // kdump_ctx_t const *
/* 125 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 10), // unsigned long
/* 126 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 127 */ _CFFI_OP(_CFFI_OP_FUNCTION, 101), // kdump_ctx_t *()(void)
/* 128 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 129 */ _CFFI_OP(_CFFI_OP_FUNCTION, 104), // kdump_status()(kdump_blob_t *, void *, size_t)
/* 130 */ _CFFI_OP(_CFFI_OP_POINTER, 419), // kdump_blob_t *
/* 131 */ _CFFI_OP(_CFFI_OP_NOOP, 76),
/* 132 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28),
/* 133 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 134 */ _CFFI_OP(_CFFI_OP_FUNCTION, 104), // kdump_status()(kdump_bmp_t *, uint_fast64_t *)
/* 135 */ _CFFI_OP(_CFFI_OP_POINTER, 420), // kdump_bmp_t *
/* 136 */ _CFFI_OP(_CFFI_OP_NOOP, 35),
/* 137 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 138 */ _CFFI_OP(_CFFI_OP_FUNCTION, 104), // kdump_status()(kdump_bmp_t *, uint_fast64_t, uint_fast64_t, unsigned char *)
/* 139 */ _CFFI_OP(_CFFI_OP_NOOP, 135),
/* 140 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 45),
/* 141 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 45),
/* 142 */ _CFFI_OP(_CFFI_OP_POINTER, 430), // unsigned char *
/* 143 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 144 */ _CFFI_OP(_CFFI_OP_FUNCTION, 104), // kdump_status()(kdump_ctx_t *, addrxlat_ctx_t * *, addrxlat_sys_t * *)
/* 145 */ _CFFI_OP(_CFFI_OP_NOOP, 101),
/* 146 */ _CFFI_OP(_CFFI_OP_POINTER, 1), // addrxlat_ctx_t * *
/* 147 */ _CFFI_OP(_CFFI_OP_POINTER, 51), // addrxlat_sys_t * *
/* 148 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 149 */ _CFFI_OP(_CFFI_OP_FUNCTION, 104), // kdump_status()(kdump_ctx_t *, char * *)
/* 150 */ _CFFI_OP(_CFFI_OP_NOOP, 101),
/* 151 */ _CFFI_OP(_CFFI_OP_POINTER, 411), // char * *
/* 152 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 153 */ _CFFI_OP(_CFFI_OP_FUNCTION, 104), // kdump_status()(kdump_ctx_t *, char const *)
/* 154 */ _CFFI_OP(_CFFI_OP_NOOP, 101),
/* 155 */ _CFFI_OP(_CFFI_OP_NOOP, 22),
/* 156 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 157 */ _CFFI_OP(_CFFI_OP_FUNCTION, 104), // kdump_status()(kdump_ctx_t *, char const *, char * *)
/* 158 */ _CFFI_OP(_CFFI_OP_NOOP, 101),
/* 159 */ _CFFI_OP(_CFFI_OP_NOOP, 22),
/* 160 */ _CFFI_OP(_CFFI_OP_NOOP, 151),
/* 161 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 162 */ _CFFI_OP(_CFFI_OP_FUNCTION, 104), // kdump_status()(kdump_ctx_t *, char const *, char const * *)
/* 163 */ _CFFI_OP(_CFFI_OP_NOOP, 101),
/* 164 */ _CFFI_OP(_CFFI_OP_NOOP, 22),
/* 165 */ _CFFI_OP(_CFFI_OP_POINTER, 22), // char const * *
/* 166 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 167 */ _CFFI_OP(_CFFI_OP_FUNCTION, 104), // kdump_status()(kdump_ctx_t *, char const *, char const *)
/* 168 */ _CFFI_OP(_CFFI_OP_NOOP, 101),
/* 169 */ _CFFI_OP(_CFFI_OP_NOOP, 22),
/* 170 */ _CFFI_OP(_CFFI_OP_NOOP, 22),
/* 171 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 172 */ _CFFI_OP(_CFFI_OP_FUNCTION, 104), // kdump_status()(kdump_ctx_t *, char const *, kdump_attr_iter_t *)
/* 173 */ _CFFI_OP(_CFFI_OP_NOOP, 101),
/* 174 */ _CFFI_OP(_CFFI_OP_NOOP, 22),
/* 175 */ _CFFI_OP(_CFFI_OP_POINTER, 415), // kdump_attr_iter_t *
/* 176 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 177 */ _CFFI_OP(_CFFI_OP_FUNCTION, 104), // kdump_status()(kdump_ctx_t *, char const *, kdump_attr_ref_t *)
/* 178 */ _CFFI_OP(_CFFI_OP_NOOP, 101),
/* 179 */ _CFFI_OP(_CFFI_OP_NOOP, 22),
/* 180 */ _CFFI_OP(_CFFI_OP_NOOP, 110),
/* 181 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 182 */ _CFFI_OP(_CFFI_OP_FUNCTION, 104), // kdump_status()(kdump_ctx_t *, char const *, kdump_attr_t *)
/* 183 */ _CFFI_OP(_CFFI_OP_NOOP, 101),
/* 184 */ _CFFI_OP(_CFFI_OP_NOOP, 22),
/* 185 */ _CFFI_OP(_CFFI_OP_POINTER, 417), // kdump_attr_t *
/* 186 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 187 */ _CFFI_OP(_CFFI_OP_FUNCTION, 104), // kdump_status()(kdump_ctx_t *, char const *, kdump_attr_t const *)
/* 188 */ _CFFI_OP(_CFFI_OP_NOOP, 101),
/* 189 */ _CFFI_OP(_CFFI_OP_NOOP, 22),
/* 190 */ _CFFI_OP(_CFFI_OP_POINTER, 417), // kdump_attr_t const *
/* 191 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 192 */ _CFFI_OP(_CFFI_OP_FUNCTION, 104), // kdump_status()(kdump_ctx_t *, char const *, kdump_attr_type_t, kdump_attr_value_t *)
/* 193 */ _CFFI_OP(_CFFI_OP_NOOP, 101),
/* 194 */ _CFFI_OP(_CFFI_OP_NOOP, 22),
/* 195 */ _CFFI_OP(_CFFI_OP_ENUM, 9), // kdump_attr_type_t
/* 196 */ _CFFI_OP(_CFFI_OP_POINTER, 418), // kdump_attr_value_t *
/* 197 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 198 */ _CFFI_OP(_CFFI_OP_FUNCTION, 104), // kdump_status()(kdump_ctx_t *, char const *, uint_fast64_t *)
/* 199 */ _CFFI_OP(_CFFI_OP_NOOP, 101),
/* 200 */ _CFFI_OP(_CFFI_OP_NOOP, 22),
/* 201 */ _CFFI_OP(_CFFI_OP_NOOP, 35),
/* 202 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 203 */ _CFFI_OP(_CFFI_OP_FUNCTION, 104), // kdump_status()(kdump_ctx_t *, char const *, uint_fast64_t)
/* 204 */ _CFFI_OP(_CFFI_OP_NOOP, 101),
/* 205 */ _CFFI_OP(_CFFI_OP_NOOP, 22),
/* 206 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 45),
/* 207 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 208 */ _CFFI_OP(_CFFI_OP_FUNCTION, 104), // kdump_status()(kdump_ctx_t *, int)
/* 209 */ _CFFI_OP(_CFFI_OP_NOOP, 101),
/* 210 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7), // int
/* 211 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 212 */ _CFFI_OP(_CFFI_OP_FUNCTION, 104), // kdump_status()(kdump_ctx_t *, kdump_addrspace_t, uint_fast64_t, char * *)
/* 213 */ _CFFI_OP(_CFFI_OP_NOOP, 101),
/* 214 */ _CFFI_OP(_CFFI_OP_ENUM, 8), // kdump_addrspace_t
/* 215 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 45),
/* 216 */ _CFFI_OP(_CFFI_OP_NOOP, 151),
/* 217 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 218 */ _CFFI_OP(_CFFI_OP_FUNCTION, 104), // kdump_status()(kdump_ctx_t *, kdump_addrspace_t, uint_fast64_t, void *, size_t *)
/* 219 */ _CFFI_OP(_CFFI_OP_NOOP, 101),
/* 220 */ _CFFI_OP(_CFFI_OP_NOOP, 214),
/* 221 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 45),
/* 222 */ _CFFI_OP(_CFFI_OP_NOOP, 76),
/* 223 */ _CFFI_OP(_CFFI_OP_POINTER, 117), // size_t *
/* 224 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 225 */ _CFFI_OP(_CFFI_OP_FUNCTION, 104), // kdump_status()(kdump_ctx_t *, kdump_attr_iter_t *)
/* 226 */ _CFFI_OP(_CFFI_OP_NOOP, 101),
/* 227 */ _CFFI_OP(_CFFI_OP_NOOP, 175),
/* 228 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 229 */ _CFFI_OP(_CFFI_OP_FUNCTION, 104), // kdump_status()(kdump_ctx_t *, kdump_attr_ref_t *, kdump_attr_t const *)
/* 230 */ _CFFI_OP(_CFFI_OP_NOOP, 101),
/* 231 */ _CFFI_OP(_CFFI_OP_NOOP, 110),
/* 232 */ _CFFI_OP(_CFFI_OP_NOOP, 190),
/* 233 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 234 */ _CFFI_OP(_CFFI_OP_FUNCTION, 104), // kdump_status()(kdump_ctx_t *, kdump_attr_ref_t const *, char const *, kdump_attr_ref_t *)
/* 235 */ _CFFI_OP(_CFFI_OP_NOOP, 101),
/* 236 */ _CFFI_OP(_CFFI_OP_POINTER, 416), // kdump_attr_ref_t const *
/* 237 */ _CFFI_OP(_CFFI_OP_NOOP, 22),
/* 238 */ _CFFI_OP(_CFFI_OP_NOOP, 110),
/* 239 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 240 */ _CFFI_OP(_CFFI_OP_FUNCTION, 104), // kdump_status()(kdump_ctx_t *, kdump_attr_ref_t const *, char const *, kdump_attr_t const *)
/* 241 */ _CFFI_OP(_CFFI_OP_NOOP, 101),
/* 242 */ _CFFI_OP(_CFFI_OP_NOOP, 236),
/* 243 */ _CFFI_OP(_CFFI_OP_NOOP, 22),
/* 244 */ _CFFI_OP(_CFFI_OP_NOOP, 190),
/* 245 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 246 */ _CFFI_OP(_CFFI_OP_FUNCTION, 104), // kdump_status()(kdump_ctx_t *, kdump_attr_ref_t const *, kdump_attr_iter_t *)
/* 247 */ _CFFI_OP(_CFFI_OP_NOOP, 101),
/* 248 */ _CFFI_OP(_CFFI_OP_NOOP, 236),
/* 249 */ _CFFI_OP(_CFFI_OP_NOOP, 175),
/* 250 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 251 */ _CFFI_OP(_CFFI_OP_FUNCTION, 104), // kdump_status()(kdump_ctx_t *, kdump_attr_ref_t const *, kdump_attr_t *)
/* 252 */ _CFFI_OP(_CFFI_OP_NOOP, 101),
/* 253 */ _CFFI_OP(_CFFI_OP_NOOP, 236),
/* 254 */ _CFFI_OP(_CFFI_OP_NOOP, 185),
/* 255 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 256 */ _CFFI_OP(_CFFI_OP_FUNCTION, 104), // kdump_status()(kdump_ctx_t *, kdump_status, char const *, ...)
/* 257 */ _CFFI_OP(_CFFI_OP_NOOP, 101),
/* 258 */ _CFFI_OP(_CFFI_OP_NOOP, 104),
/* 259 */ _CFFI_OP(_CFFI_OP_NOOP, 22),
/* 260 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 1),
/* 261 */ _CFFI_OP(_CFFI_OP_FUNCTION, 104), // kdump_status()(kdump_ctx_t *, unsigned int, char const * const *)
/* 262 */ _CFFI_OP(_CFFI_OP_NOOP, 101),
/* 263 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 264 */ _CFFI_OP(_CFFI_OP_POINTER, 22), // char const * const *
/* 265 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 266 */ _CFFI_OP(_CFFI_OP_FUNCTION, 104), // kdump_status()(kdump_ctx_t *, unsigned int, int const *)
/* 267 */ _CFFI_OP(_CFFI_OP_NOOP, 101),
/* 268 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 269 */ _CFFI_OP(_CFFI_OP_POINTER, 210), // int const *
/* 270 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 271 */ _CFFI_OP(_CFFI_OP_FUNCTION, 117), // size_t()(addrxlat_map_t const *)
/* 272 */ _CFFI_OP(_CFFI_OP_NOOP, 9),
/* 273 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 274 */ _CFFI_OP(_CFFI_OP_FUNCTION, 117), // size_t()(kdump_blob_t const *)
/* 275 */ _CFFI_OP(_CFFI_OP_POINTER, 419), // kdump_blob_t const *
/* 276 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 277 */ _CFFI_OP(_CFFI_OP_FUNCTION, 279), // uint_fast16_t()(kdump_ctx_t *, uint_fast16_t)
/* 278 */ _CFFI_OP(_CFFI_OP_NOOP, 101),
/* 279 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 41), // uint_fast16_t
/* 280 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 281 */ _CFFI_OP(_CFFI_OP_FUNCTION, 283), // uint_fast32_t()(kdump_ctx_t *, uint_fast32_t)
/* 282 */ _CFFI_OP(_CFFI_OP_NOOP, 101),
/* 283 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 43), // uint_fast32_t
/* 284 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 285 */ _CFFI_OP(_CFFI_OP_FUNCTION, 55), // uint_fast64_t()(kdump_ctx_t *, uint_fast64_t)
/* 286 */ _CFFI_OP(_CFFI_OP_NOOP, 101),
/* 287 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 45),
/* 288 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 289 */ _CFFI_OP(_CFFI_OP_FUNCTION, 125), // unsigned long()(addrxlat_cb_t const *)
/* 290 */ _CFFI_OP(_CFFI_OP_NOOP, 28),
/* 291 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 292 */ _CFFI_OP(_CFFI_OP_FUNCTION, 125), // unsigned long()(addrxlat_ctx_t *)
/* 293 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/* 294 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 295 */ _CFFI_OP(_CFFI_OP_FUNCTION, 125), // unsigned long()(addrxlat_map_t *)
/* 296 */ _CFFI_OP(_CFFI_OP_NOOP, 54),
/* 297 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 298 */ _CFFI_OP(_CFFI_OP_FUNCTION, 125), // unsigned long()(addrxlat_sys_t *)
/* 299 */ _CFFI_OP(_CFFI_OP_NOOP, 51),
/* 300 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 301 */ _CFFI_OP(_CFFI_OP_FUNCTION, 125), // unsigned long()(kdump_blob_t *)
/* 302 */ _CFFI_OP(_CFFI_OP_NOOP, 130),
/* 303 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 304 */ _CFFI_OP(_CFFI_OP_FUNCTION, 125), // unsigned long()(kdump_bmp_t *)
/* 305 */ _CFFI_OP(_CFFI_OP_NOOP, 135),
/* 306 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 307 */ _CFFI_OP(_CFFI_OP_FUNCTION, 125), // unsigned long()(unsigned int)
/* 308 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 309 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 310 */ _CFFI_OP(_CFFI_OP_FUNCTION, 125), // unsigned long()(unsigned int, unsigned int)
/* 311 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 312 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 313 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 314 */ _CFFI_OP(_CFFI_OP_FUNCTION, 125), // unsigned long()(unsigned int, unsigned int, unsigned int)
/* 315 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 316 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 317 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 318 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 319 */ _CFFI_OP(_CFFI_OP_FUNCTION, 76), // void *()(kdump_blob_t *)
/* 320 */ _CFFI_OP(_CFFI_OP_NOOP, 130),
/* 321 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 322 */ _CFFI_OP(_CFFI_OP_FUNCTION, 76), // void *()(size_t)
/* 323 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28),
/* 324 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 325 */ _CFFI_OP(_CFFI_OP_FUNCTION, 436), // void()(addrxlat_buffer_t const *)
/* 326 */ _CFFI_OP(_CFFI_OP_POINTER, 379), // addrxlat_buffer_t const *
/* 327 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 328 */ _CFFI_OP(_CFFI_OP_FUNCTION, 436), // void()(addrxlat_ctx_t *)
/* 329 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/* 330 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 331 */ _CFFI_OP(_CFFI_OP_FUNCTION, 436), // void()(addrxlat_ctx_t *, addrxlat_cb_t *)
/* 332 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/* 333 */ _CFFI_OP(_CFFI_OP_POINTER, 381), // addrxlat_cb_t *
/* 334 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 335 */ _CFFI_OP(_CFFI_OP_FUNCTION, 436), // void()(addrxlat_opt_t *, addrxlat_fulladdr_t const *)
/* 336 */ _CFFI_OP(_CFFI_OP_POINTER, 391), // addrxlat_opt_t *
/* 337 */ _CFFI_OP(_CFFI_OP_NOOP, 60),
/* 338 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 339 */ _CFFI_OP(_CFFI_OP_FUNCTION, 436), // void()(addrxlat_opt_t *, char const *)
/* 340 */ _CFFI_OP(_CFFI_OP_NOOP, 336),
/* 341 */ _CFFI_OP(_CFFI_OP_NOOP, 22),
/* 342 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 343 */ _CFFI_OP(_CFFI_OP_FUNCTION, 436), // void()(addrxlat_opt_t *, uint_fast64_t)
/* 344 */ _CFFI_OP(_CFFI_OP_NOOP, 336),
/* 345 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 45),
/* 346 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 347 */ _CFFI_OP(_CFFI_OP_FUNCTION, 436), // void()(addrxlat_opt_t *, unsigned long)
/* 348 */ _CFFI_OP(_CFFI_OP_NOOP, 336),
/* 349 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 10),
/* 350 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 351 */ _CFFI_OP(_CFFI_OP_FUNCTION, 436), // void()(addrxlat_sys_t *, addrxlat_sys_map_t, addrxlat_map_t *)
/* 352 */ _CFFI_OP(_CFFI_OP_NOOP, 51),
/* 353 */ _CFFI_OP(_CFFI_OP_NOOP, 13),
/* 354 */ _CFFI_OP(_CFFI_OP_NOOP, 54),
/* 355 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 356 */ _CFFI_OP(_CFFI_OP_FUNCTION, 436), // void()(addrxlat_sys_t *, addrxlat_sys_meth_t, addrxlat_meth_t const *)
/* 357 */ _CFFI_OP(_CFFI_OP_NOOP, 51),
/* 358 */ _CFFI_OP(_CFFI_OP_NOOP, 19),
/* 359 */ _CFFI_OP(_CFFI_OP_POINTER, 389), // addrxlat_meth_t const *
/* 360 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 361 */ _CFFI_OP(_CFFI_OP_FUNCTION, 436), // void()(kdump_ctx_t *)
/* 362 */ _CFFI_OP(_CFFI_OP_NOOP, 101),
/* 363 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 364 */ _CFFI_OP(_CFFI_OP_FUNCTION, 436), // void()(kdump_ctx_t *, kdump_attr_iter_t *)
/* 365 */ _CFFI_OP(_CFFI_OP_NOOP, 101),
/* 366 */ _CFFI_OP(_CFFI_OP_NOOP, 175),
/* 367 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 368 */ _CFFI_OP(_CFFI_OP_FUNCTION, 436), // void()(kdump_ctx_t *, kdump_attr_ref_t *)
/* 369 */ _CFFI_OP(_CFFI_OP_NOOP, 101),
/* 370 */ _CFFI_OP(_CFFI_OP_NOOP, 110),
/* 371 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 372 */ _CFFI_OP(_CFFI_OP_FUNCTION, 436), // void()(kdump_ctx_t *, kdump_attr_t *)
/* 373 */ _CFFI_OP(_CFFI_OP_NOOP, 101),
/* 374 */ _CFFI_OP(_CFFI_OP_NOOP, 185),
/* 375 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 376 */ _CFFI_OP(_CFFI_OP_FUNCTION, 436), // void()(void *)
/* 377 */ _CFFI_OP(_CFFI_OP_NOOP, 76),
/* 378 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 379 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 1), // addrxlat_buffer_t
/* 380 */ _CFFI_OP(_CFFI_OP_ENUM, 1), // addrxlat_byte_order_t
/* 381 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 2), // addrxlat_cb_t
/* 382 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 3), // addrxlat_ctx_t
/* 383 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 4), // addrxlat_fulladdr_t
/* 384 */ _CFFI_OP(_CFFI_OP_ENUM, 2), // addrxlat_kind_t
/* 385 */ _CFFI_OP(_CFFI_OP_POINTER, 387), // addrxlat_lookup_elem_t *
/* 386 */ _CFFI_OP(_CFFI_OP_POINTER, 387), // addrxlat_lookup_elem_t const *
/* 387 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 5), // addrxlat_lookup_elem_t
/* 388 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 6), // addrxlat_map_t
/* 389 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 7), // addrxlat_meth_t
/* 390 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 8), // addrxlat_op_ctl_t
/* 391 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 9), // addrxlat_opt_t
/* 392 */ _CFFI_OP(_CFFI_OP_ENUM, 3), // addrxlat_optidx_t
/* 393 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 10), // addrxlat_optval_t
/* 394 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 11), // addrxlat_paging_form_t
/* 395 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 13), // addrxlat_param_custom_t
/* 396 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 14), // addrxlat_param_linear_t
/* 397 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 15), // addrxlat_param_lookup_t
/* 398 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 16), // addrxlat_param_memarr_t
/* 399 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 17), // addrxlat_param_pgt_t
/* 400 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 12), // addrxlat_param_t
/* 401 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 18), // addrxlat_range_t
/* 402 */ _CFFI_OP(_CFFI_OP_POINTER, 27), // addrxlat_status(*)(addrxlat_cb_t const *, addrxlat_buffer_t *)
/* 403 */ _CFFI_OP(_CFFI_OP_POINTER, 31), // addrxlat_status(*)(addrxlat_cb_t const *, char const *, char const *, uint_fast64_t *)
/* 404 */ _CFFI_OP(_CFFI_OP_POINTER, 37), // addrxlat_status(*)(addrxlat_cb_t const *, char const *, uint_fast64_t *)
/* 405 */ _CFFI_OP(_CFFI_OP_POINTER, 42), // addrxlat_status(*)(addrxlat_ctx_t *, addrxlat_status, char const *, ...)
/* 406 */ _CFFI_OP(_CFFI_OP_POINTER, 62), // addrxlat_status(*)(addrxlat_step_t *)
/* 407 */ _CFFI_OP(_CFFI_OP_POINTER, 65), // addrxlat_status(*)(addrxlat_step_t *, uint_fast64_t)
/* 408 */ _CFFI_OP(_CFFI_OP_POINTER, 75), // addrxlat_status(*)(void *, addrxlat_fulladdr_t const *)
/* 409 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 19), // addrxlat_step_t
/* 410 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 20), // addrxlat_sys_t
/* 411 */ _CFFI_OP(_CFFI_OP_POINTER, 412), // char *
/* 412 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 2), // char
/* 413 */ _CFFI_OP(_CFFI_OP_ENUM, 15), // enum kdump_clone_bits
/* 414 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 44), // int_fast64_t
/* 415 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 22), // kdump_attr_iter_t
/* 416 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 23), // kdump_attr_ref_t
/* 417 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 21), // kdump_attr_t
/* 418 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 24), // kdump_attr_value_t
/* 419 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 25), // kdump_blob_t
/* 420 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 26), // kdump_bmp_t
/* 421 */ _CFFI_OP(_CFFI_OP_ENUM, 10), // kdump_byte_order_t
/* 422 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 27), // kdump_ctx_t
/* 423 */ _CFFI_OP(_CFFI_OP_ENUM, 11), // kdump_mmap_policy_t
/* 424 */ _CFFI_OP(_CFFI_OP_POINTER, 256), // kdump_status(*)(kdump_ctx_t *, kdump_status, char const *, ...)
/* 425 */ _CFFI_OP(_CFFI_OP_ENUM, 13), // kdump_xen_type_t
/* 426 */ _CFFI_OP(_CFFI_OP_ENUM, 14), // kdump_xen_xlat_t
/* 427 */ _CFFI_OP(_CFFI_OP_ARRAY, 55), // uint_fast64_t[9]
/* 428 */ (_cffi_opcode_t)(9),
/* 429 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 0), // union $1
/* 430 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4), // unsigned char
/* 431 */ _CFFI_OP(_CFFI_OP_POINTER, 289), // unsigned long(*)(addrxlat_cb_t const *)
/* 432 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6), // unsigned short
/* 433 */ _CFFI_OP(_CFFI_OP_ARRAY, 432), // unsigned short[8]
/* 434 */ (_cffi_opcode_t)(8),
/* 435 */ _CFFI_OP(_CFFI_OP_POINTER, 325), // void(*)(addrxlat_buffer_t const *)
/* 436 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 0), // void
};

static int _cffi_const_ADDRXLAT_KPHYSADDR(unsigned long long *o)
{
  int n = (ADDRXLAT_KPHYSADDR) <= 0;
  *o = (unsigned long long)((ADDRXLAT_KPHYSADDR) | 0);  /* check that ADDRXLAT_KPHYSADDR is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_MACHPHYSADDR(unsigned long long *o)
{
  int n = (ADDRXLAT_MACHPHYSADDR) <= 0;
  *o = (unsigned long long)((ADDRXLAT_MACHPHYSADDR) | 0);  /* check that ADDRXLAT_MACHPHYSADDR is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_KVADDR(unsigned long long *o)
{
  int n = (ADDRXLAT_KVADDR) <= 0;
  *o = (unsigned long long)((ADDRXLAT_KVADDR) | 0);  /* check that ADDRXLAT_KVADDR is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_NOADDR(unsigned long long *o)
{
  int n = (ADDRXLAT_NOADDR) <= 0;
  *o = (unsigned long long)((ADDRXLAT_NOADDR) | 0);  /* check that ADDRXLAT_NOADDR is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_BIG_ENDIAN(unsigned long long *o)
{
  int n = (ADDRXLAT_BIG_ENDIAN) <= 0;
  *o = (unsigned long long)((ADDRXLAT_BIG_ENDIAN) | 0);  /* check that ADDRXLAT_BIG_ENDIAN is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_LITTLE_ENDIAN(unsigned long long *o)
{
  int n = (ADDRXLAT_LITTLE_ENDIAN) <= 0;
  *o = (unsigned long long)((ADDRXLAT_LITTLE_ENDIAN) | 0);  /* check that ADDRXLAT_LITTLE_ENDIAN is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_HOST_ENDIAN(unsigned long long *o)
{
  int n = (ADDRXLAT_HOST_ENDIAN) <= 0;
  *o = (unsigned long long)((ADDRXLAT_HOST_ENDIAN) | 0);  /* check that ADDRXLAT_HOST_ENDIAN is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_NOMETH(unsigned long long *o)
{
  int n = (ADDRXLAT_NOMETH) <= 0;
  *o = (unsigned long long)((ADDRXLAT_NOMETH) | 0);  /* check that ADDRXLAT_NOMETH is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_CUSTOM(unsigned long long *o)
{
  int n = (ADDRXLAT_CUSTOM) <= 0;
  *o = (unsigned long long)((ADDRXLAT_CUSTOM) | 0);  /* check that ADDRXLAT_CUSTOM is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_LINEAR(unsigned long long *o)
{
  int n = (ADDRXLAT_LINEAR) <= 0;
  *o = (unsigned long long)((ADDRXLAT_LINEAR) | 0);  /* check that ADDRXLAT_LINEAR is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_PGT(unsigned long long *o)
{
  int n = (ADDRXLAT_PGT) <= 0;
  *o = (unsigned long long)((ADDRXLAT_PGT) | 0);  /* check that ADDRXLAT_PGT is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_LOOKUP(unsigned long long *o)
{
  int n = (ADDRXLAT_LOOKUP) <= 0;
  *o = (unsigned long long)((ADDRXLAT_LOOKUP) | 0);  /* check that ADDRXLAT_LOOKUP is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_MEMARR(unsigned long long *o)
{
  int n = (ADDRXLAT_MEMARR) <= 0;
  *o = (unsigned long long)((ADDRXLAT_MEMARR) | 0);  /* check that ADDRXLAT_MEMARR is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_OPT_NULL(unsigned long long *o)
{
  int n = (ADDRXLAT_OPT_NULL) <= 0;
  *o = (unsigned long long)((ADDRXLAT_OPT_NULL) | 0);  /* check that ADDRXLAT_OPT_NULL is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_OPT_arch(unsigned long long *o)
{
  int n = (ADDRXLAT_OPT_arch) <= 0;
  *o = (unsigned long long)((ADDRXLAT_OPT_arch) | 0);  /* check that ADDRXLAT_OPT_arch is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_OPT_os_type(unsigned long long *o)
{
  int n = (ADDRXLAT_OPT_os_type) <= 0;
  *o = (unsigned long long)((ADDRXLAT_OPT_os_type) | 0);  /* check that ADDRXLAT_OPT_os_type is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_OPT_version_code(unsigned long long *o)
{
  int n = (ADDRXLAT_OPT_version_code) <= 0;
  *o = (unsigned long long)((ADDRXLAT_OPT_version_code) | 0);  /* check that ADDRXLAT_OPT_version_code is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_OPT_phys_bits(unsigned long long *o)
{
  int n = (ADDRXLAT_OPT_phys_bits) <= 0;
  *o = (unsigned long long)((ADDRXLAT_OPT_phys_bits) | 0);  /* check that ADDRXLAT_OPT_phys_bits is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_OPT_virt_bits(unsigned long long *o)
{
  int n = (ADDRXLAT_OPT_virt_bits) <= 0;
  *o = (unsigned long long)((ADDRXLAT_OPT_virt_bits) | 0);  /* check that ADDRXLAT_OPT_virt_bits is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_OPT_page_shift(unsigned long long *o)
{
  int n = (ADDRXLAT_OPT_page_shift) <= 0;
  *o = (unsigned long long)((ADDRXLAT_OPT_page_shift) | 0);  /* check that ADDRXLAT_OPT_page_shift is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_OPT_phys_base(unsigned long long *o)
{
  int n = (ADDRXLAT_OPT_phys_base) <= 0;
  *o = (unsigned long long)((ADDRXLAT_OPT_phys_base) | 0);  /* check that ADDRXLAT_OPT_phys_base is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_OPT_rootpgt(unsigned long long *o)
{
  int n = (ADDRXLAT_OPT_rootpgt) <= 0;
  *o = (unsigned long long)((ADDRXLAT_OPT_rootpgt) | 0);  /* check that ADDRXLAT_OPT_rootpgt is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_OPT_xen_p2m_mfn(unsigned long long *o)
{
  int n = (ADDRXLAT_OPT_xen_p2m_mfn) <= 0;
  *o = (unsigned long long)((ADDRXLAT_OPT_xen_p2m_mfn) | 0);  /* check that ADDRXLAT_OPT_xen_p2m_mfn is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_OPT_xen_xlat(unsigned long long *o)
{
  int n = (ADDRXLAT_OPT_xen_xlat) <= 0;
  *o = (unsigned long long)((ADDRXLAT_OPT_xen_xlat) | 0);  /* check that ADDRXLAT_OPT_xen_xlat is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_OPT_NUM(unsigned long long *o)
{
  int n = (ADDRXLAT_OPT_NUM) <= 0;
  *o = (unsigned long long)((ADDRXLAT_OPT_NUM) | 0);  /* check that ADDRXLAT_OPT_NUM is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_PTE_INVALID(unsigned long long *o)
{
  int n = (ADDRXLAT_PTE_INVALID) <= 0;
  *o = (unsigned long long)((ADDRXLAT_PTE_INVALID) | 0);  /* check that ADDRXLAT_PTE_INVALID is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_PTE_NONE(unsigned long long *o)
{
  int n = (ADDRXLAT_PTE_NONE) <= 0;
  *o = (unsigned long long)((ADDRXLAT_PTE_NONE) | 0);  /* check that ADDRXLAT_PTE_NONE is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_PTE_PFN32(unsigned long long *o)
{
  int n = (ADDRXLAT_PTE_PFN32) <= 0;
  *o = (unsigned long long)((ADDRXLAT_PTE_PFN32) | 0);  /* check that ADDRXLAT_PTE_PFN32 is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_PTE_PFN64(unsigned long long *o)
{
  int n = (ADDRXLAT_PTE_PFN64) <= 0;
  *o = (unsigned long long)((ADDRXLAT_PTE_PFN64) | 0);  /* check that ADDRXLAT_PTE_PFN64 is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_PTE_AARCH64(unsigned long long *o)
{
  int n = (ADDRXLAT_PTE_AARCH64) <= 0;
  *o = (unsigned long long)((ADDRXLAT_PTE_AARCH64) | 0);  /* check that ADDRXLAT_PTE_AARCH64 is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_PTE_IA32(unsigned long long *o)
{
  int n = (ADDRXLAT_PTE_IA32) <= 0;
  *o = (unsigned long long)((ADDRXLAT_PTE_IA32) | 0);  /* check that ADDRXLAT_PTE_IA32 is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_PTE_IA32_PAE(unsigned long long *o)
{
  int n = (ADDRXLAT_PTE_IA32_PAE) <= 0;
  *o = (unsigned long long)((ADDRXLAT_PTE_IA32_PAE) | 0);  /* check that ADDRXLAT_PTE_IA32_PAE is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_PTE_X86_64(unsigned long long *o)
{
  int n = (ADDRXLAT_PTE_X86_64) <= 0;
  *o = (unsigned long long)((ADDRXLAT_PTE_X86_64) | 0);  /* check that ADDRXLAT_PTE_X86_64 is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_PTE_S390X(unsigned long long *o)
{
  int n = (ADDRXLAT_PTE_S390X) <= 0;
  *o = (unsigned long long)((ADDRXLAT_PTE_S390X) | 0);  /* check that ADDRXLAT_PTE_S390X is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_PTE_PPC64_LINUX_RPN30(unsigned long long *o)
{
  int n = (ADDRXLAT_PTE_PPC64_LINUX_RPN30) <= 0;
  *o = (unsigned long long)((ADDRXLAT_PTE_PPC64_LINUX_RPN30) | 0);  /* check that ADDRXLAT_PTE_PPC64_LINUX_RPN30 is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_PTE_AARCH64_LPA(unsigned long long *o)
{
  int n = (ADDRXLAT_PTE_AARCH64_LPA) <= 0;
  *o = (unsigned long long)((ADDRXLAT_PTE_AARCH64_LPA) | 0);  /* check that ADDRXLAT_PTE_AARCH64_LPA is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_PTE_AARCH64_LPA2(unsigned long long *o)
{
  int n = (ADDRXLAT_PTE_AARCH64_LPA2) <= 0;
  *o = (unsigned long long)((ADDRXLAT_PTE_AARCH64_LPA2) | 0);  /* check that ADDRXLAT_PTE_AARCH64_LPA2 is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_PTE_ARM(unsigned long long *o)
{
  int n = (ADDRXLAT_PTE_ARM) <= 0;
  *o = (unsigned long long)((ADDRXLAT_PTE_ARM) | 0);  /* check that ADDRXLAT_PTE_ARM is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_PTE_RISCV32(unsigned long long *o)
{
  int n = (ADDRXLAT_PTE_RISCV32) <= 0;
  *o = (unsigned long long)((ADDRXLAT_PTE_RISCV32) | 0);  /* check that ADDRXLAT_PTE_RISCV32 is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_PTE_RISCV64(unsigned long long *o)
{
  int n = (ADDRXLAT_PTE_RISCV64) <= 0;
  *o = (unsigned long long)((ADDRXLAT_PTE_RISCV64) | 0);  /* check that ADDRXLAT_PTE_RISCV64 is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_OK(unsigned long long *o)
{
  int n = (ADDRXLAT_OK) <= 0;
  *o = (unsigned long long)((ADDRXLAT_OK) | 0);  /* check that ADDRXLAT_OK is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_ERR_NOTIMPL(unsigned long long *o)
{
  int n = (ADDRXLAT_ERR_NOTIMPL) <= 0;
  *o = (unsigned long long)((ADDRXLAT_ERR_NOTIMPL) | 0);  /* check that ADDRXLAT_ERR_NOTIMPL is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_ERR_NOTPRESENT(unsigned long long *o)
{
  int n = (ADDRXLAT_ERR_NOTPRESENT) <= 0;
  *o = (unsigned long long)((ADDRXLAT_ERR_NOTPRESENT) | 0);  /* check that ADDRXLAT_ERR_NOTPRESENT is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_ERR_INVALID(unsigned long long *o)
{
  int n = (ADDRXLAT_ERR_INVALID) <= 0;
  *o = (unsigned long long)((ADDRXLAT_ERR_INVALID) | 0);  /* check that ADDRXLAT_ERR_INVALID is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_ERR_NOMEM(unsigned long long *o)
{
  int n = (ADDRXLAT_ERR_NOMEM) <= 0;
  *o = (unsigned long long)((ADDRXLAT_ERR_NOMEM) | 0);  /* check that ADDRXLAT_ERR_NOMEM is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_ERR_NODATA(unsigned long long *o)
{
  int n = (ADDRXLAT_ERR_NODATA) <= 0;
  *o = (unsigned long long)((ADDRXLAT_ERR_NODATA) | 0);  /* check that ADDRXLAT_ERR_NODATA is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_ERR_NOMETH(unsigned long long *o)
{
  int n = (ADDRXLAT_ERR_NOMETH) <= 0;
  *o = (unsigned long long)((ADDRXLAT_ERR_NOMETH) | 0);  /* check that ADDRXLAT_ERR_NOMETH is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_ERR_CUSTOM_BASE(unsigned long long *o)
{
  int n = (ADDRXLAT_ERR_CUSTOM_BASE) <= 0;
  *o = (unsigned long long)((ADDRXLAT_ERR_CUSTOM_BASE) | 0);  /* check that ADDRXLAT_ERR_CUSTOM_BASE is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_SYS_MAP_HW(unsigned long long *o)
{
  int n = (ADDRXLAT_SYS_MAP_HW) <= 0;
  *o = (unsigned long long)((ADDRXLAT_SYS_MAP_HW) | 0);  /* check that ADDRXLAT_SYS_MAP_HW is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_SYS_MAP_KV_PHYS(unsigned long long *o)
{
  int n = (ADDRXLAT_SYS_MAP_KV_PHYS) <= 0;
  *o = (unsigned long long)((ADDRXLAT_SYS_MAP_KV_PHYS) | 0);  /* check that ADDRXLAT_SYS_MAP_KV_PHYS is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_SYS_MAP_KPHYS_DIRECT(unsigned long long *o)
{
  int n = (ADDRXLAT_SYS_MAP_KPHYS_DIRECT) <= 0;
  *o = (unsigned long long)((ADDRXLAT_SYS_MAP_KPHYS_DIRECT) | 0);  /* check that ADDRXLAT_SYS_MAP_KPHYS_DIRECT is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_SYS_MAP_MACHPHYS_KPHYS(unsigned long long *o)
{
  int n = (ADDRXLAT_SYS_MAP_MACHPHYS_KPHYS) <= 0;
  *o = (unsigned long long)((ADDRXLAT_SYS_MAP_MACHPHYS_KPHYS) | 0);  /* check that ADDRXLAT_SYS_MAP_MACHPHYS_KPHYS is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_SYS_MAP_KPHYS_MACHPHYS(unsigned long long *o)
{
  int n = (ADDRXLAT_SYS_MAP_KPHYS_MACHPHYS) <= 0;
  *o = (unsigned long long)((ADDRXLAT_SYS_MAP_KPHYS_MACHPHYS) | 0);  /* check that ADDRXLAT_SYS_MAP_KPHYS_MACHPHYS is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_SYS_MAP_NUM(unsigned long long *o)
{
  int n = (ADDRXLAT_SYS_MAP_NUM) <= 0;
  *o = (unsigned long long)((ADDRXLAT_SYS_MAP_NUM) | 0);  /* check that ADDRXLAT_SYS_MAP_NUM is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_SYS_METH_NONE(unsigned long long *o)
{
  int n = (ADDRXLAT_SYS_METH_NONE) <= 0;
  *o = (unsigned long long)((ADDRXLAT_SYS_METH_NONE) | 0);  /* check that ADDRXLAT_SYS_METH_NONE is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_SYS_METH_PGT(unsigned long long *o)
{
  int n = (ADDRXLAT_SYS_METH_PGT) <= 0;
  *o = (unsigned long long)((ADDRXLAT_SYS_METH_PGT) | 0);  /* check that ADDRXLAT_SYS_METH_PGT is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_SYS_METH_UPGT(unsigned long long *o)
{
  int n = (ADDRXLAT_SYS_METH_UPGT) <= 0;
  *o = (unsigned long long)((ADDRXLAT_SYS_METH_UPGT) | 0);  /* check that ADDRXLAT_SYS_METH_UPGT is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_SYS_METH_DIRECT(unsigned long long *o)
{
  int n = (ADDRXLAT_SYS_METH_DIRECT) <= 0;
  *o = (unsigned long long)((ADDRXLAT_SYS_METH_DIRECT) | 0);  /* check that ADDRXLAT_SYS_METH_DIRECT is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_SYS_METH_KTEXT(unsigned long long *o)
{
  int n = (ADDRXLAT_SYS_METH_KTEXT) <= 0;
  *o = (unsigned long long)((ADDRXLAT_SYS_METH_KTEXT) | 0);  /* check that ADDRXLAT_SYS_METH_KTEXT is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_SYS_METH_VMEMMAP(unsigned long long *o)
{
  int n = (ADDRXLAT_SYS_METH_VMEMMAP) <= 0;
  *o = (unsigned long long)((ADDRXLAT_SYS_METH_VMEMMAP) | 0);  /* check that ADDRXLAT_SYS_METH_VMEMMAP is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_SYS_METH_RDIRECT(unsigned long long *o)
{
  int n = (ADDRXLAT_SYS_METH_RDIRECT) <= 0;
  *o = (unsigned long long)((ADDRXLAT_SYS_METH_RDIRECT) | 0);  /* check that ADDRXLAT_SYS_METH_RDIRECT is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_SYS_METH_MACHPHYS_KPHYS(unsigned long long *o)
{
  int n = (ADDRXLAT_SYS_METH_MACHPHYS_KPHYS) <= 0;
  *o = (unsigned long long)((ADDRXLAT_SYS_METH_MACHPHYS_KPHYS) | 0);  /* check that ADDRXLAT_SYS_METH_MACHPHYS_KPHYS is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_SYS_METH_KPHYS_MACHPHYS(unsigned long long *o)
{
  int n = (ADDRXLAT_SYS_METH_KPHYS_MACHPHYS) <= 0;
  *o = (unsigned long long)((ADDRXLAT_SYS_METH_KPHYS_MACHPHYS) | 0);  /* check that ADDRXLAT_SYS_METH_KPHYS_MACHPHYS is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_SYS_METH_CUSTOM(unsigned long long *o)
{
  int n = (ADDRXLAT_SYS_METH_CUSTOM) <= 0;
  *o = (unsigned long long)((ADDRXLAT_SYS_METH_CUSTOM) | 0);  /* check that ADDRXLAT_SYS_METH_CUSTOM is an integer */
  return n;
}

static int _cffi_const_KDUMP_KPHYSADDR(unsigned long long *o)
{
  int n = (KDUMP_KPHYSADDR) <= 0;
  *o = (unsigned long long)((KDUMP_KPHYSADDR) | 0);  /* check that KDUMP_KPHYSADDR is an integer */
  return n;
}

static int _cffi_const_KDUMP_MACHPHYSADDR(unsigned long long *o)
{
  int n = (KDUMP_MACHPHYSADDR) <= 0;
  *o = (unsigned long long)((KDUMP_MACHPHYSADDR) | 0);  /* check that KDUMP_MACHPHYSADDR is an integer */
  return n;
}

static int _cffi_const_KDUMP_KVADDR(unsigned long long *o)
{
  int n = (KDUMP_KVADDR) <= 0;
  *o = (unsigned long long)((KDUMP_KVADDR) | 0);  /* check that KDUMP_KVADDR is an integer */
  return n;
}

static int _cffi_const_KDUMP_NOADDR(unsigned long long *o)
{
  int n = (KDUMP_NOADDR) <= 0;
  *o = (unsigned long long)((KDUMP_NOADDR) | 0);  /* check that KDUMP_NOADDR is an integer */
  return n;
}

static int _cffi_const_KDUMP_NIL(unsigned long long *o)
{
  int n = (KDUMP_NIL) <= 0;
  *o = (unsigned long long)((KDUMP_NIL) | 0);  /* check that KDUMP_NIL is an integer */
  return n;
}

static int _cffi_const_KDUMP_DIRECTORY(unsigned long long *o)
{
  int n = (KDUMP_DIRECTORY) <= 0;
  *o = (unsigned long long)((KDUMP_DIRECTORY) | 0);  /* check that KDUMP_DIRECTORY is an integer */
  return n;
}

static int _cffi_const_KDUMP_NUMBER(unsigned long long *o)
{
  int n = (KDUMP_NUMBER) <= 0;
  *o = (unsigned long long)((KDUMP_NUMBER) | 0);  /* check that KDUMP_NUMBER is an integer */
  return n;
}

static int _cffi_const_KDUMP_ADDRESS(unsigned long long *o)
{
  int n = (KDUMP_ADDRESS) <= 0;
  *o = (unsigned long long)((KDUMP_ADDRESS) | 0);  /* check that KDUMP_ADDRESS is an integer */
  return n;
}

static int _cffi_const_KDUMP_STRING(unsigned long long *o)
{
  int n = (KDUMP_STRING) <= 0;
  *o = (unsigned long long)((KDUMP_STRING) | 0);  /* check that KDUMP_STRING is an integer */
  return n;
}

static int _cffi_const_KDUMP_BITMAP(unsigned long long *o)
{
  int n = (KDUMP_BITMAP) <= 0;
  *o = (unsigned long long)((KDUMP_BITMAP) | 0);  /* check that KDUMP_BITMAP is an integer */
  return n;
}

static int _cffi_const_KDUMP_BLOB(unsigned long long *o)
{
  int n = (KDUMP_BLOB) <= 0;
  *o = (unsigned long long)((KDUMP_BLOB) | 0);  /* check that KDUMP_BLOB is an integer */
  return n;
}

static int _cffi_const_KDUMP_BIG_ENDIAN(unsigned long long *o)
{
  int n = (KDUMP_BIG_ENDIAN) <= 0;
  *o = (unsigned long long)((KDUMP_BIG_ENDIAN) | 0);  /* check that KDUMP_BIG_ENDIAN is an integer */
  return n;
}

static int _cffi_const_KDUMP_LITTLE_ENDIAN(unsigned long long *o)
{
  int n = (KDUMP_LITTLE_ENDIAN) <= 0;
  *o = (unsigned long long)((KDUMP_LITTLE_ENDIAN) | 0);  /* check that KDUMP_LITTLE_ENDIAN is an integer */
  return n;
}

static int _cffi_const_KDUMP_MMAP_NEVER(unsigned long long *o)
{
  int n = (KDUMP_MMAP_NEVER) <= 0;
  *o = (unsigned long long)((KDUMP_MMAP_NEVER) | 0);  /* check that KDUMP_MMAP_NEVER is an integer */
  return n;
}

static int _cffi_const_KDUMP_MMAP_ALWAYS(unsigned long long *o)
{
  int n = (KDUMP_MMAP_ALWAYS) <= 0;
  *o = (unsigned long long)((KDUMP_MMAP_ALWAYS) | 0);  /* check that KDUMP_MMAP_ALWAYS is an integer */
  return n;
}

static int _cffi_const_KDUMP_MMAP_TRY(unsigned long long *o)
{
  int n = (KDUMP_MMAP_TRY) <= 0;
  *o = (unsigned long long)((KDUMP_MMAP_TRY) | 0);  /* check that KDUMP_MMAP_TRY is an integer */
  return n;
}

static int _cffi_const_KDUMP_MMAP_TRY_ONCE(unsigned long long *o)
{
  int n = (KDUMP_MMAP_TRY_ONCE) <= 0;
  *o = (unsigned long long)((KDUMP_MMAP_TRY_ONCE) | 0);  /* check that KDUMP_MMAP_TRY_ONCE is an integer */
  return n;
}

static int _cffi_const_KDUMP_OK(unsigned long long *o)
{
  int n = (KDUMP_OK) <= 0;
  *o = (unsigned long long)((KDUMP_OK) | 0);  /* check that KDUMP_OK is an integer */
  return n;
}

static int _cffi_const_KDUMP_ERR_SYSTEM(unsigned long long *o)
{
  int n = (KDUMP_ERR_SYSTEM) <= 0;
  *o = (unsigned long long)((KDUMP_ERR_SYSTEM) | 0);  /* check that KDUMP_ERR_SYSTEM is an integer */
  return n;
}

static int _cffi_const_KDUMP_ERR_NOTIMPL(unsigned long long *o)
{
  int n = (KDUMP_ERR_NOTIMPL) <= 0;
  *o = (unsigned long long)((KDUMP_ERR_NOTIMPL) | 0);  /* check that KDUMP_ERR_NOTIMPL is an integer */
  return n;
}

static int _cffi_const_KDUMP_ERR_NODATA(unsigned long long *o)
{
  int n = (KDUMP_ERR_NODATA) <= 0;
  *o = (unsigned long long)((KDUMP_ERR_NODATA) | 0);  /* check that KDUMP_ERR_NODATA is an integer */
  return n;
}

static int _cffi_const_KDUMP_ERR_CORRUPT(unsigned long long *o)
{
  int n = (KDUMP_ERR_CORRUPT) <= 0;
  *o = (unsigned long long)((KDUMP_ERR_CORRUPT) | 0);  /* check that KDUMP_ERR_CORRUPT is an integer */
  return n;
}

static int _cffi_const_KDUMP_ERR_INVALID(unsigned long long *o)
{
  int n = (KDUMP_ERR_INVALID) <= 0;
  *o = (unsigned long long)((KDUMP_ERR_INVALID) | 0);  /* check that KDUMP_ERR_INVALID is an integer */
  return n;
}

static int _cffi_const_KDUMP_ERR_NOKEY(unsigned long long *o)
{
  int n = (KDUMP_ERR_NOKEY) <= 0;
  *o = (unsigned long long)((KDUMP_ERR_NOKEY) | 0);  /* check that KDUMP_ERR_NOKEY is an integer */
  return n;
}

static int _cffi_const_KDUMP_ERR_EOF(unsigned long long *o)
{
  int n = (KDUMP_ERR_EOF) <= 0;
  *o = (unsigned long long)((KDUMP_ERR_EOF) | 0);  /* check that KDUMP_ERR_EOF is an integer */
  return n;
}

static int _cffi_const_KDUMP_ERR_BUSY(unsigned long long *o)
{
  int n = (KDUMP_ERR_BUSY) <= 0;
  *o = (unsigned long long)((KDUMP_ERR_BUSY) | 0);  /* check that KDUMP_ERR_BUSY is an integer */
  return n;
}

static int _cffi_const_KDUMP_ERR_ADDRXLAT(unsigned long long *o)
{
  int n = (KDUMP_ERR_ADDRXLAT) <= 0;
  *o = (unsigned long long)((KDUMP_ERR_ADDRXLAT) | 0);  /* check that KDUMP_ERR_ADDRXLAT is an integer */
  return n;
}

static int _cffi_const_KDUMP_XEN_NONE(unsigned long long *o)
{
  int n = (KDUMP_XEN_NONE) <= 0;
  *o = (unsigned long long)((KDUMP_XEN_NONE) | 0);  /* check that KDUMP_XEN_NONE is an integer */
  return n;
}

static int _cffi_const_KDUMP_XEN_SYSTEM(unsigned long long *o)
{
  int n = (KDUMP_XEN_SYSTEM) <= 0;
  *o = (unsigned long long)((KDUMP_XEN_SYSTEM) | 0);  /* check that KDUMP_XEN_SYSTEM is an integer */
  return n;
}

static int _cffi_const_KDUMP_XEN_DOMAIN(unsigned long long *o)
{
  int n = (KDUMP_XEN_DOMAIN) <= 0;
  *o = (unsigned long long)((KDUMP_XEN_DOMAIN) | 0);  /* check that KDUMP_XEN_DOMAIN is an integer */
  return n;
}

static int _cffi_const_KDUMP_XEN_AUTO(unsigned long long *o)
{
  int n = (KDUMP_XEN_AUTO) <= 0;
  *o = (unsigned long long)((KDUMP_XEN_AUTO) | 0);  /* check that KDUMP_XEN_AUTO is an integer */
  return n;
}

static int _cffi_const_KDUMP_XEN_NONAUTO(unsigned long long *o)
{
  int n = (KDUMP_XEN_NONAUTO) <= 0;
  *o = (unsigned long long)((KDUMP_XEN_NONAUTO) | 0);  /* check that KDUMP_XEN_NONAUTO is an integer */
  return n;
}

static int _cffi_const_KDUMP_CLONE_BIT_XLAT(unsigned long long *o)
{
  int n = (KDUMP_CLONE_BIT_XLAT) <= 0;
  *o = (unsigned long long)((KDUMP_CLONE_BIT_XLAT) | 0);  /* check that KDUMP_CLONE_BIT_XLAT is an integer */
  return n;
}

static unsigned long _cffi_d_ADDRXLAT_CAPS(unsigned int x0)
{
  return ADDRXLAT_CAPS(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_ADDRXLAT_CAPS(PyObject *self, PyObject *arg0)
{
  unsigned int x0;
  unsigned long result;
  PyObject *pyresult;

  x0 = _cffi_to_c_int(arg0, unsigned int);
  if (x0 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = ADDRXLAT_CAPS(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned long);
  return pyresult;
}
#else
#  define _cffi_f_ADDRXLAT_CAPS _cffi_d_ADDRXLAT_CAPS
#endif

static unsigned long _cffi_d_ADDRXLAT_VER_LINUX(unsigned int x0, unsigned int x1, unsigned int x2)
{
  return ADDRXLAT_VER_LINUX(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_ADDRXLAT_VER_LINUX(PyObject *self, PyObject *args)
{
  unsigned int x0;
  unsigned int x1;
  unsigned int x2;
  unsigned long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "ADDRXLAT_VER_LINUX", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned int);
  if (x0 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned int);
  if (x1 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned int);
  if (x2 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = ADDRXLAT_VER_LINUX(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned long);
  return pyresult;
}
#else
#  define _cffi_f_ADDRXLAT_VER_LINUX _cffi_d_ADDRXLAT_VER_LINUX
#endif

static unsigned long _cffi_d_ADDRXLAT_VER_XEN(unsigned int x0, unsigned int x1)
{
  return ADDRXLAT_VER_XEN(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_ADDRXLAT_VER_XEN(PyObject *self, PyObject *args)
{
  unsigned int x0;
  unsigned int x1;
  unsigned long result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "ADDRXLAT_VER_XEN", 2, 2, &arg0, &arg1))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned int);
  if (x0 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, unsigned int);
  if (x1 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = ADDRXLAT_VER_XEN(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned long);
  return pyresult;
}
#else
#  define _cffi_f_ADDRXLAT_VER_XEN _cffi_d_ADDRXLAT_VER_XEN
#endif

static char const * _cffi_d_addrxlat_addrspace_name(addrxlat_addrspace_t x0)
{
  return addrxlat_addrspace_name(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_addrspace_name(PyObject *self, PyObject *arg0)
{
  addrxlat_addrspace_t x0;
  char const * result;
  PyObject *pyresult;

  if (_cffi_to_c((char *)&x0, _cffi_type(49), arg0) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_addrspace_name(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(22));
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_addrspace_name _cffi_d_addrxlat_addrspace_name
#endif

static addrxlat_cb_t * _cffi_d_addrxlat_ctx_add_cb(addrxlat_ctx_t * x0)
{
  return addrxlat_ctx_add_cb(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_ctx_add_cb(PyObject *self, PyObject *arg0)
{
  addrxlat_ctx_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  addrxlat_cb_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_ctx_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_ctx_add_cb(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(333));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_ctx_add_cb _cffi_d_addrxlat_ctx_add_cb
#endif

static void _cffi_d_addrxlat_ctx_clear_err(addrxlat_ctx_t * x0)
{
  addrxlat_ctx_clear_err(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_ctx_clear_err(PyObject *self, PyObject *arg0)
{
  addrxlat_ctx_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_ctx_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { addrxlat_ctx_clear_err(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_addrxlat_ctx_clear_err _cffi_d_addrxlat_ctx_clear_err
#endif

static unsigned long _cffi_d_addrxlat_ctx_decref(addrxlat_ctx_t * x0)
{
  return addrxlat_ctx_decref(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_ctx_decref(PyObject *self, PyObject *arg0)
{
  addrxlat_ctx_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned long result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_ctx_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_ctx_decref(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_ctx_decref _cffi_d_addrxlat_ctx_decref
#endif

static void _cffi_d_addrxlat_ctx_del_cb(addrxlat_ctx_t * x0, addrxlat_cb_t * x1)
{
  addrxlat_ctx_del_cb(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_ctx_del_cb(PyObject *self, PyObject *args)
{
  addrxlat_ctx_t * x0;
  addrxlat_cb_t * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "addrxlat_ctx_del_cb", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_ctx_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(333), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (addrxlat_cb_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(333), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { addrxlat_ctx_del_cb(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_addrxlat_ctx_del_cb _cffi_d_addrxlat_ctx_del_cb
#endif

static void _cffi_const_addrxlat_ctx_err(char *o)
{
  *(addrxlat_status(* *)(addrxlat_ctx_t *, addrxlat_status, char const *, ...))o = addrxlat_ctx_err;
}

static addrxlat_cb_t const * _cffi_d_addrxlat_ctx_get_cb(addrxlat_ctx_t const * x0)
{
  return addrxlat_ctx_get_cb(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_ctx_get_cb(PyObject *self, PyObject *arg0)
{
  addrxlat_ctx_t const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  addrxlat_cb_t const * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(4), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_ctx_t const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(4), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_ctx_get_cb(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(28));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_ctx_get_cb _cffi_d_addrxlat_ctx_get_cb
#endif

static char const * _cffi_d_addrxlat_ctx_get_err(addrxlat_ctx_t const * x0)
{
  return addrxlat_ctx_get_err(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_ctx_get_err(PyObject *self, PyObject *arg0)
{
  addrxlat_ctx_t const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  char const * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(4), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_ctx_t const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(4), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_ctx_get_err(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(22));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_ctx_get_err _cffi_d_addrxlat_ctx_get_err
#endif

static unsigned long _cffi_d_addrxlat_ctx_incref(addrxlat_ctx_t * x0)
{
  return addrxlat_ctx_incref(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_ctx_incref(PyObject *self, PyObject *arg0)
{
  addrxlat_ctx_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned long result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_ctx_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_ctx_incref(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_ctx_incref _cffi_d_addrxlat_ctx_incref
#endif

static addrxlat_ctx_t * _cffi_d_addrxlat_ctx_new(void)
{
  return addrxlat_ctx_new();
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_ctx_new(PyObject *self, PyObject *noarg)
{
  addrxlat_ctx_t * result;
  PyObject *pyresult;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_ctx_new(); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  (void)noarg; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(1));
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_ctx_new _cffi_d_addrxlat_ctx_new
#endif

static addrxlat_status _cffi_d_addrxlat_fulladdr_conv(addrxlat_fulladdr_t * x0, addrxlat_addrspace_t x1, addrxlat_ctx_t * x2, addrxlat_sys_t * x3)
{
  return addrxlat_fulladdr_conv(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_fulladdr_conv(PyObject *self, PyObject *args)
{
  addrxlat_fulladdr_t * x0;
  addrxlat_addrspace_t x1;
  addrxlat_ctx_t * x2;
  addrxlat_sys_t * x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  addrxlat_status result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "addrxlat_fulladdr_conv", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(48), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_fulladdr_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(48), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(49), arg1) < 0)
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (addrxlat_ctx_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(51), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (addrxlat_sys_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(51), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_fulladdr_conv(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(44));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_fulladdr_conv _cffi_d_addrxlat_fulladdr_conv
#endif

static addrxlat_status _cffi_d_addrxlat_launch(addrxlat_step_t * x0, uint_fast64_t x1)
{
  return addrxlat_launch(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_launch(PyObject *self, PyObject *args)
{
  addrxlat_step_t * x0;
  uint_fast64_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  addrxlat_status result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "addrxlat_launch", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(63), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_step_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(63), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, uint_fast64_t);
  if (x1 == (uint_fast64_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_launch(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(44));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_launch _cffi_d_addrxlat_launch
#endif

static addrxlat_map_t * _cffi_d_addrxlat_map_copy(addrxlat_map_t const * x0)
{
  return addrxlat_map_copy(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_map_copy(PyObject *self, PyObject *arg0)
{
  addrxlat_map_t const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  addrxlat_map_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(9), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_map_t const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(9), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_map_copy(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(54));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_map_copy _cffi_d_addrxlat_map_copy
#endif

static unsigned long _cffi_d_addrxlat_map_decref(addrxlat_map_t * x0)
{
  return addrxlat_map_decref(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_map_decref(PyObject *self, PyObject *arg0)
{
  addrxlat_map_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned long result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(54), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_map_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(54), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_map_decref(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_map_decref _cffi_d_addrxlat_map_decref
#endif

static unsigned long _cffi_d_addrxlat_map_incref(addrxlat_map_t * x0)
{
  return addrxlat_map_incref(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_map_incref(PyObject *self, PyObject *arg0)
{
  addrxlat_map_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned long result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(54), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_map_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(54), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_map_incref(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_map_incref _cffi_d_addrxlat_map_incref
#endif

static size_t _cffi_d_addrxlat_map_len(addrxlat_map_t const * x0)
{
  return addrxlat_map_len(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_map_len(PyObject *self, PyObject *arg0)
{
  addrxlat_map_t const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  size_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(9), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_map_t const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(9), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_map_len(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, size_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_map_len _cffi_d_addrxlat_map_len
#endif

static addrxlat_map_t * _cffi_d_addrxlat_map_new(void)
{
  return addrxlat_map_new();
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_map_new(PyObject *self, PyObject *noarg)
{
  addrxlat_map_t * result;
  PyObject *pyresult;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_map_new(); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  (void)noarg; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(54));
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_map_new _cffi_d_addrxlat_map_new
#endif

static addrxlat_range_t const * _cffi_d_addrxlat_map_ranges(addrxlat_map_t const * x0)
{
  return addrxlat_map_ranges(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_map_ranges(PyObject *self, PyObject *arg0)
{
  addrxlat_map_t const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  addrxlat_range_t const * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(9), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_map_t const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(9), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_map_ranges(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(56));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_map_ranges _cffi_d_addrxlat_map_ranges
#endif

static addrxlat_sys_meth_t _cffi_d_addrxlat_map_search(addrxlat_map_t const * x0, uint_fast64_t x1)
{
  return addrxlat_map_search(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_map_search(PyObject *self, PyObject *args)
{
  addrxlat_map_t const * x0;
  uint_fast64_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  addrxlat_sys_meth_t result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "addrxlat_map_search", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(9), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_map_t const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(9), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, uint_fast64_t);
  if (x1 == (uint_fast64_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_map_search(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(19));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_map_search _cffi_d_addrxlat_map_search
#endif

static addrxlat_status _cffi_d_addrxlat_map_set(addrxlat_map_t * x0, uint_fast64_t x1, addrxlat_range_t const * x2)
{
  return addrxlat_map_set(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_map_set(PyObject *self, PyObject *args)
{
  addrxlat_map_t * x0;
  uint_fast64_t x1;
  addrxlat_range_t const * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  addrxlat_status result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "addrxlat_map_set", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(54), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_map_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(54), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, uint_fast64_t);
  if (x1 == (uint_fast64_t)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(56), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (addrxlat_range_t const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(56), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_map_set(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(44));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_map_set _cffi_d_addrxlat_map_set
#endif

static addrxlat_status _cffi_d_addrxlat_op(addrxlat_op_ctl_t const * x0, addrxlat_fulladdr_t const * x1)
{
  return addrxlat_op(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_op(PyObject *self, PyObject *args)
{
  addrxlat_op_ctl_t const * x0;
  addrxlat_fulladdr_t const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  addrxlat_status result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "addrxlat_op", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(59), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_op_ctl_t const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(59), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(60), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (addrxlat_fulladdr_t const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(60), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_op(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(44));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_op _cffi_d_addrxlat_op
#endif

static void _cffi_d_addrxlat_opt_arch(addrxlat_opt_t * x0, char const * x1)
{
  addrxlat_opt_arch(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_opt_arch(PyObject *self, PyObject *args)
{
  addrxlat_opt_t * x0;
  char const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "addrxlat_opt_arch", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(336), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_opt_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(336), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(22), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(22), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { addrxlat_opt_arch(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_addrxlat_opt_arch _cffi_d_addrxlat_opt_arch
#endif

static void _cffi_d_addrxlat_opt_os_type(addrxlat_opt_t * x0, char const * x1)
{
  addrxlat_opt_os_type(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_opt_os_type(PyObject *self, PyObject *args)
{
  addrxlat_opt_t * x0;
  char const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "addrxlat_opt_os_type", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(336), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_opt_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(336), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(22), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(22), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { addrxlat_opt_os_type(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_addrxlat_opt_os_type _cffi_d_addrxlat_opt_os_type
#endif

static void _cffi_d_addrxlat_opt_page_shift(addrxlat_opt_t * x0, unsigned long x1)
{
  addrxlat_opt_page_shift(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_opt_page_shift(PyObject *self, PyObject *args)
{
  addrxlat_opt_t * x0;
  unsigned long x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "addrxlat_opt_page_shift", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(336), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_opt_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(336), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, unsigned long);
  if (x1 == (unsigned long)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { addrxlat_opt_page_shift(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_addrxlat_opt_page_shift _cffi_d_addrxlat_opt_page_shift
#endif

static void _cffi_d_addrxlat_opt_phys_base(addrxlat_opt_t * x0, uint_fast64_t x1)
{
  addrxlat_opt_phys_base(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_opt_phys_base(PyObject *self, PyObject *args)
{
  addrxlat_opt_t * x0;
  uint_fast64_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "addrxlat_opt_phys_base", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(336), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_opt_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(336), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, uint_fast64_t);
  if (x1 == (uint_fast64_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { addrxlat_opt_phys_base(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_addrxlat_opt_phys_base _cffi_d_addrxlat_opt_phys_base
#endif

static void _cffi_d_addrxlat_opt_phys_bits(addrxlat_opt_t * x0, unsigned long x1)
{
  addrxlat_opt_phys_bits(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_opt_phys_bits(PyObject *self, PyObject *args)
{
  addrxlat_opt_t * x0;
  unsigned long x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "addrxlat_opt_phys_bits", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(336), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_opt_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(336), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, unsigned long);
  if (x1 == (unsigned long)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { addrxlat_opt_phys_bits(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_addrxlat_opt_phys_bits _cffi_d_addrxlat_opt_phys_bits
#endif

static void _cffi_d_addrxlat_opt_rootpgt(addrxlat_opt_t * x0, addrxlat_fulladdr_t const * x1)
{
  addrxlat_opt_rootpgt(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_opt_rootpgt(PyObject *self, PyObject *args)
{
  addrxlat_opt_t * x0;
  addrxlat_fulladdr_t const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "addrxlat_opt_rootpgt", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(336), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_opt_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(336), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(60), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (addrxlat_fulladdr_t const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(60), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { addrxlat_opt_rootpgt(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_addrxlat_opt_rootpgt _cffi_d_addrxlat_opt_rootpgt
#endif

static void _cffi_d_addrxlat_opt_version_code(addrxlat_opt_t * x0, unsigned long x1)
{
  addrxlat_opt_version_code(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_opt_version_code(PyObject *self, PyObject *args)
{
  addrxlat_opt_t * x0;
  unsigned long x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "addrxlat_opt_version_code", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(336), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_opt_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(336), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, unsigned long);
  if (x1 == (unsigned long)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { addrxlat_opt_version_code(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_addrxlat_opt_version_code _cffi_d_addrxlat_opt_version_code
#endif

static void _cffi_d_addrxlat_opt_virt_bits(addrxlat_opt_t * x0, unsigned long x1)
{
  addrxlat_opt_virt_bits(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_opt_virt_bits(PyObject *self, PyObject *args)
{
  addrxlat_opt_t * x0;
  unsigned long x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "addrxlat_opt_virt_bits", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(336), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_opt_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(336), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, unsigned long);
  if (x1 == (unsigned long)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { addrxlat_opt_virt_bits(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_addrxlat_opt_virt_bits _cffi_d_addrxlat_opt_virt_bits
#endif

static void _cffi_d_addrxlat_opt_xen_p2m_mfn(addrxlat_opt_t * x0, unsigned long x1)
{
  addrxlat_opt_xen_p2m_mfn(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_opt_xen_p2m_mfn(PyObject *self, PyObject *args)
{
  addrxlat_opt_t * x0;
  unsigned long x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "addrxlat_opt_xen_p2m_mfn", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(336), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_opt_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(336), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, unsigned long);
  if (x1 == (unsigned long)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { addrxlat_opt_xen_p2m_mfn(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_addrxlat_opt_xen_p2m_mfn _cffi_d_addrxlat_opt_xen_p2m_mfn
#endif

static void _cffi_d_addrxlat_opt_xen_xlat(addrxlat_opt_t * x0, unsigned long x1)
{
  addrxlat_opt_xen_xlat(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_opt_xen_xlat(PyObject *self, PyObject *args)
{
  addrxlat_opt_t * x0;
  unsigned long x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "addrxlat_opt_xen_xlat", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(336), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_opt_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(336), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, unsigned long);
  if (x1 == (unsigned long)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { addrxlat_opt_xen_xlat(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_addrxlat_opt_xen_xlat _cffi_d_addrxlat_opt_xen_xlat
#endif

static addrxlat_pte_format_t _cffi_d_addrxlat_pte_format(char const * x0)
{
  return addrxlat_pte_format(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_pte_format(PyObject *self, PyObject *arg0)
{
  char const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  addrxlat_pte_format_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(22), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(22), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_pte_format(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(92));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_pte_format _cffi_d_addrxlat_pte_format
#endif

static char const * _cffi_d_addrxlat_pte_format_name(addrxlat_pte_format_t x0)
{
  return addrxlat_pte_format_name(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_pte_format_name(PyObject *self, PyObject *arg0)
{
  addrxlat_pte_format_t x0;
  char const * result;
  PyObject *pyresult;

  if (_cffi_to_c((char *)&x0, _cffi_type(92), arg0) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_pte_format_name(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(22));
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_pte_format_name _cffi_d_addrxlat_pte_format_name
#endif

static int _cffi_d_addrxlat_pteval_shift(addrxlat_pte_format_t x0)
{
  return addrxlat_pteval_shift(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_pteval_shift(PyObject *self, PyObject *arg0)
{
  addrxlat_pte_format_t x0;
  int result;
  PyObject *pyresult;

  if (_cffi_to_c((char *)&x0, _cffi_type(92), arg0) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_pteval_shift(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_pteval_shift _cffi_d_addrxlat_pteval_shift
#endif

static addrxlat_status _cffi_d_addrxlat_step(addrxlat_step_t * x0)
{
  return addrxlat_step(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_step(PyObject *self, PyObject *arg0)
{
  addrxlat_step_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  addrxlat_status result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(63), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_step_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(63), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_step(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(44));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_step _cffi_d_addrxlat_step
#endif

static char const * _cffi_d_addrxlat_strerror(addrxlat_status x0)
{
  return addrxlat_strerror(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_strerror(PyObject *self, PyObject *arg0)
{
  addrxlat_status x0;
  char const * result;
  PyObject *pyresult;

  if (_cffi_to_c((char *)&x0, _cffi_type(44), arg0) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_strerror(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(22));
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_strerror _cffi_d_addrxlat_strerror
#endif

static unsigned long _cffi_d_addrxlat_sys_decref(addrxlat_sys_t * x0)
{
  return addrxlat_sys_decref(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_sys_decref(PyObject *self, PyObject *arg0)
{
  addrxlat_sys_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned long result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(51), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_sys_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(51), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_sys_decref(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_sys_decref _cffi_d_addrxlat_sys_decref
#endif

static addrxlat_map_t * _cffi_d_addrxlat_sys_get_map(addrxlat_sys_t const * x0, addrxlat_sys_map_t x1)
{
  return addrxlat_sys_get_map(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_sys_get_map(PyObject *self, PyObject *args)
{
  addrxlat_sys_t const * x0;
  addrxlat_sys_map_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  addrxlat_map_t * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "addrxlat_sys_get_map", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(12), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_sys_t const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(12), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(13), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_sys_get_map(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(54));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_sys_get_map _cffi_d_addrxlat_sys_get_map
#endif

static addrxlat_meth_t const * _cffi_d_addrxlat_sys_get_meth(addrxlat_sys_t const * x0, addrxlat_sys_meth_t x1)
{
  return addrxlat_sys_get_meth(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_sys_get_meth(PyObject *self, PyObject *args)
{
  addrxlat_sys_t const * x0;
  addrxlat_sys_meth_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  addrxlat_meth_t const * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "addrxlat_sys_get_meth", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(12), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_sys_t const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(12), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(19), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_sys_get_meth(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(359));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_sys_get_meth _cffi_d_addrxlat_sys_get_meth
#endif

static unsigned long _cffi_d_addrxlat_sys_incref(addrxlat_sys_t * x0)
{
  return addrxlat_sys_incref(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_sys_incref(PyObject *self, PyObject *arg0)
{
  addrxlat_sys_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned long result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(51), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_sys_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(51), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_sys_incref(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_sys_incref _cffi_d_addrxlat_sys_incref
#endif

static addrxlat_sys_t * _cffi_d_addrxlat_sys_new(void)
{
  return addrxlat_sys_new();
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_sys_new(PyObject *self, PyObject *noarg)
{
  addrxlat_sys_t * result;
  PyObject *pyresult;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_sys_new(); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  (void)noarg; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(51));
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_sys_new _cffi_d_addrxlat_sys_new
#endif

static addrxlat_status _cffi_d_addrxlat_sys_os_init(addrxlat_sys_t * x0, addrxlat_ctx_t * x1, unsigned int x2, addrxlat_opt_t const * x3)
{
  return addrxlat_sys_os_init(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_sys_os_init(PyObject *self, PyObject *args)
{
  addrxlat_sys_t * x0;
  addrxlat_ctx_t * x1;
  unsigned int x2;
  addrxlat_opt_t const * x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  addrxlat_status result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "addrxlat_sys_os_init", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(51), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_sys_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(51), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (addrxlat_ctx_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x2 = _cffi_to_c_int(arg2, unsigned int);
  if (x2 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(73), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (addrxlat_opt_t const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(73), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_sys_os_init(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(44));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_sys_os_init _cffi_d_addrxlat_sys_os_init
#endif

static void _cffi_d_addrxlat_sys_set_map(addrxlat_sys_t * x0, addrxlat_sys_map_t x1, addrxlat_map_t * x2)
{
  addrxlat_sys_set_map(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_sys_set_map(PyObject *self, PyObject *args)
{
  addrxlat_sys_t * x0;
  addrxlat_sys_map_t x1;
  addrxlat_map_t * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "addrxlat_sys_set_map", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(51), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_sys_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(51), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(13), arg1) < 0)
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(54), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (addrxlat_map_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(54), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { addrxlat_sys_set_map(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_addrxlat_sys_set_map _cffi_d_addrxlat_sys_set_map
#endif

static void _cffi_d_addrxlat_sys_set_meth(addrxlat_sys_t * x0, addrxlat_sys_meth_t x1, addrxlat_meth_t const * x2)
{
  addrxlat_sys_set_meth(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_sys_set_meth(PyObject *self, PyObject *args)
{
  addrxlat_sys_t * x0;
  addrxlat_sys_meth_t x1;
  addrxlat_meth_t const * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "addrxlat_sys_set_meth", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(51), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_sys_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(51), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(19), arg1) < 0)
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(359), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (addrxlat_meth_t const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(359), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { addrxlat_sys_set_meth(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_addrxlat_sys_set_meth _cffi_d_addrxlat_sys_set_meth
#endif

static addrxlat_status _cffi_d_addrxlat_walk(addrxlat_step_t * x0)
{
  return addrxlat_walk(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_addrxlat_walk(PyObject *self, PyObject *arg0)
{
  addrxlat_step_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  addrxlat_status result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(63), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (addrxlat_step_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(63), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = addrxlat_walk(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(44));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_addrxlat_walk _cffi_d_addrxlat_walk
#endif

static void _cffi_d_free(void * x0)
{
  free(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_free(PyObject *self, PyObject *arg0)
{
  void * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(76), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (void *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(76), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { free(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_free _cffi_d_free
#endif

static void _cffi_d_kdump_attr_discard(kdump_ctx_t * x0, kdump_attr_t * x1)
{
  kdump_attr_discard(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_kdump_attr_discard(PyObject *self, PyObject *args)
{
  kdump_ctx_t * x0;
  kdump_attr_t * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "kdump_attr_discard", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(101), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (kdump_ctx_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(101), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(185), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (kdump_attr_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(185), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { kdump_attr_discard(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_kdump_attr_discard _cffi_d_kdump_attr_discard
#endif

static void _cffi_d_kdump_attr_iter_end(kdump_ctx_t * x0, kdump_attr_iter_t * x1)
{
  kdump_attr_iter_end(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_kdump_attr_iter_end(PyObject *self, PyObject *args)
{
  kdump_ctx_t * x0;
  kdump_attr_iter_t * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "kdump_attr_iter_end", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(101), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (kdump_ctx_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(101), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(175), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (kdump_attr_iter_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(175), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { kdump_attr_iter_end(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_kdump_attr_iter_end _cffi_d_kdump_attr_iter_end
#endif

static kdump_status _cffi_d_kdump_attr_iter_next(kdump_ctx_t * x0, kdump_attr_iter_t * x1)
{
  return kdump_attr_iter_next(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_kdump_attr_iter_next(PyObject *self, PyObject *args)
{
  kdump_ctx_t * x0;
  kdump_attr_iter_t * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  kdump_status result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "kdump_attr_iter_next", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(101), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (kdump_ctx_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(101), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(175), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (kdump_attr_iter_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(175), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = kdump_attr_iter_next(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(104));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_kdump_attr_iter_next _cffi_d_kdump_attr_iter_next
#endif

static kdump_status _cffi_d_kdump_attr_iter_start(kdump_ctx_t * x0, char const * x1, kdump_attr_iter_t * x2)
{
  return kdump_attr_iter_start(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_kdump_attr_iter_start(PyObject *self, PyObject *args)
{
  kdump_ctx_t * x0;
  char const * x1;
  kdump_attr_iter_t * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  kdump_status result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "kdump_attr_iter_start", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(101), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (kdump_ctx_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(101), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(22), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(22), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(175), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (kdump_attr_iter_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(175), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = kdump_attr_iter_start(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(104));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_kdump_attr_iter_start _cffi_d_kdump_attr_iter_start
#endif

static kdump_status _cffi_d_kdump_attr_ref(kdump_ctx_t * x0, char const * x1, kdump_attr_ref_t * x2)
{
  return kdump_attr_ref(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_kdump_attr_ref(PyObject *self, PyObject *args)
{
  kdump_ctx_t * x0;
  char const * x1;
  kdump_attr_ref_t * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  kdump_status result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "kdump_attr_ref", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(101), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (kdump_ctx_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(101), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(22), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(22), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(110), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (kdump_attr_ref_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(110), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = kdump_attr_ref(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(104));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_kdump_attr_ref _cffi_d_kdump_attr_ref
#endif

static kdump_status _cffi_d_kdump_attr_ref_get(kdump_ctx_t * x0, kdump_attr_ref_t const * x1, kdump_attr_t * x2)
{
  return kdump_attr_ref_get(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_kdump_attr_ref_get(PyObject *self, PyObject *args)
{
  kdump_ctx_t * x0;
  kdump_attr_ref_t const * x1;
  kdump_attr_t * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  kdump_status result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "kdump_attr_ref_get", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(101), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (kdump_ctx_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(101), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(236), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (kdump_attr_ref_t const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(236), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(185), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (kdump_attr_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(185), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = kdump_attr_ref_get(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(104));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_kdump_attr_ref_get _cffi_d_kdump_attr_ref_get
#endif

static int _cffi_d_kdump_attr_ref_isset(kdump_attr_ref_t * x0)
{
  return kdump_attr_ref_isset(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_kdump_attr_ref_isset(PyObject *self, PyObject *arg0)
{
  kdump_attr_ref_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(110), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (kdump_attr_ref_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(110), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = kdump_attr_ref_isset(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_kdump_attr_ref_isset _cffi_d_kdump_attr_ref_isset
#endif

static kdump_status _cffi_d_kdump_attr_ref_iter_start(kdump_ctx_t * x0, kdump_attr_ref_t const * x1, kdump_attr_iter_t * x2)
{
  return kdump_attr_ref_iter_start(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_kdump_attr_ref_iter_start(PyObject *self, PyObject *args)
{
  kdump_ctx_t * x0;
  kdump_attr_ref_t const * x1;
  kdump_attr_iter_t * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  kdump_status result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "kdump_attr_ref_iter_start", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(101), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (kdump_ctx_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(101), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(236), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (kdump_attr_ref_t const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(236), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(175), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (kdump_attr_iter_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(175), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = kdump_attr_ref_iter_start(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(104));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_kdump_attr_ref_iter_start _cffi_d_kdump_attr_ref_iter_start
#endif

static kdump_status _cffi_d_kdump_attr_ref_set(kdump_ctx_t * x0, kdump_attr_ref_t * x1, kdump_attr_t const * x2)
{
  return kdump_attr_ref_set(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_kdump_attr_ref_set(PyObject *self, PyObject *args)
{
  kdump_ctx_t * x0;
  kdump_attr_ref_t * x1;
  kdump_attr_t const * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  kdump_status result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "kdump_attr_ref_set", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(101), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (kdump_ctx_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(101), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(110), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (kdump_attr_ref_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(110), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(190), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (kdump_attr_t const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(190), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = kdump_attr_ref_set(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(104));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_kdump_attr_ref_set _cffi_d_kdump_attr_ref_set
#endif

static kdump_attr_type_t _cffi_d_kdump_attr_ref_type(kdump_attr_ref_t * x0)
{
  return kdump_attr_ref_type(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_kdump_attr_ref_type(PyObject *self, PyObject *arg0)
{
  kdump_attr_ref_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  kdump_attr_type_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(110), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (kdump_attr_ref_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(110), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = kdump_attr_ref_type(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(195));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_kdump_attr_ref_type _cffi_d_kdump_attr_ref_type
#endif

static void _cffi_d_kdump_attr_unref(kdump_ctx_t * x0, kdump_attr_ref_t * x1)
{
  kdump_attr_unref(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_kdump_attr_unref(PyObject *self, PyObject *args)
{
  kdump_ctx_t * x0;
  kdump_attr_ref_t * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "kdump_attr_unref", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(101), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (kdump_ctx_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(101), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(110), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (kdump_attr_ref_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(110), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { kdump_attr_unref(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_kdump_attr_unref _cffi_d_kdump_attr_unref
#endif

static unsigned long _cffi_d_kdump_blob_decref(kdump_blob_t * x0)
{
  return kdump_blob_decref(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_kdump_blob_decref(PyObject *self, PyObject *arg0)
{
  kdump_blob_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned long result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(130), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (kdump_blob_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(130), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = kdump_blob_decref(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_kdump_blob_decref _cffi_d_kdump_blob_decref
#endif

static unsigned long _cffi_d_kdump_blob_incref(kdump_blob_t * x0)
{
  return kdump_blob_incref(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_kdump_blob_incref(PyObject *self, PyObject *arg0)
{
  kdump_blob_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned long result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(130), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (kdump_blob_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(130), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = kdump_blob_incref(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_kdump_blob_incref _cffi_d_kdump_blob_incref
#endif

static kdump_blob_t * _cffi_d_kdump_blob_new(void * x0, size_t x1)
{
  return kdump_blob_new(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_kdump_blob_new(PyObject *self, PyObject *args)
{
  void * x0;
  size_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  kdump_blob_t * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "kdump_blob_new", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(76), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (void *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(76), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, size_t);
  if (x1 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = kdump_blob_new(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(130));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_kdump_blob_new _cffi_d_kdump_blob_new
#endif

static kdump_blob_t * _cffi_d_kdump_blob_new_dup(void const * x0, size_t x1)
{
  return kdump_blob_new_dup(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_kdump_blob_new_dup(PyObject *self, PyObject *args)
{
  void const * x0;
  size_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  kdump_blob_t * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "kdump_blob_new_dup", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(120), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (void const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(120), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, size_t);
  if (x1 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = kdump_blob_new_dup(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(130));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_kdump_blob_new_dup _cffi_d_kdump_blob_new_dup
#endif

static void * _cffi_d_kdump_blob_pin(kdump_blob_t * x0)
{
  return kdump_blob_pin(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_kdump_blob_pin(PyObject *self, PyObject *arg0)
{
  kdump_blob_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  void * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(130), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (kdump_blob_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(130), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = kdump_blob_pin(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(76));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_kdump_blob_pin _cffi_d_kdump_blob_pin
#endif

static kdump_status _cffi_d_kdump_blob_set(kdump_blob_t * x0, void * x1, size_t x2)
{
  return kdump_blob_set(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_kdump_blob_set(PyObject *self, PyObject *args)
{
  kdump_blob_t * x0;
  void * x1;
  size_t x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  kdump_status result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "kdump_blob_set", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(130), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (kdump_blob_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(130), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(76), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (void *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(76), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x2 = _cffi_to_c_int(arg2, size_t);
  if (x2 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = kdump_blob_set(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(104));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_kdump_blob_set _cffi_d_kdump_blob_set
#endif

static size_t _cffi_d_kdump_blob_size(kdump_blob_t const * x0)
{
  return kdump_blob_size(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_kdump_blob_size(PyObject *self, PyObject *arg0)
{
  kdump_blob_t const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  size_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(275), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (kdump_blob_t const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(275), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = kdump_blob_size(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, size_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_kdump_blob_size _cffi_d_kdump_blob_size
#endif

static unsigned long _cffi_d_kdump_blob_unpin(kdump_blob_t * x0)
{
  return kdump_blob_unpin(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_kdump_blob_unpin(PyObject *self, PyObject *arg0)
{
  kdump_blob_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned long result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(130), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (kdump_blob_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(130), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = kdump_blob_unpin(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_kdump_blob_unpin _cffi_d_kdump_blob_unpin
#endif

static unsigned long _cffi_d_kdump_bmp_decref(kdump_bmp_t * x0)
{
  return kdump_bmp_decref(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_kdump_bmp_decref(PyObject *self, PyObject *arg0)
{
  kdump_bmp_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned long result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(135), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (kdump_bmp_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(135), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = kdump_bmp_decref(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_kdump_bmp_decref _cffi_d_kdump_bmp_decref
#endif

static kdump_status _cffi_d_kdump_bmp_find_clear(kdump_bmp_t * x0, uint_fast64_t * x1)
{
  return kdump_bmp_find_clear(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_kdump_bmp_find_clear(PyObject *self, PyObject *args)
{
  kdump_bmp_t * x0;
  uint_fast64_t * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  kdump_status result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "kdump_bmp_find_clear", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(135), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (kdump_bmp_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(135), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(35), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (uint_fast64_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(35), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = kdump_bmp_find_clear(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(104));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_kdump_bmp_find_clear _cffi_d_kdump_bmp_find_clear
#endif

static kdump_status _cffi_d_kdump_bmp_find_set(kdump_bmp_t * x0, uint_fast64_t * x1)
{
  return kdump_bmp_find_set(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_kdump_bmp_find_set(PyObject *self, PyObject *args)
{
  kdump_bmp_t * x0;
  uint_fast64_t * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  kdump_status result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "kdump_bmp_find_set", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(135), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (kdump_bmp_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(135), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(35), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (uint_fast64_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(35), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = kdump_bmp_find_set(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(104));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_kdump_bmp_find_set _cffi_d_kdump_bmp_find_set
#endif

static kdump_status _cffi_d_kdump_bmp_get_bits(kdump_bmp_t * x0, uint_fast64_t x1, uint_fast64_t x2, unsigned char * x3)
{
  return kdump_bmp_get_bits(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_kdump_bmp_get_bits(PyObject *self, PyObject *args)
{
  kdump_bmp_t * x0;
  uint_fast64_t x1;
  uint_fast64_t x2;
  unsigned char * x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  kdump_status result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "kdump_bmp_get_bits", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(135), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (kdump_bmp_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(135), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, uint_fast64_t);
  if (x1 == (uint_fast64_t)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, uint_fast64_t);
  if (x2 == (uint_fast64_t)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(142), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (unsigned char *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(142), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = kdump_bmp_get_bits(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(104));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_kdump_bmp_get_bits _cffi_d_kdump_bmp_get_bits
#endif

static char const * _cffi_d_kdump_bmp_get_err(kdump_bmp_t const * x0)
{
  return kdump_bmp_get_err(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_kdump_bmp_get_err(PyObject *self, PyObject *arg0)
{
  kdump_bmp_t const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  char const * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(98), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (kdump_bmp_t const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(98), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = kdump_bmp_get_err(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(22));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_kdump_bmp_get_err _cffi_d_kdump_bmp_get_err
#endif

static unsigned long _cffi_d_kdump_bmp_incref(kdump_bmp_t * x0)
{
  return kdump_bmp_incref(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_kdump_bmp_incref(PyObject *self, PyObject *arg0)
{
  kdump_bmp_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  unsigned long result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(135), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (kdump_bmp_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(135), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = kdump_bmp_incref(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, unsigned long);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_kdump_bmp_incref _cffi_d_kdump_bmp_incref
#endif

static kdump_status _cffi_d_kdump_clear_attr(kdump_ctx_t * x0, char const * x1)
{
  return kdump_clear_attr(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_kdump_clear_attr(PyObject *self, PyObject *args)
{
  kdump_ctx_t * x0;
  char const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  kdump_status result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "kdump_clear_attr", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(101), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (kdump_ctx_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(101), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(22), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(22), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = kdump_clear_attr(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(104));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_kdump_clear_attr _cffi_d_kdump_clear_attr
#endif

static void _cffi_d_kdump_clear_err(kdump_ctx_t * x0)
{
  kdump_clear_err(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_kdump_clear_err(PyObject *self, PyObject *arg0)
{
  kdump_ctx_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(101), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (kdump_ctx_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(101), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { kdump_clear_err(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_kdump_clear_err _cffi_d_kdump_clear_err
#endif

static kdump_ctx_t * _cffi_d_kdump_clone(kdump_ctx_t const * x0, unsigned long x1)
{
  return kdump_clone(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_kdump_clone(PyObject *self, PyObject *args)
{
  kdump_ctx_t const * x0;
  unsigned long x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  kdump_ctx_t * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "kdump_clone", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(124), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (kdump_ctx_t const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(124), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, unsigned long);
  if (x1 == (unsigned long)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = kdump_clone(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(101));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_kdump_clone _cffi_d_kdump_clone
#endif

static uint_fast16_t _cffi_d_kdump_d16toh(kdump_ctx_t * x0, uint_fast16_t x1)
{
  return kdump_d16toh(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_kdump_d16toh(PyObject *self, PyObject *args)
{
  kdump_ctx_t * x0;
  uint_fast16_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  uint_fast16_t result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "kdump_d16toh", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(101), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (kdump_ctx_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(101), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, uint_fast16_t);
  if (x1 == (uint_fast16_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = kdump_d16toh(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, uint_fast16_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_kdump_d16toh _cffi_d_kdump_d16toh
#endif

static uint_fast32_t _cffi_d_kdump_d32toh(kdump_ctx_t * x0, uint_fast32_t x1)
{
  return kdump_d32toh(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_kdump_d32toh(PyObject *self, PyObject *args)
{
  kdump_ctx_t * x0;
  uint_fast32_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  uint_fast32_t result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "kdump_d32toh", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(101), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (kdump_ctx_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(101), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, uint_fast32_t);
  if (x1 == (uint_fast32_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = kdump_d32toh(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, uint_fast32_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_kdump_d32toh _cffi_d_kdump_d32toh
#endif

static uint_fast64_t _cffi_d_kdump_d64toh(kdump_ctx_t * x0, uint_fast64_t x1)
{
  return kdump_d64toh(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_kdump_d64toh(PyObject *self, PyObject *args)
{
  kdump_ctx_t * x0;
  uint_fast64_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  uint_fast64_t result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "kdump_d64toh", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(101), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (kdump_ctx_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(101), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, uint_fast64_t);
  if (x1 == (uint_fast64_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = kdump_d64toh(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, uint_fast64_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_kdump_d64toh _cffi_d_kdump_d64toh
#endif

static void _cffi_const_kdump_err(char *o)
{
  *(kdump_status(* *)(kdump_ctx_t *, kdump_status, char const *, ...))o = kdump_err;
}

static void _cffi_d_kdump_free(kdump_ctx_t * x0)
{
  kdump_free(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_kdump_free(PyObject *self, PyObject *arg0)
{
  kdump_ctx_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(101), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (kdump_ctx_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(101), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { kdump_free(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_kdump_free _cffi_d_kdump_free
#endif

static kdump_status _cffi_d_kdump_get_address_attr(kdump_ctx_t * x0, char const * x1, uint_fast64_t * x2)
{
  return kdump_get_address_attr(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_kdump_get_address_attr(PyObject *self, PyObject *args)
{
  kdump_ctx_t * x0;
  char const * x1;
  uint_fast64_t * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  kdump_status result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "kdump_get_address_attr", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(101), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (kdump_ctx_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(101), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(22), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(22), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(35), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (uint_fast64_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(35), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = kdump_get_address_attr(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(104));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_kdump_get_address_attr _cffi_d_kdump_get_address_attr
#endif

static kdump_status _cffi_d_kdump_get_addrxlat(kdump_ctx_t * x0, addrxlat_ctx_t * * x1, addrxlat_sys_t * * x2)
{
  return kdump_get_addrxlat(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_kdump_get_addrxlat(PyObject *self, PyObject *args)
{
  kdump_ctx_t * x0;
  addrxlat_ctx_t * * x1;
  addrxlat_sys_t * * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  kdump_status result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "kdump_get_addrxlat", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(101), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (kdump_ctx_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(101), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(146), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (addrxlat_ctx_t * *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(146), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(147), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (addrxlat_sys_t * *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(147), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = kdump_get_addrxlat(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(104));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_kdump_get_addrxlat _cffi_d_kdump_get_addrxlat
#endif

static kdump_status _cffi_d_kdump_get_attr(kdump_ctx_t * x0, char const * x1, kdump_attr_t * x2)
{
  return kdump_get_attr(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_kdump_get_attr(PyObject *self, PyObject *args)
{
  kdump_ctx_t * x0;
  char const * x1;
  kdump_attr_t * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  kdump_status result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "kdump_get_attr", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(101), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (kdump_ctx_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(101), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(22), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(22), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(185), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (kdump_attr_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(185), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = kdump_get_attr(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(104));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_kdump_get_attr _cffi_d_kdump_get_attr
#endif

static char const * _cffi_d_kdump_get_err(kdump_ctx_t * x0)
{
  return kdump_get_err(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_kdump_get_err(PyObject *self, PyObject *arg0)
{
  kdump_ctx_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  char const * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(101), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (kdump_ctx_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(101), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = kdump_get_err(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(22));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_kdump_get_err _cffi_d_kdump_get_err
#endif

static kdump_status _cffi_d_kdump_get_number_attr(kdump_ctx_t * x0, char const * x1, uint_fast64_t * x2)
{
  return kdump_get_number_attr(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_kdump_get_number_attr(PyObject *self, PyObject *args)
{
  kdump_ctx_t * x0;
  char const * x1;
  uint_fast64_t * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  kdump_status result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "kdump_get_number_attr", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(101), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (kdump_ctx_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(101), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(22), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(22), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(35), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (uint_fast64_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(35), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = kdump_get_number_attr(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(104));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_kdump_get_number_attr _cffi_d_kdump_get_number_attr
#endif

static kdump_status _cffi_d_kdump_get_string_attr(kdump_ctx_t * x0, char const * x1, char const * * x2)
{
  return kdump_get_string_attr(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_kdump_get_string_attr(PyObject *self, PyObject *args)
{
  kdump_ctx_t * x0;
  char const * x1;
  char const * * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  kdump_status result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "kdump_get_string_attr", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(101), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (kdump_ctx_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(101), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(22), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(22), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(165), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (char const * *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(165), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = kdump_get_string_attr(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(104));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_kdump_get_string_attr _cffi_d_kdump_get_string_attr
#endif

static kdump_status _cffi_d_kdump_get_typed_attr(kdump_ctx_t * x0, char const * x1, kdump_attr_type_t x2, kdump_attr_value_t * x3)
{
  return kdump_get_typed_attr(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_kdump_get_typed_attr(PyObject *self, PyObject *args)
{
  kdump_ctx_t * x0;
  char const * x1;
  kdump_attr_type_t x2;
  kdump_attr_value_t * x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  kdump_status result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "kdump_get_typed_attr", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(101), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (kdump_ctx_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(101), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(22), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(22), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x2, _cffi_type(195), arg2) < 0)
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(196), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (kdump_attr_value_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(196), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = kdump_get_typed_attr(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(104));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_kdump_get_typed_attr _cffi_d_kdump_get_typed_attr
#endif

static kdump_ctx_t * _cffi_d_kdump_new(void)
{
  return kdump_new();
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_kdump_new(PyObject *self, PyObject *noarg)
{
  kdump_ctx_t * result;
  PyObject *pyresult;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = kdump_new(); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  (void)noarg; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(101));
  return pyresult;
}
#else
#  define _cffi_f_kdump_new _cffi_d_kdump_new
#endif

static kdump_status _cffi_d_kdump_open_fd(kdump_ctx_t * x0, int x1)
{
  return kdump_open_fd(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_kdump_open_fd(PyObject *self, PyObject *args)
{
  kdump_ctx_t * x0;
  int x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  kdump_status result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "kdump_open_fd", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(101), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (kdump_ctx_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(101), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = kdump_open_fd(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(104));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_kdump_open_fd _cffi_d_kdump_open_fd
#endif

static kdump_status _cffi_d_kdump_open_fdset(kdump_ctx_t * x0, unsigned int x1, int const * x2)
{
  return kdump_open_fdset(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_kdump_open_fdset(PyObject *self, PyObject *args)
{
  kdump_ctx_t * x0;
  unsigned int x1;
  int const * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  kdump_status result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "kdump_open_fdset", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(101), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (kdump_ctx_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(101), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, unsigned int);
  if (x1 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(269), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (int const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(269), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = kdump_open_fdset(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(104));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_kdump_open_fdset _cffi_d_kdump_open_fdset
#endif

static kdump_status _cffi_d_kdump_read(kdump_ctx_t * x0, kdump_addrspace_t x1, uint_fast64_t x2, void * x3, size_t * x4)
{
  return kdump_read(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_kdump_read(PyObject *self, PyObject *args)
{
  kdump_ctx_t * x0;
  kdump_addrspace_t x1;
  uint_fast64_t x2;
  void * x3;
  size_t * x4;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  kdump_status result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "kdump_read", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(101), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (kdump_ctx_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(101), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(214), arg1) < 0)
    return NULL;

  x2 = _cffi_to_c_int(arg2, uint_fast64_t);
  if (x2 == (uint_fast64_t)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(76), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (void *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(76), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(223), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (size_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(223), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = kdump_read(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(104));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_kdump_read _cffi_d_kdump_read
#endif

static kdump_status _cffi_d_kdump_read_string(kdump_ctx_t * x0, kdump_addrspace_t x1, uint_fast64_t x2, char * * x3)
{
  return kdump_read_string(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_kdump_read_string(PyObject *self, PyObject *args)
{
  kdump_ctx_t * x0;
  kdump_addrspace_t x1;
  uint_fast64_t x2;
  char * * x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  kdump_status result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "kdump_read_string", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(101), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (kdump_ctx_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(101), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(214), arg1) < 0)
    return NULL;

  x2 = _cffi_to_c_int(arg2, uint_fast64_t);
  if (x2 == (uint_fast64_t)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(151), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (char * *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(151), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = kdump_read_string(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(104));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_kdump_read_string _cffi_d_kdump_read_string
#endif

static kdump_status _cffi_d_kdump_set_address_attr(kdump_ctx_t * x0, char const * x1, uint_fast64_t x2)
{
  return kdump_set_address_attr(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_kdump_set_address_attr(PyObject *self, PyObject *args)
{
  kdump_ctx_t * x0;
  char const * x1;
  uint_fast64_t x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  kdump_status result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "kdump_set_address_attr", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(101), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (kdump_ctx_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(101), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(22), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(22), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x2 = _cffi_to_c_int(arg2, uint_fast64_t);
  if (x2 == (uint_fast64_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = kdump_set_address_attr(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(104));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_kdump_set_address_attr _cffi_d_kdump_set_address_attr
#endif

static kdump_status _cffi_d_kdump_set_attr(kdump_ctx_t * x0, char const * x1, kdump_attr_t const * x2)
{
  return kdump_set_attr(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_kdump_set_attr(PyObject *self, PyObject *args)
{
  kdump_ctx_t * x0;
  char const * x1;
  kdump_attr_t const * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  kdump_status result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "kdump_set_attr", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(101), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (kdump_ctx_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(101), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(22), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(22), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(190), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (kdump_attr_t const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(190), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = kdump_set_attr(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(104));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_kdump_set_attr _cffi_d_kdump_set_attr
#endif

static kdump_status _cffi_d_kdump_set_filename(kdump_ctx_t * x0, char const * x1)
{
  return kdump_set_filename(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_kdump_set_filename(PyObject *self, PyObject *args)
{
  kdump_ctx_t * x0;
  char const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  kdump_status result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "kdump_set_filename", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(101), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (kdump_ctx_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(101), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(22), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(22), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = kdump_set_filename(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(104));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_kdump_set_filename _cffi_d_kdump_set_filename
#endif

static kdump_status _cffi_d_kdump_set_filenames(kdump_ctx_t * x0, unsigned int x1, char const * const * x2)
{
  return kdump_set_filenames(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_kdump_set_filenames(PyObject *self, PyObject *args)
{
  kdump_ctx_t * x0;
  unsigned int x1;
  char const * const * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  kdump_status result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "kdump_set_filenames", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(101), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (kdump_ctx_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(101), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, unsigned int);
  if (x1 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(264), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (char const * const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(264), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = kdump_set_filenames(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(104));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_kdump_set_filenames _cffi_d_kdump_set_filenames
#endif

static kdump_status _cffi_d_kdump_set_number_attr(kdump_ctx_t * x0, char const * x1, uint_fast64_t x2)
{
  return kdump_set_number_attr(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_kdump_set_number_attr(PyObject *self, PyObject *args)
{
  kdump_ctx_t * x0;
  char const * x1;
  uint_fast64_t x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  kdump_status result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "kdump_set_number_attr", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(101), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (kdump_ctx_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(101), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(22), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(22), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x2 = _cffi_to_c_int(arg2, uint_fast64_t);
  if (x2 == (uint_fast64_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = kdump_set_number_attr(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(104));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_kdump_set_number_attr _cffi_d_kdump_set_number_attr
#endif

static kdump_status _cffi_d_kdump_set_string_attr(kdump_ctx_t * x0, char const * x1, char const * x2)
{
  return kdump_set_string_attr(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_kdump_set_string_attr(PyObject *self, PyObject *args)
{
  kdump_ctx_t * x0;
  char const * x1;
  char const * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  kdump_status result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "kdump_set_string_attr", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(101), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (kdump_ctx_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(101), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(22), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(22), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(22), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(22), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = kdump_set_string_attr(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(104));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_kdump_set_string_attr _cffi_d_kdump_set_string_attr
#endif

static kdump_status _cffi_d_kdump_set_sub_attr(kdump_ctx_t * x0, kdump_attr_ref_t const * x1, char const * x2, kdump_attr_t const * x3)
{
  return kdump_set_sub_attr(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_kdump_set_sub_attr(PyObject *self, PyObject *args)
{
  kdump_ctx_t * x0;
  kdump_attr_ref_t const * x1;
  char const * x2;
  kdump_attr_t const * x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  kdump_status result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "kdump_set_sub_attr", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(101), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (kdump_ctx_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(101), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(236), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (kdump_attr_ref_t const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(236), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(22), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(22), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(190), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (kdump_attr_t const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(190), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = kdump_set_sub_attr(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(104));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_kdump_set_sub_attr _cffi_d_kdump_set_sub_attr
#endif

static char const * _cffi_d_kdump_strerror(kdump_status x0)
{
  return kdump_strerror(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_kdump_strerror(PyObject *self, PyObject *arg0)
{
  kdump_status x0;
  char const * result;
  PyObject *pyresult;

  if (_cffi_to_c((char *)&x0, _cffi_type(104), arg0) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = kdump_strerror(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(22));
  return pyresult;
}
#else
#  define _cffi_f_kdump_strerror _cffi_d_kdump_strerror
#endif

static kdump_status _cffi_d_kdump_sub_attr_ref(kdump_ctx_t * x0, kdump_attr_ref_t const * x1, char const * x2, kdump_attr_ref_t * x3)
{
  return kdump_sub_attr_ref(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_kdump_sub_attr_ref(PyObject *self, PyObject *args)
{
  kdump_ctx_t * x0;
  kdump_attr_ref_t const * x1;
  char const * x2;
  kdump_attr_ref_t * x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  kdump_status result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "kdump_sub_attr_ref", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(101), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (kdump_ctx_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(101), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(236), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (kdump_attr_ref_t const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(236), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(22), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(22), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(110), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (kdump_attr_ref_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(110), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = kdump_sub_attr_ref(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(104));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_kdump_sub_attr_ref _cffi_d_kdump_sub_attr_ref
#endif

static kdump_status _cffi_d_kdump_vmcoreinfo_line(kdump_ctx_t * x0, char const * x1, char * * x2)
{
  return kdump_vmcoreinfo_line(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_kdump_vmcoreinfo_line(PyObject *self, PyObject *args)
{
  kdump_ctx_t * x0;
  char const * x1;
  char * * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  kdump_status result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "kdump_vmcoreinfo_line", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(101), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (kdump_ctx_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(101), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(22), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(22), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(151), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (char * *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(151), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = kdump_vmcoreinfo_line(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(104));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_kdump_vmcoreinfo_line _cffi_d_kdump_vmcoreinfo_line
#endif

static kdump_status _cffi_d_kdump_vmcoreinfo_raw(kdump_ctx_t * x0, char * * x1)
{
  return kdump_vmcoreinfo_raw(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_kdump_vmcoreinfo_raw(PyObject *self, PyObject *args)
{
  kdump_ctx_t * x0;
  char * * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  kdump_status result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "kdump_vmcoreinfo_raw", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(101), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (kdump_ctx_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(101), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(151), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char * *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(151), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = kdump_vmcoreinfo_raw(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(104));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_kdump_vmcoreinfo_raw _cffi_d_kdump_vmcoreinfo_raw
#endif

static kdump_status _cffi_d_kdump_vmcoreinfo_symbol(kdump_ctx_t * x0, char const * x1, uint_fast64_t * x2)
{
  return kdump_vmcoreinfo_symbol(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_kdump_vmcoreinfo_symbol(PyObject *self, PyObject *args)
{
  kdump_ctx_t * x0;
  char const * x1;
  uint_fast64_t * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  kdump_status result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "kdump_vmcoreinfo_symbol", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(101), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (kdump_ctx_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(101), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(22), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(22), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(35), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (uint_fast64_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(35), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = kdump_vmcoreinfo_symbol(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(104));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_kdump_vmcoreinfo_symbol _cffi_d_kdump_vmcoreinfo_symbol
#endif

static void * _cffi_d_malloc(size_t x0)
{
  return malloc(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_malloc(PyObject *self, PyObject *arg0)
{
  size_t x0;
  void * result;
  PyObject *pyresult;

  x0 = _cffi_to_c_int(arg0, size_t);
  if (x0 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = malloc(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(76));
  return pyresult;
}
#else
#  define _cffi_f_malloc _cffi_d_malloc
#endif

static int _cffi_const_ADDRXLAT_ADDR_MAX(unsigned long long *o)
{
  int n = (ADDRXLAT_ADDR_MAX) <= 0;
  *o = (unsigned long long)((ADDRXLAT_ADDR_MAX) | 0);  /* check that ADDRXLAT_ADDR_MAX is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_FIELDS_MAX(unsigned long long *o)
{
  int n = (ADDRXLAT_FIELDS_MAX) <= 0;
  *o = (unsigned long long)((ADDRXLAT_FIELDS_MAX) | 0);  /* check that ADDRXLAT_FIELDS_MAX is an integer */
  if (!_cffi_check_int(*o, n, 8U))
    n |= 2;
  return n;
}

static int _cffi_const_ADDRXLAT_SYS_METH_CUSTOM_NUM(unsigned long long *o)
{
  int n = (ADDRXLAT_SYS_METH_CUSTOM_NUM) <= 0;
  *o = (unsigned long long)((ADDRXLAT_SYS_METH_CUSTOM_NUM) | 0);  /* check that ADDRXLAT_SYS_METH_CUSTOM_NUM is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_SYS_METH_NUM(unsigned long long *o)
{
  int n = (ADDRXLAT_SYS_METH_NUM) <= 0;
  *o = (unsigned long long)((ADDRXLAT_SYS_METH_NUM) | 0);  /* check that ADDRXLAT_SYS_METH_NUM is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_VERSION(unsigned long long *o)
{
  int n = (ADDRXLAT_VERSION) <= 0;
  *o = (unsigned long long)((ADDRXLAT_VERSION) | 0);  /* check that ADDRXLAT_VERSION is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_VER_MAJOR(unsigned long long *o)
{
  int n = (ADDRXLAT_VER_MAJOR) <= 0;
  *o = (unsigned long long)((ADDRXLAT_VER_MAJOR) | 0);  /* check that ADDRXLAT_VER_MAJOR is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_VER_MICRO(unsigned long long *o)
{
  int n = (ADDRXLAT_VER_MICRO) <= 0;
  *o = (unsigned long long)((ADDRXLAT_VER_MICRO) | 0);  /* check that ADDRXLAT_VER_MICRO is an integer */
  return n;
}

static int _cffi_const_ADDRXLAT_VER_MINOR(unsigned long long *o)
{
  int n = (ADDRXLAT_VER_MINOR) <= 0;
  *o = (unsigned long long)((ADDRXLAT_VER_MINOR) | 0);  /* check that ADDRXLAT_VER_MINOR is an integer */
  return n;
}

static int _cffi_const_KDUMPFILE_VERSION(unsigned long long *o)
{
  int n = (KDUMPFILE_VERSION) <= 0;
  *o = (unsigned long long)((KDUMPFILE_VERSION) | 0);  /* check that KDUMPFILE_VERSION is an integer */
  return n;
}

static int _cffi_const_KDUMPFILE_VER_MAJOR(unsigned long long *o)
{
  int n = (KDUMPFILE_VER_MAJOR) <= 0;
  *o = (unsigned long long)((KDUMPFILE_VER_MAJOR) | 0);  /* check that KDUMPFILE_VER_MAJOR is an integer */
  return n;
}

static int _cffi_const_KDUMPFILE_VER_MICRO(unsigned long long *o)
{
  int n = (KDUMPFILE_VER_MICRO) <= 0;
  *o = (unsigned long long)((KDUMPFILE_VER_MICRO) | 0);  /* check that KDUMPFILE_VER_MICRO is an integer */
  return n;
}

static int _cffi_const_KDUMPFILE_VER_MINOR(unsigned long long *o)
{
  int n = (KDUMPFILE_VER_MINOR) <= 0;
  *o = (unsigned long long)((KDUMPFILE_VER_MINOR) | 0);  /* check that KDUMPFILE_VER_MINOR is an integer */
  return n;
}

static int _cffi_const_KDUMP_ADDR_MAX(unsigned long long *o)
{
  int n = (KDUMP_ADDR_MAX) <= 0;
  *o = (unsigned long long)((KDUMP_ADDR_MAX) | 0);  /* check that KDUMP_ADDR_MAX is an integer */
  return n;
}

static int _cffi_const_KDUMP_CLONE_XLAT(unsigned long long *o)
{
  int n = (KDUMP_CLONE_XLAT) <= 0;
  *o = (unsigned long long)((KDUMP_CLONE_XLAT) | 0);  /* check that KDUMP_CLONE_XLAT is an integer */
  return n;
}

_CFFI_UNUSED_FN
static void _cffi_checkfld__addrxlat_buffer_t(addrxlat_buffer_t *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { addrxlat_fulladdr_t *tmp = &p->addr; (void)tmp; }
  { void const * *tmp = &p->ptr; (void)tmp; }
  (void)((p->size) | 0);  /* check that 'addrxlat_buffer_t.size' is an integer */
  { addrxlat_byte_order_t *tmp = &p->byte_order; (void)tmp; }
  { void(* *tmp)(addrxlat_buffer_t const *) = &p->put_page; (void)tmp; }
  { void * *tmp = &p->priv; (void)tmp; }
}
struct _cffi_align__addrxlat_buffer_t { char x; addrxlat_buffer_t y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__addrxlat_cb_t(addrxlat_cb_t *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { addrxlat_cb_t const * *tmp = &p->next; (void)tmp; }
  { void * *tmp = &p->priv; (void)tmp; }
  { addrxlat_status(* *tmp)(addrxlat_cb_t const *, addrxlat_buffer_t *) = &p->get_page; (void)tmp; }
  { unsigned long(* *tmp)(addrxlat_cb_t const *) = &p->read_caps; (void)tmp; }
  { addrxlat_status(* *tmp)(addrxlat_cb_t const *, char const *, uint_fast64_t *) = &p->reg_value; (void)tmp; }
  { addrxlat_status(* *tmp)(addrxlat_cb_t const *, char const *, uint_fast64_t *) = &p->sym_value; (void)tmp; }
  { addrxlat_status(* *tmp)(addrxlat_cb_t const *, char const *, uint_fast64_t *) = &p->sym_sizeof; (void)tmp; }
  { addrxlat_status(* *tmp)(addrxlat_cb_t const *, char const *, char const *, uint_fast64_t *) = &p->sym_offsetof; (void)tmp; }
  { addrxlat_status(* *tmp)(addrxlat_cb_t const *, char const *, uint_fast64_t *) = &p->num_value; (void)tmp; }
}
struct _cffi_align__addrxlat_cb_t { char x; addrxlat_cb_t y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__addrxlat_fulladdr_t(addrxlat_fulladdr_t *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->addr) | 0);  /* check that 'addrxlat_fulladdr_t.addr' is an integer */
  { addrxlat_addrspace_t *tmp = &p->as; (void)tmp; }
}
struct _cffi_align__addrxlat_fulladdr_t { char x; addrxlat_fulladdr_t y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__addrxlat_lookup_elem_t(addrxlat_lookup_elem_t *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->orig) | 0);  /* check that 'addrxlat_lookup_elem_t.orig' is an integer */
  (void)((p->dest) | 0);  /* check that 'addrxlat_lookup_elem_t.dest' is an integer */
}
struct _cffi_align__addrxlat_lookup_elem_t { char x; addrxlat_lookup_elem_t y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__addrxlat_meth_t(addrxlat_meth_t *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { addrxlat_kind_t *tmp = &p->kind; (void)tmp; }
  { addrxlat_addrspace_t *tmp = &p->target_as; (void)tmp; }
  { addrxlat_param_t *tmp = &p->param; (void)tmp; }
}
struct _cffi_align__addrxlat_meth_t { char x; addrxlat_meth_t y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__addrxlat_op_ctl_t(addrxlat_op_ctl_t *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { addrxlat_ctx_t * *tmp = &p->ctx; (void)tmp; }
  { addrxlat_sys_t * *tmp = &p->sys; (void)tmp; }
  { addrxlat_status(* *tmp)(void *, addrxlat_fulladdr_t const *) = &p->op; (void)tmp; }
  { void * *tmp = &p->data; (void)tmp; }
  (void)((p->caps) | 0);  /* check that 'addrxlat_op_ctl_t.caps' is an integer */
}
struct _cffi_align__addrxlat_op_ctl_t { char x; addrxlat_op_ctl_t y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__addrxlat_opt_t(addrxlat_opt_t *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { addrxlat_optidx_t *tmp = &p->idx; (void)tmp; }
  { addrxlat_optval_t *tmp = &p->val; (void)tmp; }
}
struct _cffi_align__addrxlat_opt_t { char x; addrxlat_opt_t y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__addrxlat_paging_form_t(addrxlat_paging_form_t *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { addrxlat_pte_format_t *tmp = &p->pte_format; (void)tmp; }
  (void)((p->nfields) | 0);  /* check that 'addrxlat_paging_form_t.nfields' is an integer */
  { unsigned short(*tmp)[8] = &p->fieldsz; (void)tmp; }
}
struct _cffi_align__addrxlat_paging_form_t { char x; addrxlat_paging_form_t y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__addrxlat_param_custom_t(addrxlat_param_custom_t *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { addrxlat_status(* *tmp)(addrxlat_step_t *, uint_fast64_t) = &p->first_step; (void)tmp; }
  { addrxlat_status(* *tmp)(addrxlat_step_t *) = &p->next_step; (void)tmp; }
  { void * *tmp = &p->data; (void)tmp; }
}
struct _cffi_align__addrxlat_param_custom_t { char x; addrxlat_param_custom_t y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__addrxlat_param_linear_t(addrxlat_param_linear_t *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->off) | 0);  /* check that 'addrxlat_param_linear_t.off' is an integer */
}
struct _cffi_align__addrxlat_param_linear_t { char x; addrxlat_param_linear_t y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__addrxlat_param_lookup_t(addrxlat_param_lookup_t *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->endoff) | 0);  /* check that 'addrxlat_param_lookup_t.endoff' is an integer */
  (void)((p->nelem) | 0);  /* check that 'addrxlat_param_lookup_t.nelem' is an integer */
  { addrxlat_lookup_elem_t * *tmp = &p->tbl; (void)tmp; }
}
struct _cffi_align__addrxlat_param_lookup_t { char x; addrxlat_param_lookup_t y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__addrxlat_param_memarr_t(addrxlat_param_memarr_t *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { addrxlat_fulladdr_t *tmp = &p->base; (void)tmp; }
  (void)((p->shift) | 0);  /* check that 'addrxlat_param_memarr_t.shift' is an integer */
  (void)((p->elemsz) | 0);  /* check that 'addrxlat_param_memarr_t.elemsz' is an integer */
  (void)((p->valsz) | 0);  /* check that 'addrxlat_param_memarr_t.valsz' is an integer */
}
struct _cffi_align__addrxlat_param_memarr_t { char x; addrxlat_param_memarr_t y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__addrxlat_param_pgt_t(addrxlat_param_pgt_t *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { addrxlat_fulladdr_t *tmp = &p->root; (void)tmp; }
  (void)((p->pte_mask) | 0);  /* check that 'addrxlat_param_pgt_t.pte_mask' is an integer */
  { addrxlat_paging_form_t *tmp = &p->pf; (void)tmp; }
}
struct _cffi_align__addrxlat_param_pgt_t { char x; addrxlat_param_pgt_t y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__addrxlat_range_t(addrxlat_range_t *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->endoff) | 0);  /* check that 'addrxlat_range_t.endoff' is an integer */
  { addrxlat_sys_meth_t *tmp = &p->meth; (void)tmp; }
}
struct _cffi_align__addrxlat_range_t { char x; addrxlat_range_t y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__addrxlat_step_t(addrxlat_step_t *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { addrxlat_ctx_t * *tmp = &p->ctx; (void)tmp; }
  { addrxlat_sys_t * *tmp = &p->sys; (void)tmp; }
  { addrxlat_meth_t const * *tmp = &p->meth; (void)tmp; }
  (void)((p->remain) | 0);  /* check that 'addrxlat_step_t.remain' is an integer */
  (void)((p->elemsz) | 0);  /* check that 'addrxlat_step_t.elemsz' is an integer */
  { addrxlat_fulladdr_t *tmp = &p->base; (void)tmp; }
  /* cannot generate 'union $1' in field 'raw': unknown type name */
  { uint_fast64_t(*tmp)[9] = &p->idx; (void)tmp; }
}
struct _cffi_align__addrxlat_step_t { char x; addrxlat_step_t y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__kdump_attr_t(kdump_attr_t *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { kdump_attr_type_t *tmp = &p->type; (void)tmp; }
  { kdump_attr_value_t *tmp = &p->val; (void)tmp; }
}
struct _cffi_align__kdump_attr_t { char x; kdump_attr_t y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__kdump_attr_iter_t(kdump_attr_iter_t *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { char const * *tmp = &p->key; (void)tmp; }
  { kdump_attr_ref_t *tmp = &p->pos; (void)tmp; }
}
struct _cffi_align__kdump_attr_iter_t { char x; kdump_attr_iter_t y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__kdump_attr_ref_t(kdump_attr_ref_t *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { void * *tmp = &p->_ptr; (void)tmp; }
}
struct _cffi_align__kdump_attr_ref_t { char x; kdump_attr_ref_t y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__addrxlat_optval_t(addrxlat_optval_t *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { char const * *tmp = &p->str; (void)tmp; }
  (void)((p->num) | 0);  /* check that 'addrxlat_optval_t.num' is an integer */
  (void)((p->addr) | 0);  /* check that 'addrxlat_optval_t.addr' is an integer */
  { addrxlat_fulladdr_t *tmp = &p->fulladdr; (void)tmp; }
}
struct _cffi_align__addrxlat_optval_t { char x; addrxlat_optval_t y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__addrxlat_param_t(addrxlat_param_t *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { addrxlat_param_custom_t *tmp = &p->custom; (void)tmp; }
  { addrxlat_param_linear_t *tmp = &p->linear; (void)tmp; }
  { addrxlat_param_pgt_t *tmp = &p->pgt; (void)tmp; }
  { addrxlat_param_lookup_t *tmp = &p->lookup; (void)tmp; }
  { addrxlat_param_memarr_t *tmp = &p->memarr; (void)tmp; }
}
struct _cffi_align__addrxlat_param_t { char x; addrxlat_param_t y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__kdump_attr_value_t(kdump_attr_value_t *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->number) | 0);  /* check that 'kdump_attr_value_t.number' is an integer */
  (void)((p->address) | 0);  /* check that 'kdump_attr_value_t.address' is an integer */
  { char const * *tmp = &p->string; (void)tmp; }
  { kdump_bmp_t * *tmp = &p->bitmap; (void)tmp; }
  { kdump_blob_t * *tmp = &p->blob; (void)tmp; }
}
struct _cffi_align__kdump_attr_value_t { char x; kdump_attr_value_t y; };

static const struct _cffi_global_s _cffi_globals[] = {
  { "ADDRXLAT_ADDR_MAX", (void *)_cffi_const_ADDRXLAT_ADDR_MAX, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "ADDRXLAT_BIG_ENDIAN", (void *)_cffi_const_ADDRXLAT_BIG_ENDIAN, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_CAPS", (void *)_cffi_f_ADDRXLAT_CAPS, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 307), (void *)_cffi_d_ADDRXLAT_CAPS },
  { "ADDRXLAT_CUSTOM", (void *)_cffi_const_ADDRXLAT_CUSTOM, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_ERR_CUSTOM_BASE", (void *)_cffi_const_ADDRXLAT_ERR_CUSTOM_BASE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_ERR_INVALID", (void *)_cffi_const_ADDRXLAT_ERR_INVALID, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_ERR_NODATA", (void *)_cffi_const_ADDRXLAT_ERR_NODATA, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_ERR_NOMEM", (void *)_cffi_const_ADDRXLAT_ERR_NOMEM, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_ERR_NOMETH", (void *)_cffi_const_ADDRXLAT_ERR_NOMETH, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_ERR_NOTIMPL", (void *)_cffi_const_ADDRXLAT_ERR_NOTIMPL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_ERR_NOTPRESENT", (void *)_cffi_const_ADDRXLAT_ERR_NOTPRESENT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_FIELDS_MAX", (void *)_cffi_const_ADDRXLAT_FIELDS_MAX, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "ADDRXLAT_HOST_ENDIAN", (void *)_cffi_const_ADDRXLAT_HOST_ENDIAN, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_KPHYSADDR", (void *)_cffi_const_ADDRXLAT_KPHYSADDR, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_KVADDR", (void *)_cffi_const_ADDRXLAT_KVADDR, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_LINEAR", (void *)_cffi_const_ADDRXLAT_LINEAR, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_LITTLE_ENDIAN", (void *)_cffi_const_ADDRXLAT_LITTLE_ENDIAN, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_LOOKUP", (void *)_cffi_const_ADDRXLAT_LOOKUP, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_MACHPHYSADDR", (void *)_cffi_const_ADDRXLAT_MACHPHYSADDR, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_MEMARR", (void *)_cffi_const_ADDRXLAT_MEMARR, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_NOADDR", (void *)_cffi_const_ADDRXLAT_NOADDR, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_NOMETH", (void *)_cffi_const_ADDRXLAT_NOMETH, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_OK", (void *)_cffi_const_ADDRXLAT_OK, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_OPT_NULL", (void *)_cffi_const_ADDRXLAT_OPT_NULL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_OPT_NUM", (void *)_cffi_const_ADDRXLAT_OPT_NUM, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_OPT_arch", (void *)_cffi_const_ADDRXLAT_OPT_arch, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_OPT_os_type", (void *)_cffi_const_ADDRXLAT_OPT_os_type, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_OPT_page_shift", (void *)_cffi_const_ADDRXLAT_OPT_page_shift, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_OPT_phys_base", (void *)_cffi_const_ADDRXLAT_OPT_phys_base, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_OPT_phys_bits", (void *)_cffi_const_ADDRXLAT_OPT_phys_bits, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_OPT_rootpgt", (void *)_cffi_const_ADDRXLAT_OPT_rootpgt, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_OPT_version_code", (void *)_cffi_const_ADDRXLAT_OPT_version_code, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_OPT_virt_bits", (void *)_cffi_const_ADDRXLAT_OPT_virt_bits, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_OPT_xen_p2m_mfn", (void *)_cffi_const_ADDRXLAT_OPT_xen_p2m_mfn, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_OPT_xen_xlat", (void *)_cffi_const_ADDRXLAT_OPT_xen_xlat, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_PGT", (void *)_cffi_const_ADDRXLAT_PGT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_PTE_AARCH64", (void *)_cffi_const_ADDRXLAT_PTE_AARCH64, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_PTE_AARCH64_LPA", (void *)_cffi_const_ADDRXLAT_PTE_AARCH64_LPA, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_PTE_AARCH64_LPA2", (void *)_cffi_const_ADDRXLAT_PTE_AARCH64_LPA2, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_PTE_ARM", (void *)_cffi_const_ADDRXLAT_PTE_ARM, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_PTE_IA32", (void *)_cffi_const_ADDRXLAT_PTE_IA32, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_PTE_IA32_PAE", (void *)_cffi_const_ADDRXLAT_PTE_IA32_PAE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_PTE_INVALID", (void *)_cffi_const_ADDRXLAT_PTE_INVALID, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_PTE_NONE", (void *)_cffi_const_ADDRXLAT_PTE_NONE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_PTE_PFN32", (void *)_cffi_const_ADDRXLAT_PTE_PFN32, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_PTE_PFN64", (void *)_cffi_const_ADDRXLAT_PTE_PFN64, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_PTE_PPC64_LINUX_RPN30", (void *)_cffi_const_ADDRXLAT_PTE_PPC64_LINUX_RPN30, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_PTE_RISCV32", (void *)_cffi_const_ADDRXLAT_PTE_RISCV32, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_PTE_RISCV64", (void *)_cffi_const_ADDRXLAT_PTE_RISCV64, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_PTE_S390X", (void *)_cffi_const_ADDRXLAT_PTE_S390X, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_PTE_X86_64", (void *)_cffi_const_ADDRXLAT_PTE_X86_64, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_SYS_MAP_HW", (void *)_cffi_const_ADDRXLAT_SYS_MAP_HW, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_SYS_MAP_KPHYS_DIRECT", (void *)_cffi_const_ADDRXLAT_SYS_MAP_KPHYS_DIRECT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_SYS_MAP_KPHYS_MACHPHYS", (void *)_cffi_const_ADDRXLAT_SYS_MAP_KPHYS_MACHPHYS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_SYS_MAP_KV_PHYS", (void *)_cffi_const_ADDRXLAT_SYS_MAP_KV_PHYS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_SYS_MAP_MACHPHYS_KPHYS", (void *)_cffi_const_ADDRXLAT_SYS_MAP_MACHPHYS_KPHYS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_SYS_MAP_NUM", (void *)_cffi_const_ADDRXLAT_SYS_MAP_NUM, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_SYS_METH_CUSTOM", (void *)_cffi_const_ADDRXLAT_SYS_METH_CUSTOM, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_SYS_METH_CUSTOM_NUM", (void *)_cffi_const_ADDRXLAT_SYS_METH_CUSTOM_NUM, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "ADDRXLAT_SYS_METH_DIRECT", (void *)_cffi_const_ADDRXLAT_SYS_METH_DIRECT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_SYS_METH_KPHYS_MACHPHYS", (void *)_cffi_const_ADDRXLAT_SYS_METH_KPHYS_MACHPHYS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_SYS_METH_KTEXT", (void *)_cffi_const_ADDRXLAT_SYS_METH_KTEXT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_SYS_METH_MACHPHYS_KPHYS", (void *)_cffi_const_ADDRXLAT_SYS_METH_MACHPHYS_KPHYS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_SYS_METH_NONE", (void *)_cffi_const_ADDRXLAT_SYS_METH_NONE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_SYS_METH_NUM", (void *)_cffi_const_ADDRXLAT_SYS_METH_NUM, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "ADDRXLAT_SYS_METH_PGT", (void *)_cffi_const_ADDRXLAT_SYS_METH_PGT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_SYS_METH_RDIRECT", (void *)_cffi_const_ADDRXLAT_SYS_METH_RDIRECT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_SYS_METH_UPGT", (void *)_cffi_const_ADDRXLAT_SYS_METH_UPGT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_SYS_METH_VMEMMAP", (void *)_cffi_const_ADDRXLAT_SYS_METH_VMEMMAP, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ADDRXLAT_VERSION", (void *)_cffi_const_ADDRXLAT_VERSION, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "ADDRXLAT_VER_LINUX", (void *)_cffi_f_ADDRXLAT_VER_LINUX, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 314), (void *)_cffi_d_ADDRXLAT_VER_LINUX },
  { "ADDRXLAT_VER_MAJOR", (void *)_cffi_const_ADDRXLAT_VER_MAJOR, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "ADDRXLAT_VER_MICRO", (void *)_cffi_const_ADDRXLAT_VER_MICRO, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "ADDRXLAT_VER_MINOR", (void *)_cffi_const_ADDRXLAT_VER_MINOR, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "ADDRXLAT_VER_XEN", (void *)_cffi_f_ADDRXLAT_VER_XEN, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 310), (void *)_cffi_d_ADDRXLAT_VER_XEN },
  { "KDUMPFILE_VERSION", (void *)_cffi_const_KDUMPFILE_VERSION, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "KDUMPFILE_VER_MAJOR", (void *)_cffi_const_KDUMPFILE_VER_MAJOR, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "KDUMPFILE_VER_MICRO", (void *)_cffi_const_KDUMPFILE_VER_MICRO, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "KDUMPFILE_VER_MINOR", (void *)_cffi_const_KDUMPFILE_VER_MINOR, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "KDUMP_ADDRESS", (void *)_cffi_const_KDUMP_ADDRESS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "KDUMP_ADDR_MAX", (void *)_cffi_const_KDUMP_ADDR_MAX, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "KDUMP_BIG_ENDIAN", (void *)_cffi_const_KDUMP_BIG_ENDIAN, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "KDUMP_BITMAP", (void *)_cffi_const_KDUMP_BITMAP, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "KDUMP_BLOB", (void *)_cffi_const_KDUMP_BLOB, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "KDUMP_CLONE_BIT_XLAT", (void *)_cffi_const_KDUMP_CLONE_BIT_XLAT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "KDUMP_CLONE_XLAT", (void *)_cffi_const_KDUMP_CLONE_XLAT, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "KDUMP_DIRECTORY", (void *)_cffi_const_KDUMP_DIRECTORY, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "KDUMP_ERR_ADDRXLAT", (void *)_cffi_const_KDUMP_ERR_ADDRXLAT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "KDUMP_ERR_BUSY", (void *)_cffi_const_KDUMP_ERR_BUSY, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "KDUMP_ERR_CORRUPT", (void *)_cffi_const_KDUMP_ERR_CORRUPT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "KDUMP_ERR_EOF", (void *)_cffi_const_KDUMP_ERR_EOF, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "KDUMP_ERR_INVALID", (void *)_cffi_const_KDUMP_ERR_INVALID, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "KDUMP_ERR_NODATA", (void *)_cffi_const_KDUMP_ERR_NODATA, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "KDUMP_ERR_NOKEY", (void *)_cffi_const_KDUMP_ERR_NOKEY, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "KDUMP_ERR_NOTIMPL", (void *)_cffi_const_KDUMP_ERR_NOTIMPL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "KDUMP_ERR_SYSTEM", (void *)_cffi_const_KDUMP_ERR_SYSTEM, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "KDUMP_KPHYSADDR", (void *)_cffi_const_KDUMP_KPHYSADDR, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "KDUMP_KVADDR", (void *)_cffi_const_KDUMP_KVADDR, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "KDUMP_LITTLE_ENDIAN", (void *)_cffi_const_KDUMP_LITTLE_ENDIAN, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "KDUMP_MACHPHYSADDR", (void *)_cffi_const_KDUMP_MACHPHYSADDR, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "KDUMP_MMAP_ALWAYS", (void *)_cffi_const_KDUMP_MMAP_ALWAYS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "KDUMP_MMAP_NEVER", (void *)_cffi_const_KDUMP_MMAP_NEVER, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "KDUMP_MMAP_TRY", (void *)_cffi_const_KDUMP_MMAP_TRY, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "KDUMP_MMAP_TRY_ONCE", (void *)_cffi_const_KDUMP_MMAP_TRY_ONCE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "KDUMP_NIL", (void *)_cffi_const_KDUMP_NIL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "KDUMP_NOADDR", (void *)_cffi_const_KDUMP_NOADDR, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "KDUMP_NUMBER", (void *)_cffi_const_KDUMP_NUMBER, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "KDUMP_OK", (void *)_cffi_const_KDUMP_OK, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "KDUMP_STRING", (void *)_cffi_const_KDUMP_STRING, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "KDUMP_XEN_AUTO", (void *)_cffi_const_KDUMP_XEN_AUTO, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "KDUMP_XEN_DOMAIN", (void *)_cffi_const_KDUMP_XEN_DOMAIN, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "KDUMP_XEN_NONAUTO", (void *)_cffi_const_KDUMP_XEN_NONAUTO, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "KDUMP_XEN_NONE", (void *)_cffi_const_KDUMP_XEN_NONE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "KDUMP_XEN_SYSTEM", (void *)_cffi_const_KDUMP_XEN_SYSTEM, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "addrxlat_addrspace_name", (void *)_cffi_f_addrxlat_addrspace_name, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 85), (void *)_cffi_d_addrxlat_addrspace_name },
  { "addrxlat_ctx_add_cb", (void *)_cffi_f_addrxlat_ctx_add_cb, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 0), (void *)_cffi_d_addrxlat_ctx_add_cb },
  { "addrxlat_ctx_clear_err", (void *)_cffi_f_addrxlat_ctx_clear_err, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 328), (void *)_cffi_d_addrxlat_ctx_clear_err },
  { "addrxlat_ctx_decref", (void *)_cffi_f_addrxlat_ctx_decref, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 292), (void *)_cffi_d_addrxlat_ctx_decref },
  { "addrxlat_ctx_del_cb", (void *)_cffi_f_addrxlat_ctx_del_cb, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 331), (void *)_cffi_d_addrxlat_ctx_del_cb },
  { "addrxlat_ctx_err", (void *)_cffi_const_addrxlat_ctx_err, _CFFI_OP(_CFFI_OP_CONSTANT, 405), (void *)0 },
  { "addrxlat_ctx_get_cb", (void *)_cffi_f_addrxlat_ctx_get_cb, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 3), (void *)_cffi_d_addrxlat_ctx_get_cb },
  { "addrxlat_ctx_get_err", (void *)_cffi_f_addrxlat_ctx_get_err, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 88), (void *)_cffi_d_addrxlat_ctx_get_err },
  { "addrxlat_ctx_incref", (void *)_cffi_f_addrxlat_ctx_incref, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 292), (void *)_cffi_d_addrxlat_ctx_incref },
  { "addrxlat_ctx_new", (void *)_cffi_f_addrxlat_ctx_new, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_N, 6), (void *)_cffi_d_addrxlat_ctx_new },
  { "addrxlat_fulladdr_conv", (void *)_cffi_f_addrxlat_fulladdr_conv, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 47), (void *)_cffi_d_addrxlat_fulladdr_conv },
  { "addrxlat_launch", (void *)_cffi_f_addrxlat_launch, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 65), (void *)_cffi_d_addrxlat_launch },
  { "addrxlat_map_copy", (void *)_cffi_f_addrxlat_map_copy, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 8), (void *)_cffi_d_addrxlat_map_copy },
  { "addrxlat_map_decref", (void *)_cffi_f_addrxlat_map_decref, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 295), (void *)_cffi_d_addrxlat_map_decref },
  { "addrxlat_map_incref", (void *)_cffi_f_addrxlat_map_incref, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 295), (void *)_cffi_d_addrxlat_map_incref },
  { "addrxlat_map_len", (void *)_cffi_f_addrxlat_map_len, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 271), (void *)_cffi_d_addrxlat_map_len },
  { "addrxlat_map_new", (void *)_cffi_f_addrxlat_map_new, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_N, 15), (void *)_cffi_d_addrxlat_map_new },
  { "addrxlat_map_ranges", (void *)_cffi_f_addrxlat_map_ranges, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 24), (void *)_cffi_d_addrxlat_map_ranges },
  { "addrxlat_map_search", (void *)_cffi_f_addrxlat_map_search, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 79), (void *)_cffi_d_addrxlat_map_search },
  { "addrxlat_map_set", (void *)_cffi_f_addrxlat_map_set, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 53), (void *)_cffi_d_addrxlat_map_set },
  { "addrxlat_op", (void *)_cffi_f_addrxlat_op, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 58), (void *)_cffi_d_addrxlat_op },
  { "addrxlat_opt_arch", (void *)_cffi_f_addrxlat_opt_arch, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 339), (void *)_cffi_d_addrxlat_opt_arch },
  { "addrxlat_opt_os_type", (void *)_cffi_f_addrxlat_opt_os_type, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 339), (void *)_cffi_d_addrxlat_opt_os_type },
  { "addrxlat_opt_page_shift", (void *)_cffi_f_addrxlat_opt_page_shift, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 347), (void *)_cffi_d_addrxlat_opt_page_shift },
  { "addrxlat_opt_phys_base", (void *)_cffi_f_addrxlat_opt_phys_base, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 343), (void *)_cffi_d_addrxlat_opt_phys_base },
  { "addrxlat_opt_phys_bits", (void *)_cffi_f_addrxlat_opt_phys_bits, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 347), (void *)_cffi_d_addrxlat_opt_phys_bits },
  { "addrxlat_opt_rootpgt", (void *)_cffi_f_addrxlat_opt_rootpgt, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 335), (void *)_cffi_d_addrxlat_opt_rootpgt },
  { "addrxlat_opt_version_code", (void *)_cffi_f_addrxlat_opt_version_code, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 347), (void *)_cffi_d_addrxlat_opt_version_code },
  { "addrxlat_opt_virt_bits", (void *)_cffi_f_addrxlat_opt_virt_bits, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 347), (void *)_cffi_d_addrxlat_opt_virt_bits },
  { "addrxlat_opt_xen_p2m_mfn", (void *)_cffi_f_addrxlat_opt_xen_p2m_mfn, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 347), (void *)_cffi_d_addrxlat_opt_xen_p2m_mfn },
  { "addrxlat_opt_xen_xlat", (void *)_cffi_f_addrxlat_opt_xen_xlat, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 347), (void *)_cffi_d_addrxlat_opt_xen_xlat },
  { "addrxlat_pte_format", (void *)_cffi_f_addrxlat_pte_format, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 21), (void *)_cffi_d_addrxlat_pte_format },
  { "addrxlat_pte_format_name", (void *)_cffi_f_addrxlat_pte_format_name, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 91), (void *)_cffi_d_addrxlat_pte_format_name },
  { "addrxlat_pteval_shift", (void *)_cffi_f_addrxlat_pteval_shift, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 106), (void *)_cffi_d_addrxlat_pteval_shift },
  { "addrxlat_step", (void *)_cffi_f_addrxlat_step, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 62), (void *)_cffi_d_addrxlat_step },
  { "addrxlat_strerror", (void *)_cffi_f_addrxlat_strerror, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 94), (void *)_cffi_d_addrxlat_strerror },
  { "addrxlat_sys_decref", (void *)_cffi_f_addrxlat_sys_decref, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 298), (void *)_cffi_d_addrxlat_sys_decref },
  { "addrxlat_sys_get_map", (void *)_cffi_f_addrxlat_sys_get_map, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 11), (void *)_cffi_d_addrxlat_sys_get_map },
  { "addrxlat_sys_get_meth", (void *)_cffi_f_addrxlat_sys_get_meth, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 17), (void *)_cffi_d_addrxlat_sys_get_meth },
  { "addrxlat_sys_incref", (void *)_cffi_f_addrxlat_sys_incref, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 298), (void *)_cffi_d_addrxlat_sys_incref },
  { "addrxlat_sys_new", (void *)_cffi_f_addrxlat_sys_new, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_N, 83), (void *)_cffi_d_addrxlat_sys_new },
  { "addrxlat_sys_os_init", (void *)_cffi_f_addrxlat_sys_os_init, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 69), (void *)_cffi_d_addrxlat_sys_os_init },
  { "addrxlat_sys_set_map", (void *)_cffi_f_addrxlat_sys_set_map, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 351), (void *)_cffi_d_addrxlat_sys_set_map },
  { "addrxlat_sys_set_meth", (void *)_cffi_f_addrxlat_sys_set_meth, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 356), (void *)_cffi_d_addrxlat_sys_set_meth },
  { "addrxlat_walk", (void *)_cffi_f_addrxlat_walk, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 62), (void *)_cffi_d_addrxlat_walk },
  { "free", (void *)_cffi_f_free, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 376), (void *)_cffi_d_free },
  { "kdump_attr_discard", (void *)_cffi_f_kdump_attr_discard, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 372), (void *)_cffi_d_kdump_attr_discard },
  { "kdump_attr_iter_end", (void *)_cffi_f_kdump_attr_iter_end, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 364), (void *)_cffi_d_kdump_attr_iter_end },
  { "kdump_attr_iter_next", (void *)_cffi_f_kdump_attr_iter_next, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 225), (void *)_cffi_d_kdump_attr_iter_next },
  { "kdump_attr_iter_start", (void *)_cffi_f_kdump_attr_iter_start, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 172), (void *)_cffi_d_kdump_attr_iter_start },
  { "kdump_attr_ref", (void *)_cffi_f_kdump_attr_ref, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 177), (void *)_cffi_d_kdump_attr_ref },
  { "kdump_attr_ref_get", (void *)_cffi_f_kdump_attr_ref_get, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 251), (void *)_cffi_d_kdump_attr_ref_get },
  { "kdump_attr_ref_isset", (void *)_cffi_f_kdump_attr_ref_isset, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 109), (void *)_cffi_d_kdump_attr_ref_isset },
  { "kdump_attr_ref_iter_start", (void *)_cffi_f_kdump_attr_ref_iter_start, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 246), (void *)_cffi_d_kdump_attr_ref_iter_start },
  { "kdump_attr_ref_set", (void *)_cffi_f_kdump_attr_ref_set, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 229), (void *)_cffi_d_kdump_attr_ref_set },
  { "kdump_attr_ref_type", (void *)_cffi_f_kdump_attr_ref_type, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 112), (void *)_cffi_d_kdump_attr_ref_type },
  { "kdump_attr_unref", (void *)_cffi_f_kdump_attr_unref, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 368), (void *)_cffi_d_kdump_attr_unref },
  { "kdump_blob_decref", (void *)_cffi_f_kdump_blob_decref, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 301), (void *)_cffi_d_kdump_blob_decref },
  { "kdump_blob_incref", (void *)_cffi_f_kdump_blob_incref, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 301), (void *)_cffi_d_kdump_blob_incref },
  { "kdump_blob_new", (void *)_cffi_f_kdump_blob_new, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 115), (void *)_cffi_d_kdump_blob_new },
  { "kdump_blob_new_dup", (void *)_cffi_f_kdump_blob_new_dup, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 119), (void *)_cffi_d_kdump_blob_new_dup },
  { "kdump_blob_pin", (void *)_cffi_f_kdump_blob_pin, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 319), (void *)_cffi_d_kdump_blob_pin },
  { "kdump_blob_set", (void *)_cffi_f_kdump_blob_set, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 129), (void *)_cffi_d_kdump_blob_set },
  { "kdump_blob_size", (void *)_cffi_f_kdump_blob_size, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 274), (void *)_cffi_d_kdump_blob_size },
  { "kdump_blob_unpin", (void *)_cffi_f_kdump_blob_unpin, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 301), (void *)_cffi_d_kdump_blob_unpin },
  { "kdump_bmp_decref", (void *)_cffi_f_kdump_bmp_decref, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 304), (void *)_cffi_d_kdump_bmp_decref },
  { "kdump_bmp_find_clear", (void *)_cffi_f_kdump_bmp_find_clear, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 134), (void *)_cffi_d_kdump_bmp_find_clear },
  { "kdump_bmp_find_set", (void *)_cffi_f_kdump_bmp_find_set, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 134), (void *)_cffi_d_kdump_bmp_find_set },
  { "kdump_bmp_get_bits", (void *)_cffi_f_kdump_bmp_get_bits, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 138), (void *)_cffi_d_kdump_bmp_get_bits },
  { "kdump_bmp_get_err", (void *)_cffi_f_kdump_bmp_get_err, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 97), (void *)_cffi_d_kdump_bmp_get_err },
  { "kdump_bmp_incref", (void *)_cffi_f_kdump_bmp_incref, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 304), (void *)_cffi_d_kdump_bmp_incref },
  { "kdump_clear_attr", (void *)_cffi_f_kdump_clear_attr, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 153), (void *)_cffi_d_kdump_clear_attr },
  { "kdump_clear_err", (void *)_cffi_f_kdump_clear_err, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 361), (void *)_cffi_d_kdump_clear_err },
  { "kdump_clone", (void *)_cffi_f_kdump_clone, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 123), (void *)_cffi_d_kdump_clone },
  { "kdump_d16toh", (void *)_cffi_f_kdump_d16toh, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 277), (void *)_cffi_d_kdump_d16toh },
  { "kdump_d32toh", (void *)_cffi_f_kdump_d32toh, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 281), (void *)_cffi_d_kdump_d32toh },
  { "kdump_d64toh", (void *)_cffi_f_kdump_d64toh, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 285), (void *)_cffi_d_kdump_d64toh },
  { "kdump_err", (void *)_cffi_const_kdump_err, _CFFI_OP(_CFFI_OP_CONSTANT, 424), (void *)0 },
  { "kdump_free", (void *)_cffi_f_kdump_free, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 361), (void *)_cffi_d_kdump_free },
  { "kdump_get_address_attr", (void *)_cffi_f_kdump_get_address_attr, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 198), (void *)_cffi_d_kdump_get_address_attr },
  { "kdump_get_addrxlat", (void *)_cffi_f_kdump_get_addrxlat, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 144), (void *)_cffi_d_kdump_get_addrxlat },
  { "kdump_get_attr", (void *)_cffi_f_kdump_get_attr, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 182), (void *)_cffi_d_kdump_get_attr },
  { "kdump_get_err", (void *)_cffi_f_kdump_get_err, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 100), (void *)_cffi_d_kdump_get_err },
  { "kdump_get_number_attr", (void *)_cffi_f_kdump_get_number_attr, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 198), (void *)_cffi_d_kdump_get_number_attr },
  { "kdump_get_string_attr", (void *)_cffi_f_kdump_get_string_attr, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 162), (void *)_cffi_d_kdump_get_string_attr },
  { "kdump_get_typed_attr", (void *)_cffi_f_kdump_get_typed_attr, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 192), (void *)_cffi_d_kdump_get_typed_attr },
  { "kdump_new", (void *)_cffi_f_kdump_new, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_N, 127), (void *)_cffi_d_kdump_new },
  { "kdump_open_fd", (void *)_cffi_f_kdump_open_fd, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 208), (void *)_cffi_d_kdump_open_fd },
  { "kdump_open_fdset", (void *)_cffi_f_kdump_open_fdset, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 266), (void *)_cffi_d_kdump_open_fdset },
  { "kdump_read", (void *)_cffi_f_kdump_read, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 218), (void *)_cffi_d_kdump_read },
  { "kdump_read_string", (void *)_cffi_f_kdump_read_string, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 212), (void *)_cffi_d_kdump_read_string },
  { "kdump_set_address_attr", (void *)_cffi_f_kdump_set_address_attr, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 203), (void *)_cffi_d_kdump_set_address_attr },
  { "kdump_set_attr", (void *)_cffi_f_kdump_set_attr, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 187), (void *)_cffi_d_kdump_set_attr },
  { "kdump_set_filename", (void *)_cffi_f_kdump_set_filename, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 153), (void *)_cffi_d_kdump_set_filename },
  { "kdump_set_filenames", (void *)_cffi_f_kdump_set_filenames, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 261), (void *)_cffi_d_kdump_set_filenames },
  { "kdump_set_number_attr", (void *)_cffi_f_kdump_set_number_attr, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 203), (void *)_cffi_d_kdump_set_number_attr },
  { "kdump_set_string_attr", (void *)_cffi_f_kdump_set_string_attr, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 167), (void *)_cffi_d_kdump_set_string_attr },
  { "kdump_set_sub_attr", (void *)_cffi_f_kdump_set_sub_attr, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 240), (void *)_cffi_d_kdump_set_sub_attr },
  { "kdump_strerror", (void *)_cffi_f_kdump_strerror, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 103), (void *)_cffi_d_kdump_strerror },
  { "kdump_sub_attr_ref", (void *)_cffi_f_kdump_sub_attr_ref, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 234), (void *)_cffi_d_kdump_sub_attr_ref },
  { "kdump_vmcoreinfo_line", (void *)_cffi_f_kdump_vmcoreinfo_line, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 157), (void *)_cffi_d_kdump_vmcoreinfo_line },
  { "kdump_vmcoreinfo_raw", (void *)_cffi_f_kdump_vmcoreinfo_raw, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 149), (void *)_cffi_d_kdump_vmcoreinfo_raw },
  { "kdump_vmcoreinfo_symbol", (void *)_cffi_f_kdump_vmcoreinfo_symbol, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 198), (void *)_cffi_d_kdump_vmcoreinfo_symbol },
  { "malloc", (void *)_cffi_f_malloc, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 322), (void *)_cffi_d_malloc },
};

static const struct _cffi_field_s _cffi_fields[] = {
  { "addr", offsetof(addrxlat_buffer_t, addr),
            sizeof(((addrxlat_buffer_t *)0)->addr),
            _CFFI_OP(_CFFI_OP_NOOP, 383) },
  { "ptr", offsetof(addrxlat_buffer_t, ptr),
           sizeof(((addrxlat_buffer_t *)0)->ptr),
           _CFFI_OP(_CFFI_OP_NOOP, 120) },
  { "size", offsetof(addrxlat_buffer_t, size),
            sizeof(((addrxlat_buffer_t *)0)->size),
            _CFFI_OP(_CFFI_OP_NOOP, 117) },
  { "byte_order", offsetof(addrxlat_buffer_t, byte_order),
                  sizeof(((addrxlat_buffer_t *)0)->byte_order),
                  _CFFI_OP(_CFFI_OP_NOOP, 380) },
  { "put_page", offsetof(addrxlat_buffer_t, put_page),
                sizeof(((addrxlat_buffer_t *)0)->put_page),
                _CFFI_OP(_CFFI_OP_NOOP, 435) },
  { "priv", offsetof(addrxlat_buffer_t, priv),
            sizeof(((addrxlat_buffer_t *)0)->priv),
            _CFFI_OP(_CFFI_OP_NOOP, 76) },
  { "next", offsetof(addrxlat_cb_t, next),
            sizeof(((addrxlat_cb_t *)0)->next),
            _CFFI_OP(_CFFI_OP_NOOP, 28) },
  { "priv", offsetof(addrxlat_cb_t, priv),
            sizeof(((addrxlat_cb_t *)0)->priv),
            _CFFI_OP(_CFFI_OP_NOOP, 76) },
  { "get_page", offsetof(addrxlat_cb_t, get_page),
                sizeof(((addrxlat_cb_t *)0)->get_page),
                _CFFI_OP(_CFFI_OP_NOOP, 402) },
  { "read_caps", offsetof(addrxlat_cb_t, read_caps),
                 sizeof(((addrxlat_cb_t *)0)->read_caps),
                 _CFFI_OP(_CFFI_OP_NOOP, 431) },
  { "reg_value", offsetof(addrxlat_cb_t, reg_value),
                 sizeof(((addrxlat_cb_t *)0)->reg_value),
                 _CFFI_OP(_CFFI_OP_NOOP, 404) },
  { "sym_value", offsetof(addrxlat_cb_t, sym_value),
                 sizeof(((addrxlat_cb_t *)0)->sym_value),
                 _CFFI_OP(_CFFI_OP_NOOP, 404) },
  { "sym_sizeof", offsetof(addrxlat_cb_t, sym_sizeof),
                  sizeof(((addrxlat_cb_t *)0)->sym_sizeof),
                  _CFFI_OP(_CFFI_OP_NOOP, 404) },
  { "sym_offsetof", offsetof(addrxlat_cb_t, sym_offsetof),
                    sizeof(((addrxlat_cb_t *)0)->sym_offsetof),
                    _CFFI_OP(_CFFI_OP_NOOP, 403) },
  { "num_value", offsetof(addrxlat_cb_t, num_value),
                 sizeof(((addrxlat_cb_t *)0)->num_value),
                 _CFFI_OP(_CFFI_OP_NOOP, 404) },
  { "addr", offsetof(addrxlat_fulladdr_t, addr),
            sizeof(((addrxlat_fulladdr_t *)0)->addr),
            _CFFI_OP(_CFFI_OP_NOOP, 55) },
  { "as", offsetof(addrxlat_fulladdr_t, as),
          sizeof(((addrxlat_fulladdr_t *)0)->as),
          _CFFI_OP(_CFFI_OP_NOOP, 49) },
  { "orig", offsetof(addrxlat_lookup_elem_t, orig),
            sizeof(((addrxlat_lookup_elem_t *)0)->orig),
            _CFFI_OP(_CFFI_OP_NOOP, 55) },
  { "dest", offsetof(addrxlat_lookup_elem_t, dest),
            sizeof(((addrxlat_lookup_elem_t *)0)->dest),
            _CFFI_OP(_CFFI_OP_NOOP, 55) },
  { "kind", offsetof(addrxlat_meth_t, kind),
            sizeof(((addrxlat_meth_t *)0)->kind),
            _CFFI_OP(_CFFI_OP_NOOP, 384) },
  { "target_as", offsetof(addrxlat_meth_t, target_as),
                 sizeof(((addrxlat_meth_t *)0)->target_as),
                 _CFFI_OP(_CFFI_OP_NOOP, 49) },
  { "param", offsetof(addrxlat_meth_t, param),
             sizeof(((addrxlat_meth_t *)0)->param),
             _CFFI_OP(_CFFI_OP_NOOP, 400) },
  { "ctx", offsetof(addrxlat_op_ctl_t, ctx),
           sizeof(((addrxlat_op_ctl_t *)0)->ctx),
           _CFFI_OP(_CFFI_OP_NOOP, 1) },
  { "sys", offsetof(addrxlat_op_ctl_t, sys),
           sizeof(((addrxlat_op_ctl_t *)0)->sys),
           _CFFI_OP(_CFFI_OP_NOOP, 51) },
  { "op", offsetof(addrxlat_op_ctl_t, op),
          sizeof(((addrxlat_op_ctl_t *)0)->op),
          _CFFI_OP(_CFFI_OP_NOOP, 408) },
  { "data", offsetof(addrxlat_op_ctl_t, data),
            sizeof(((addrxlat_op_ctl_t *)0)->data),
            _CFFI_OP(_CFFI_OP_NOOP, 76) },
  { "caps", offsetof(addrxlat_op_ctl_t, caps),
            sizeof(((addrxlat_op_ctl_t *)0)->caps),
            _CFFI_OP(_CFFI_OP_NOOP, 125) },
  { "idx", offsetof(addrxlat_opt_t, idx),
           sizeof(((addrxlat_opt_t *)0)->idx),
           _CFFI_OP(_CFFI_OP_NOOP, 392) },
  { "val", offsetof(addrxlat_opt_t, val),
           sizeof(((addrxlat_opt_t *)0)->val),
           _CFFI_OP(_CFFI_OP_NOOP, 393) },
  { "pte_format", offsetof(addrxlat_paging_form_t, pte_format),
                  sizeof(((addrxlat_paging_form_t *)0)->pte_format),
                  _CFFI_OP(_CFFI_OP_NOOP, 92) },
  { "nfields", offsetof(addrxlat_paging_form_t, nfields),
               sizeof(((addrxlat_paging_form_t *)0)->nfields),
               _CFFI_OP(_CFFI_OP_NOOP, 432) },
  { "fieldsz", offsetof(addrxlat_paging_form_t, fieldsz),
               sizeof(((addrxlat_paging_form_t *)0)->fieldsz),
               _CFFI_OP(_CFFI_OP_NOOP, 433) },
  { "first_step", offsetof(addrxlat_param_custom_t, first_step),
                  sizeof(((addrxlat_param_custom_t *)0)->first_step),
                  _CFFI_OP(_CFFI_OP_NOOP, 407) },
  { "next_step", offsetof(addrxlat_param_custom_t, next_step),
                 sizeof(((addrxlat_param_custom_t *)0)->next_step),
                 _CFFI_OP(_CFFI_OP_NOOP, 406) },
  { "data", offsetof(addrxlat_param_custom_t, data),
            sizeof(((addrxlat_param_custom_t *)0)->data),
            _CFFI_OP(_CFFI_OP_NOOP, 76) },
  { "off", offsetof(addrxlat_param_linear_t, off),
           sizeof(((addrxlat_param_linear_t *)0)->off),
           _CFFI_OP(_CFFI_OP_NOOP, 414) },
  { "endoff", offsetof(addrxlat_param_lookup_t, endoff),
              sizeof(((addrxlat_param_lookup_t *)0)->endoff),
              _CFFI_OP(_CFFI_OP_NOOP, 55) },
  { "nelem", offsetof(addrxlat_param_lookup_t, nelem),
             sizeof(((addrxlat_param_lookup_t *)0)->nelem),
             _CFFI_OP(_CFFI_OP_NOOP, 117) },
  { "tbl", offsetof(addrxlat_param_lookup_t, tbl),
           sizeof(((addrxlat_param_lookup_t *)0)->tbl),
           _CFFI_OP(_CFFI_OP_NOOP, 385) },
  { "base", offsetof(addrxlat_param_memarr_t, base),
            sizeof(((addrxlat_param_memarr_t *)0)->base),
            _CFFI_OP(_CFFI_OP_NOOP, 383) },
  { "shift", offsetof(addrxlat_param_memarr_t, shift),
             sizeof(((addrxlat_param_memarr_t *)0)->shift),
             _CFFI_OP(_CFFI_OP_NOOP, 72) },
  { "elemsz", offsetof(addrxlat_param_memarr_t, elemsz),
              sizeof(((addrxlat_param_memarr_t *)0)->elemsz),
              _CFFI_OP(_CFFI_OP_NOOP, 72) },
  { "valsz", offsetof(addrxlat_param_memarr_t, valsz),
             sizeof(((addrxlat_param_memarr_t *)0)->valsz),
             _CFFI_OP(_CFFI_OP_NOOP, 72) },
  { "root", offsetof(addrxlat_param_pgt_t, root),
            sizeof(((addrxlat_param_pgt_t *)0)->root),
            _CFFI_OP(_CFFI_OP_NOOP, 383) },
  { "pte_mask", offsetof(addrxlat_param_pgt_t, pte_mask),
                sizeof(((addrxlat_param_pgt_t *)0)->pte_mask),
                _CFFI_OP(_CFFI_OP_NOOP, 55) },
  { "pf", offsetof(addrxlat_param_pgt_t, pf),
          sizeof(((addrxlat_param_pgt_t *)0)->pf),
          _CFFI_OP(_CFFI_OP_NOOP, 394) },
  { "endoff", offsetof(addrxlat_range_t, endoff),
              sizeof(((addrxlat_range_t *)0)->endoff),
              _CFFI_OP(_CFFI_OP_NOOP, 55) },
  { "meth", offsetof(addrxlat_range_t, meth),
            sizeof(((addrxlat_range_t *)0)->meth),
            _CFFI_OP(_CFFI_OP_NOOP, 19) },
  { "ctx", offsetof(addrxlat_step_t, ctx),
           sizeof(((addrxlat_step_t *)0)->ctx),
           _CFFI_OP(_CFFI_OP_NOOP, 1) },
  { "sys", offsetof(addrxlat_step_t, sys),
           sizeof(((addrxlat_step_t *)0)->sys),
           _CFFI_OP(_CFFI_OP_NOOP, 51) },
  { "meth", offsetof(addrxlat_step_t, meth),
            sizeof(((addrxlat_step_t *)0)->meth),
            _CFFI_OP(_CFFI_OP_NOOP, 359) },
  { "remain", offsetof(addrxlat_step_t, remain),
              sizeof(((addrxlat_step_t *)0)->remain),
              _CFFI_OP(_CFFI_OP_NOOP, 432) },
  { "elemsz", offsetof(addrxlat_step_t, elemsz),
              sizeof(((addrxlat_step_t *)0)->elemsz),
              _CFFI_OP(_CFFI_OP_NOOP, 72) },
  { "base", offsetof(addrxlat_step_t, base),
            sizeof(((addrxlat_step_t *)0)->base),
            _CFFI_OP(_CFFI_OP_NOOP, 383) },
  { "raw", offsetof(addrxlat_step_t, raw),
           sizeof(((addrxlat_step_t *)0)->raw),
           _CFFI_OP(_CFFI_OP_NOOP, 429) },
  { "idx", offsetof(addrxlat_step_t, idx),
           sizeof(((addrxlat_step_t *)0)->idx),
           _CFFI_OP(_CFFI_OP_NOOP, 427) },
  { "type", offsetof(kdump_attr_t, type),
            sizeof(((kdump_attr_t *)0)->type),
            _CFFI_OP(_CFFI_OP_NOOP, 195) },
  { "val", offsetof(kdump_attr_t, val),
           sizeof(((kdump_attr_t *)0)->val),
           _CFFI_OP(_CFFI_OP_NOOP, 418) },
  { "key", offsetof(kdump_attr_iter_t, key),
           sizeof(((kdump_attr_iter_t *)0)->key),
           _CFFI_OP(_CFFI_OP_NOOP, 22) },
  { "pos", offsetof(kdump_attr_iter_t, pos),
           sizeof(((kdump_attr_iter_t *)0)->pos),
           _CFFI_OP(_CFFI_OP_NOOP, 416) },
  { "_ptr", offsetof(kdump_attr_ref_t, _ptr),
            sizeof(((kdump_attr_ref_t *)0)->_ptr),
            _CFFI_OP(_CFFI_OP_NOOP, 76) },
  { "str", offsetof(addrxlat_optval_t, str),
           sizeof(((addrxlat_optval_t *)0)->str),
           _CFFI_OP(_CFFI_OP_NOOP, 22) },
  { "num", offsetof(addrxlat_optval_t, num),
           sizeof(((addrxlat_optval_t *)0)->num),
           _CFFI_OP(_CFFI_OP_NOOP, 125) },
  { "addr", offsetof(addrxlat_optval_t, addr),
            sizeof(((addrxlat_optval_t *)0)->addr),
            _CFFI_OP(_CFFI_OP_NOOP, 55) },
  { "fulladdr", offsetof(addrxlat_optval_t, fulladdr),
                sizeof(((addrxlat_optval_t *)0)->fulladdr),
                _CFFI_OP(_CFFI_OP_NOOP, 383) },
  { "custom", offsetof(addrxlat_param_t, custom),
              sizeof(((addrxlat_param_t *)0)->custom),
              _CFFI_OP(_CFFI_OP_NOOP, 395) },
  { "linear", offsetof(addrxlat_param_t, linear),
              sizeof(((addrxlat_param_t *)0)->linear),
              _CFFI_OP(_CFFI_OP_NOOP, 396) },
  { "pgt", offsetof(addrxlat_param_t, pgt),
           sizeof(((addrxlat_param_t *)0)->pgt),
           _CFFI_OP(_CFFI_OP_NOOP, 399) },
  { "lookup", offsetof(addrxlat_param_t, lookup),
              sizeof(((addrxlat_param_t *)0)->lookup),
              _CFFI_OP(_CFFI_OP_NOOP, 397) },
  { "memarr", offsetof(addrxlat_param_t, memarr),
              sizeof(((addrxlat_param_t *)0)->memarr),
              _CFFI_OP(_CFFI_OP_NOOP, 398) },
  { "number", offsetof(kdump_attr_value_t, number),
              sizeof(((kdump_attr_value_t *)0)->number),
              _CFFI_OP(_CFFI_OP_NOOP, 55) },
  { "address", offsetof(kdump_attr_value_t, address),
               sizeof(((kdump_attr_value_t *)0)->address),
               _CFFI_OP(_CFFI_OP_NOOP, 55) },
  { "string", offsetof(kdump_attr_value_t, string),
              sizeof(((kdump_attr_value_t *)0)->string),
              _CFFI_OP(_CFFI_OP_NOOP, 22) },
  { "bitmap", offsetof(kdump_attr_value_t, bitmap),
              sizeof(((kdump_attr_value_t *)0)->bitmap),
              _CFFI_OP(_CFFI_OP_NOOP, 135) },
  { "blob", offsetof(kdump_attr_value_t, blob),
            sizeof(((kdump_attr_value_t *)0)->blob),
            _CFFI_OP(_CFFI_OP_NOOP, 130) },
  { "data", (size_t)-1,
            (size_t)-1,
            _CFFI_OP(_CFFI_OP_NOOP, 76) },
  { "pte", (size_t)-1,
           (size_t)-1,
           _CFFI_OP(_CFFI_OP_NOOP, 55) },
  { "elem", (size_t)-1,
            (size_t)-1,
            _CFFI_OP(_CFFI_OP_NOOP, 386) },
  { "addr", (size_t)-1,
            (size_t)-1,
            _CFFI_OP(_CFFI_OP_NOOP, 55) },
};

static const struct _cffi_struct_union_s _cffi_struct_unions[] = {
  { "$1", 429, _CFFI_F_UNION|_CFFI_F_CHECK_FIELDS,
    (size_t)-2, -2, 75, 4 /* unnamed */ },
  { "_addrxlat_buffer", 379, _CFFI_F_CHECK_FIELDS,
    sizeof(addrxlat_buffer_t), offsetof(struct _cffi_align__addrxlat_buffer_t, y), 0, 6 },
  { "_addrxlat_cb", 381, _CFFI_F_CHECK_FIELDS,
    sizeof(addrxlat_cb_t), offsetof(struct _cffi_align__addrxlat_cb_t, y), 6, 9 },
  { "_addrxlat_ctx", 382, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "_addrxlat_fulladdr", 383, _CFFI_F_CHECK_FIELDS,
    sizeof(addrxlat_fulladdr_t), offsetof(struct _cffi_align__addrxlat_fulladdr_t, y), 15, 2 },
  { "_addrxlat_lookup_elem", 387, _CFFI_F_CHECK_FIELDS,
    sizeof(addrxlat_lookup_elem_t), offsetof(struct _cffi_align__addrxlat_lookup_elem_t, y), 17, 2 },
  { "_addrxlat_map", 388, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "_addrxlat_meth", 389, _CFFI_F_CHECK_FIELDS,
    sizeof(addrxlat_meth_t), offsetof(struct _cffi_align__addrxlat_meth_t, y), 19, 3 },
  { "_addrxlat_op_ctl", 390, _CFFI_F_CHECK_FIELDS,
    sizeof(addrxlat_op_ctl_t), offsetof(struct _cffi_align__addrxlat_op_ctl_t, y), 22, 5 },
  { "_addrxlat_opt", 391, _CFFI_F_CHECK_FIELDS,
    sizeof(addrxlat_opt_t), offsetof(struct _cffi_align__addrxlat_opt_t, y), 27, 2 },
  { "_addrxlat_optval", 393, _CFFI_F_UNION|_CFFI_F_CHECK_FIELDS,
    sizeof(addrxlat_optval_t), offsetof(struct _cffi_align__addrxlat_optval_t, y), 61, 4 },
  { "_addrxlat_paging_form", 394, _CFFI_F_CHECK_FIELDS,
    sizeof(addrxlat_paging_form_t), offsetof(struct _cffi_align__addrxlat_paging_form_t, y), 29, 3 },
  { "_addrxlat_param", 400, _CFFI_F_UNION|_CFFI_F_CHECK_FIELDS,
    sizeof(addrxlat_param_t), offsetof(struct _cffi_align__addrxlat_param_t, y), 65, 5 },
  { "_addrxlat_param_custom", 395, _CFFI_F_CHECK_FIELDS,
    sizeof(addrxlat_param_custom_t), offsetof(struct _cffi_align__addrxlat_param_custom_t, y), 32, 3 },
  { "_addrxlat_param_linear", 396, _CFFI_F_CHECK_FIELDS,
    sizeof(addrxlat_param_linear_t), offsetof(struct _cffi_align__addrxlat_param_linear_t, y), 35, 1 },
  { "_addrxlat_param_lookup", 397, _CFFI_F_CHECK_FIELDS,
    sizeof(addrxlat_param_lookup_t), offsetof(struct _cffi_align__addrxlat_param_lookup_t, y), 36, 3 },
  { "_addrxlat_param_memarr", 398, _CFFI_F_CHECK_FIELDS,
    sizeof(addrxlat_param_memarr_t), offsetof(struct _cffi_align__addrxlat_param_memarr_t, y), 39, 4 },
  { "_addrxlat_param_pgt", 399, _CFFI_F_CHECK_FIELDS,
    sizeof(addrxlat_param_pgt_t), offsetof(struct _cffi_align__addrxlat_param_pgt_t, y), 43, 3 },
  { "_addrxlat_range", 401, _CFFI_F_CHECK_FIELDS,
    sizeof(addrxlat_range_t), offsetof(struct _cffi_align__addrxlat_range_t, y), 46, 2 },
  { "_addrxlat_step", 409, _CFFI_F_CHECK_FIELDS,
    sizeof(addrxlat_step_t), offsetof(struct _cffi_align__addrxlat_step_t, y), 48, 8 },
  { "_addrxlat_sys", 410, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "_kdump_attr", 417, _CFFI_F_CHECK_FIELDS,
    sizeof(kdump_attr_t), offsetof(struct _cffi_align__kdump_attr_t, y), 56, 2 },
  { "_kdump_attr_iter", 415, _CFFI_F_CHECK_FIELDS,
    sizeof(kdump_attr_iter_t), offsetof(struct _cffi_align__kdump_attr_iter_t, y), 58, 2 },
  { "_kdump_attr_ref", 416, _CFFI_F_CHECK_FIELDS,
    sizeof(kdump_attr_ref_t), offsetof(struct _cffi_align__kdump_attr_ref_t, y), 60, 1 },
  { "_kdump_attr_value", 418, _CFFI_F_UNION|_CFFI_F_CHECK_FIELDS,
    sizeof(kdump_attr_value_t), offsetof(struct _cffi_align__kdump_attr_value_t, y), 70, 5 },
  { "_kdump_blob", 419, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "_kdump_bmp", 420, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "_kdump_ctx", 422, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
};

static const struct _cffi_enum_s _cffi_enums[] = {
  { "_addrxlat_addrspace", 49, _cffi_prim_int(sizeof(addrxlat_addrspace_t), ((addrxlat_addrspace_t)-1) <= 0),
    "ADDRXLAT_KPHYSADDR,ADDRXLAT_MACHPHYSADDR,ADDRXLAT_KVADDR,ADDRXLAT_NOADDR" },
  { "_addrxlat_byte_order", 380, _cffi_prim_int(sizeof(addrxlat_byte_order_t), ((addrxlat_byte_order_t)-1) <= 0),
    "ADDRXLAT_BIG_ENDIAN,ADDRXLAT_LITTLE_ENDIAN,ADDRXLAT_HOST_ENDIAN" },
  { "_addrxlat_kind", 384, _cffi_prim_int(sizeof(addrxlat_kind_t), ((addrxlat_kind_t)-1) <= 0),
    "ADDRXLAT_NOMETH,ADDRXLAT_CUSTOM,ADDRXLAT_LINEAR,ADDRXLAT_PGT,ADDRXLAT_LOOKUP,ADDRXLAT_MEMARR" },
  { "_addrxlat_optidx", 392, _cffi_prim_int(sizeof(addrxlat_optidx_t), ((addrxlat_optidx_t)-1) <= 0),
    "ADDRXLAT_OPT_NULL,ADDRXLAT_OPT_arch,ADDRXLAT_OPT_os_type,ADDRXLAT_OPT_version_code,ADDRXLAT_OPT_phys_bits,ADDRXLAT_OPT_virt_bits,ADDRXLAT_OPT_page_shift,ADDRXLAT_OPT_phys_base,ADDRXLAT_OPT_rootpgt,ADDRXLAT_OPT_xen_p2m_mfn,ADDRXLAT_OPT_xen_xlat,ADDRXLAT_OPT_NUM" },
  { "_addrxlat_pte_format", 92, _cffi_prim_int(sizeof(addrxlat_pte_format_t), ((addrxlat_pte_format_t)-1) <= 0),
    "ADDRXLAT_PTE_INVALID,ADDRXLAT_PTE_NONE,ADDRXLAT_PTE_PFN32,ADDRXLAT_PTE_PFN64,ADDRXLAT_PTE_AARCH64,ADDRXLAT_PTE_IA32,ADDRXLAT_PTE_IA32_PAE,ADDRXLAT_PTE_X86_64,ADDRXLAT_PTE_S390X,ADDRXLAT_PTE_PPC64_LINUX_RPN30,ADDRXLAT_PTE_AARCH64_LPA,ADDRXLAT_PTE_AARCH64_LPA2,ADDRXLAT_PTE_ARM,ADDRXLAT_PTE_RISCV32,ADDRXLAT_PTE_RISCV64" },
  { "_addrxlat_status", 44, _cffi_prim_int(sizeof(addrxlat_status), ((addrxlat_status)-1) <= 0),
    "ADDRXLAT_OK,ADDRXLAT_ERR_NOTIMPL,ADDRXLAT_ERR_NOTPRESENT,ADDRXLAT_ERR_INVALID,ADDRXLAT_ERR_NOMEM,ADDRXLAT_ERR_NODATA,ADDRXLAT_ERR_NOMETH,ADDRXLAT_ERR_CUSTOM_BASE" },
  { "_addrxlat_sys_map", 13, _cffi_prim_int(sizeof(addrxlat_sys_map_t), ((addrxlat_sys_map_t)-1) <= 0),
    "ADDRXLAT_SYS_MAP_HW,ADDRXLAT_SYS_MAP_KV_PHYS,ADDRXLAT_SYS_MAP_KPHYS_DIRECT,ADDRXLAT_SYS_MAP_MACHPHYS_KPHYS,ADDRXLAT_SYS_MAP_KPHYS_MACHPHYS,ADDRXLAT_SYS_MAP_NUM" },
  { "_addrxlat_sys_meth", 19, _cffi_prim_int(sizeof(addrxlat_sys_meth_t), ((addrxlat_sys_meth_t)-1) <= 0),
    "ADDRXLAT_SYS_METH_NONE,ADDRXLAT_SYS_METH_PGT,ADDRXLAT_SYS_METH_UPGT,ADDRXLAT_SYS_METH_DIRECT,ADDRXLAT_SYS_METH_KTEXT,ADDRXLAT_SYS_METH_VMEMMAP,ADDRXLAT_SYS_METH_RDIRECT,ADDRXLAT_SYS_METH_MACHPHYS_KPHYS,ADDRXLAT_SYS_METH_KPHYS_MACHPHYS,ADDRXLAT_SYS_METH_CUSTOM" },
  { "_kdump_addrspace", 214, _cffi_prim_int(sizeof(kdump_addrspace_t), ((kdump_addrspace_t)-1) <= 0),
    "KDUMP_KPHYSADDR,KDUMP_MACHPHYSADDR,KDUMP_KVADDR,KDUMP_NOADDR" },
  { "_kdump_attr_type", 195, _cffi_prim_int(sizeof(kdump_attr_type_t), ((kdump_attr_type_t)-1) <= 0),
    "KDUMP_NIL,KDUMP_DIRECTORY,KDUMP_NUMBER,KDUMP_ADDRESS,KDUMP_STRING,KDUMP_BITMAP,KDUMP_BLOB" },
  { "_kdump_byte_order", 421, _cffi_prim_int(sizeof(kdump_byte_order_t), ((kdump_byte_order_t)-1) <= 0),
    "KDUMP_BIG_ENDIAN,KDUMP_LITTLE_ENDIAN" },
  { "_kdump_mmap_policy", 423, _cffi_prim_int(sizeof(kdump_mmap_policy_t), ((kdump_mmap_policy_t)-1) <= 0),
    "KDUMP_MMAP_NEVER,KDUMP_MMAP_ALWAYS,KDUMP_MMAP_TRY,KDUMP_MMAP_TRY_ONCE" },
  { "_kdump_status", 104, _cffi_prim_int(sizeof(kdump_status), ((kdump_status)-1) <= 0),
    "KDUMP_OK,KDUMP_ERR_SYSTEM,KDUMP_ERR_NOTIMPL,KDUMP_ERR_NODATA,KDUMP_ERR_CORRUPT,KDUMP_ERR_INVALID,KDUMP_ERR_NOKEY,KDUMP_ERR_EOF,KDUMP_ERR_BUSY,KDUMP_ERR_ADDRXLAT" },
  { "_kdump_xen_type", 425, _cffi_prim_int(sizeof(kdump_xen_type_t), ((kdump_xen_type_t)-1) <= 0),
    "KDUMP_XEN_NONE,KDUMP_XEN_SYSTEM,KDUMP_XEN_DOMAIN" },
  { "_kdump_xen_xlat", 426, _cffi_prim_int(sizeof(kdump_xen_xlat_t), ((kdump_xen_xlat_t)-1) <= 0),
    "KDUMP_XEN_AUTO,KDUMP_XEN_NONAUTO" },
  { "kdump_clone_bits", 413, _cffi_prim_int(sizeof(enum kdump_clone_bits), ((enum kdump_clone_bits)-1) <= 0),
    "KDUMP_CLONE_BIT_XLAT" },
};

static const struct _cffi_typename_s _cffi_typenames[] = {
  { "addrxlat_addr_t", 55 },
  { "addrxlat_addrspace_t", 49 },
  { "addrxlat_buffer_t", 379 },
  { "addrxlat_byte_order_t", 380 },
  { "addrxlat_cb_num_value_fn", 37 },
  { "addrxlat_cb_reg_value_fn", 37 },
  { "addrxlat_cb_sym_offsetof_fn", 31 },
  { "addrxlat_cb_sym_sizeof_fn", 37 },
  { "addrxlat_cb_sym_value_fn", 37 },
  { "addrxlat_cb_t", 381 },
  { "addrxlat_ctx_t", 382 },
  { "addrxlat_first_step_fn", 65 },
  { "addrxlat_fulladdr_t", 383 },
  { "addrxlat_get_page_fn", 27 },
  { "addrxlat_kind_t", 384 },
  { "addrxlat_lookup_elem_t", 387 },
  { "addrxlat_map_t", 388 },
  { "addrxlat_meth_t", 389 },
  { "addrxlat_next_step_fn", 62 },
  { "addrxlat_off_t", 414 },
  { "addrxlat_op_ctl_t", 390 },
  { "addrxlat_op_fn", 75 },
  { "addrxlat_opt_t", 391 },
  { "addrxlat_optidx_t", 392 },
  { "addrxlat_optval_t", 393 },
  { "addrxlat_paging_form_t", 394 },
  { "addrxlat_param_custom_t", 395 },
  { "addrxlat_param_linear_t", 396 },
  { "addrxlat_param_lookup_t", 397 },
  { "addrxlat_param_memarr_t", 398 },
  { "addrxlat_param_pgt_t", 399 },
  { "addrxlat_param_t", 400 },
  { "addrxlat_pte_format_t", 92 },
  { "addrxlat_pte_t", 55 },
  { "addrxlat_put_page_fn", 325 },
  { "addrxlat_range_t", 401 },
  { "addrxlat_read_caps_fn", 289 },
  { "addrxlat_status", 44 },
  { "addrxlat_step_t", 409 },
  { "addrxlat_sys_map_t", 13 },
  { "addrxlat_sys_meth_t", 19 },
  { "addrxlat_sys_t", 410 },
  { "kdump_addr_t", 55 },
  { "kdump_addrspace_t", 214 },
  { "kdump_attr_iter_t", 415 },
  { "kdump_attr_ref_t", 416 },
  { "kdump_attr_t", 417 },
  { "kdump_attr_type_t", 195 },
  { "kdump_attr_value_t", 418 },
  { "kdump_blob_t", 419 },
  { "kdump_bmp_t", 420 },
  { "kdump_byte_order_t", 421 },
  { "kdump_ctx_t", 422 },
  { "kdump_mmap_policy_t", 423 },
  { "kdump_num_t", 55 },
  { "kdump_paddr_t", 55 },
  { "kdump_status", 104 },
  { "kdump_vaddr_t", 55 },
  { "kdump_xen_type_t", 425 },
  { "kdump_xen_xlat_t", 426 },
};

static const struct _cffi_type_context_s _cffi_type_context = {
  _cffi_types,
  _cffi_globals,
  _cffi_fields,
  _cffi_struct_unions,
  _cffi_enums,
  _cffi_typenames,
  218,  /* num_globals */
  28,  /* num_struct_unions */
  16,  /* num_enums */
  60,  /* num_typenames */
  NULL,  /* no includes */
  437,  /* num_types */
  0,  /* flags */
};

#ifdef __GNUC__
#  pragma GCC visibility push(default)  /* for -fvisibility= */
#endif

#ifdef PYPY_VERSION
PyMODINIT_FUNC
_cffi_pypyinit__kdumpfile(const void *p[])
{
    p[0] = (const void *)0x2601;
    p[1] = &_cffi_type_context;
#if PY_MAJOR_VERSION >= 3
    return NULL;
#endif
}
#  ifdef _MSC_VER
     PyMODINIT_FUNC
#  if PY_MAJOR_VERSION >= 3
     PyInit__kdumpfile(void) { return NULL; }
#  else
     init_kdumpfile(void) { }
#  endif
#  endif
#elif PY_MAJOR_VERSION >= 3
PyMODINIT_FUNC
PyInit__kdumpfile(void)
{
  return _cffi_init("_kdumpfile", 0x2601, &_cffi_type_context);
}
#else
PyMODINIT_FUNC
init_kdumpfile(void)
{
  _cffi_init("_kdumpfile", 0x2601, &_cffi_type_context);
}
#endif

#ifdef __GNUC__
#  pragma GCC visibility pop
#endif
